/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtNetworkAPI_H
#define _QtNetworkAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtNetwork[0]
#define sipNameNr_QSslConfiguration__NextProtocolNegotiationStatus 50
#define sipName_QSslConfiguration__NextProtocolNegotiationStatus &sipStrings_QtNetwork[50]
#define sipNameNr_ConnectionCacheExpiryTimeoutSecondsAttribute 99
#define sipName_ConnectionCacheExpiryTimeoutSecondsAttribute &sipStrings_QtNetwork[99]
#define sipNameNr_QDnsTlsAssociationRecord__CertificateUsage 144
#define sipName_QDnsTlsAssociationRecord__CertificateUsage &sipStrings_QtNetwork[144]
#define sipNameNr_187 187
#define sipName_187 &sipStrings_QtNetwork[187]
#define sipNameNr_QNetworkAddressEntry__DnsEligibilityStatus 230
#define sipName_QNetworkAddressEntry__DnsEligibilityStatus &sipStrings_QtNetwork[230]
#define sipNameNr_273 273
#define sipName_273 &sipStrings_QtNetwork[273]
#define sipNameNr_314 314
#define sipName_314 &sipStrings_QtNetwork[314]
#define sipNameNr_355 355
#define sipName_355 &sipStrings_QtNetwork[355]
#define sipNameNr_QNetworkRequest__TransferTimeoutConstant 396
#define sipName_QNetworkRequest__TransferTimeoutConstant &sipStrings_QtNetwork[396]
#define sipNameNr_QDnsTlsAssociationRecord__MatchingType 437
#define sipName_QDnsTlsAssociationRecord__MatchingType &sipStrings_QtNetwork[437]
#define sipNameNr_SslOptionDisableServerCipherPreference 476
#define sipName_SslOptionDisableServerCipherPreference &sipStrings_QtNetwork[476]
#define sipNameNr_EmitAllUploadProgressSignalsAttribute 515
#define sipName_EmitAllUploadProgressSignalsAttribute &sipStrings_QtNetwork[515]
#define sipNameNr_QAbstractSocket__NetworkLayerProtocol 553
#define sipName_QAbstractSocket__NetworkLayerProtocol &sipStrings_QtNetwork[553]
#define sipNameNr_isStrictTransportSecurityStoreEnabled 591
#define sipName_isStrictTransportSecurityStoreEnabled &sipStrings_QtNetwork[591]
#define sipNameNr_629 629
#define sipName_629 &sipStrings_QtNetwork[629]
#define sipNameNr_QNetworkInformation__TransportMedium 666
#define sipName_QNetworkInformation__TransportMedium &sipStrings_QtNetwork[666]
#define sipNameNr_SslOptionDisableServerNameIndication 703
#define sipName_SslOptionDisableServerNameIndication &sipStrings_QtNetwork[703]
#define sipNameNr_setTcpKeepAliveIntervalBetweenProbes 740
#define sipName_setTcpKeepAliveIntervalBetweenProbes &sipStrings_QtNetwork[740]
#define sipNameNr_AuthorityIssuerSerialNumberMismatch 777
#define sipName_AuthorityIssuerSerialNumberMismatch &sipStrings_QtNetwork[777]
#define sipNameNr_CrossOriginEmbedderPolicyReportOnly 813
#define sipName_CrossOriginEmbedderPolicyReportOnly &sipStrings_QtNetwork[813]
#define sipNameNr_SslOptionDisableLegacyRenegotiation 849
#define sipName_SslOptionDisableLegacyRenegotiation &sipStrings_QtNetwork[849]
#define sipNameNr_UnableToDecryptCertificateSignature 885
#define sipName_UnableToDecryptCertificateSignature &sipStrings_QtNetwork[885]
#define sipNameNr_setDecompressedSafetyCheckThreshold 921
#define sipName_setDecompressedSafetyCheckThreshold &sipStrings_QtNetwork[921]
#define sipNameNr_setTcpKeepAliveIdleTimeBeforeProbes 957
#define sipName_setTcpKeepAliveIdleTimeBeforeProbes &sipStrings_QtNetwork[957]
#define sipNameNr_NextProtocolNegotiationUnsupported 993
#define sipName_NextProtocolNegotiationUnsupported &sipStrings_QtNetwork[993]
#define sipNameNr_QDnsTlsAssociationRecord__Selector 1028
#define sipName_QDnsTlsAssociationRecord__Selector &sipStrings_QtNetwork[1028]
#define sipNameNr_1063 1063
#define sipName_1063 &sipStrings_QtNetwork[1063]
#define sipNameNr_1098 1098
#define sipName_1098 &sipStrings_QtNetwork[1098]
#define sipNameNr_1133 1133
#define sipName_1133 &sipStrings_QtNetwork[1133]
#define sipNameNr_QSslDiffieHellmanParameters__Error 1168
#define sipName_QSslDiffieHellmanParameters__Error &sipStrings_QtNetwork[1168]
#define sipNameNr_SslOptionDisableSessionPersistence 1203
#define sipName_SslOptionDisableSessionPersistence &sipStrings_QtNetwork[1203]
#define sipNameNr_enableStrictTransportSecurityStore 1238
#define sipName_enableStrictTransportSecurityStore &sipStrings_QtNetwork[1238]
#define sipNameNr_preSharedKeyAuthenticationRequired 1273
#define sipName_preSharedKeyAuthenticationRequired &sipStrings_QtNetwork[1273]
#define sipNameNr_ContentOperationNotPermittedError 1308
#define sipName_ContentOperationNotPermittedError &sipStrings_QtNetwork[1308]
#define sipNameNr_CrossOriginOpenerPolicyReportOnly 1342
#define sipName_CrossOriginOpenerPolicyReportOnly &sipStrings_QtNetwork[1342]
#define sipNameNr_NextProtocolNegotiationNegotiated 1376
#define sipName_NextProtocolNegotiationNegotiated &sipStrings_QtNetwork[1376]
#define sipNameNr_1410 1410
#define sipName_1410 &sipStrings_QtNetwork[1410]
#define sipNameNr_1444 1444
#define sipName_1444 &sipStrings_QtNetwork[1444]
#define sipNameNr_QNetworkInformation__Reachability 1478
#define sipName_QNetworkInformation__Reachability &sipStrings_QtNetwork[1478]
#define sipNameNr_QNetworkRequest__CacheLoadControl 1512
#define sipName_QNetworkRequest__CacheLoadControl &sipStrings_QtNetwork[1512]
#define sipNameNr_UnableToGetLocalIssuerCertificate 1546
#define sipName_UnableToGetLocalIssuerCertificate &sipStrings_QtNetwork[1546]
#define sipNameNr_setSslConfigurationImplementation 1580
#define sipName_setSslConfigurationImplementation &sipStrings_QtNetwork[1580]
#define sipNameNr_setStrictTransportSecurityEnabled 1614
#define sipName_setStrictTransportSecurityEnabled &sipStrings_QtNetwork[1614]
#define sipNameNr_tcpKeepAliveIntervalBetweenProbes 1648
#define sipName_tcpKeepAliveIntervalBetweenProbes &sipStrings_QtNetwork[1648]
#define sipNameNr_AutoDeleteReplyOnFinishAttribute 1682
#define sipName_AutoDeleteReplyOnFinishAttribute &sipStrings_QtNetwork[1682]
#define sipNameNr_BackgroundRequestNotAllowedError 1715
#define sipName_BackgroundRequestNotAllowedError &sipStrings_QtNetwork[1715]
#define sipNameNr_ProxyAuthenticationRequiredError 1748
#define sipName_ProxyAuthenticationRequiredError &sipStrings_QtNetwork[1748]
#define sipNameNr_1781 1781
#define sipName_1781 &sipStrings_QtNetwork[1781]
#define sipNameNr_QHostAddress__ConversionModeFlag 1814
#define sipName_QHostAddress__ConversionModeFlag &sipStrings_QtNetwork[1814]
#define sipNameNr_QNetworkAccessManager__Operation 1847
#define sipName_QNetworkAccessManager__Operation &sipStrings_QtNetwork[1847]
#define sipNameNr_QNetworkInterface__InterfaceFlag 1880
#define sipName_QNetworkInterface__InterfaceFlag &sipStrings_QtNetwork[1880]
#define sipNameNr_QNetworkInterface__InterfaceType 1913
#define sipName_QNetworkInterface__InterfaceType &sipStrings_QtNetwork[1913]
#define sipNameNr_UseRfc7578PercentEncodedFilename 1946
#define sipName_UseRfc7578PercentEncodedFilename &sipStrings_QtNetwork[1946]
#define sipNameNr_decompressedSafetyCheckThreshold 1979
#define sipName_decompressedSafetyCheckThreshold &sipStrings_QtNetwork[1979]
#define sipNameNr_isStrictTransportSecurityEnabled 2012
#define sipName_isStrictTransportSecurityEnabled &sipStrings_QtNetwork[2012]
#define sipNameNr_setDtlsCookieVerificationEnabled 2045
#define sipName_setDtlsCookieVerificationEnabled &sipStrings_QtNetwork[2045]
#define sipNameNr_setHandshakeMustInterruptOnError 2078
#define sipName_setHandshakeMustInterruptOnError &sipStrings_QtNetwork[2078]
#define sipNameNr_2111 2111
#define sipName_2111 &sipStrings_QtNetwork[2111]
#define sipNameNr_2144 2144
#define sipName_2144 &sipStrings_QtNetwork[2144]
#define sipNameNr_tcpKeepAliveIdleTimeBeforeProbes 2177
#define sipName_tcpKeepAliveIdleTimeBeforeProbes &sipStrings_QtNetwork[2177]
#define sipNameNr_ContentSecurityPolicyReportOnly 2210
#define sipName_ContentSecurityPolicyReportOnly &sipStrings_QtNetwork[2210]
#define sipNameNr_2242 2242
#define sipName_2242 &sipStrings_QtNetwork[2242]
#define sipNameNr_2274 2274
#define sipName_2274 &sipStrings_QtNetwork[2274]
#define sipNameNr_2306 2306
#define sipName_2306 &sipStrings_QtNetwork[2306]
#define sipNameNr_QNetworkRequest__RedirectPolicy 2338
#define sipName_QNetworkRequest__RedirectPolicy &sipStrings_QtNetwork[2338]
#define sipNameNr_UnsupportedSocketOperationError 2370
#define sipName_UnsupportedSocketOperationError &sipStrings_QtNetwork[2370]
#define sipNameNr_addStrictTransportSecurityHosts 2402
#define sipName_addStrictTransportSecurityHosts &sipStrings_QtNetwork[2402]
#define sipNameNr_DefaultTransferTimeoutConstant 2434
#define sipName_DefaultTransferTimeoutConstant &sipStrings_QtNetwork[2434]
#define sipNameNr_DoNotBufferUploadDataAttribute 2465
#define sipName_DoNotBufferUploadDataAttribute &sipStrings_QtNetwork[2465]
#define sipNameNr_Http2CleartextAllowedAttribute 2496
#define sipName_Http2CleartextAllowedAttribute &sipStrings_QtNetwork[2496]
#define sipNameNr_HttpPipeliningAllowedAttribute 2527
#define sipName_HttpPipeliningAllowedAttribute &sipStrings_QtNetwork[2527]
#define sipNameNr_HttpPipeliningWasUsedAttribute 2558
#define sipName_HttpPipeliningWasUsedAttribute &sipStrings_QtNetwork[2558]
#define sipNameNr_OriginalContentLengthAttribute 2589
#define sipName_OriginalContentLengthAttribute &sipStrings_QtNetwork[2589]
#define sipNameNr_QLocalSocket__LocalSocketError 2620
#define sipName_QLocalSocket__LocalSocketError &sipStrings_QtNetwork[2620]
#define sipNameNr_QLocalSocket__LocalSocketState 2651
#define sipName_QLocalSocket__LocalSocketState &sipStrings_QtNetwork[2651]
#define sipNameNr_QSsl__AlternativeNameEntryType 2682
#define sipName_QSsl__AlternativeNameEntryType &sipStrings_QtNetwork[2682]
#define sipNameNr_QSslCertificate__PatternSyntax 2713
#define sipName_QSslCertificate__PatternSyntax &sipStrings_QtNetwork[2713]
#define sipNameNr_SocketAddressNotAvailableError 2744
#define sipName_SocketAddressNotAvailableError &sipStrings_QtNetwork[2744]
#define sipNameNr_SslOptionDisableEmptyFragments 2775
#define sipName_SslOptionDisableEmptyFragments &sipStrings_QtNetwork[2775]
#define sipNameNr_SslOptionDisableSessionSharing 2806
#define sipName_SslOptionDisableSessionSharing &sipStrings_QtNetwork[2806]
#define sipNameNr_SslOptionDisableSessionTickets 2837
#define sipName_SslOptionDisableSessionTickets &sipStrings_QtNetwork[2837]
#define sipNameNr_UnableToVerifyFirstCertificate 2868
#define sipName_UnableToVerifyFirstCertificate &sipStrings_QtNetwork[2868]
#define sipNameNr_UnfinishedSocketOperationError 2899
#define sipName_UnfinishedSocketOperationError &sipStrings_QtNetwork[2899]
#define sipNameNr_sslConfigurationImplementation 2930
#define sipName_sslConfigurationImplementation &sipStrings_QtNetwork[2930]
#define sipNameNr_supportedSchemesImplementation 2961
#define sipName_supportedSchemesImplementation &sipStrings_QtNetwork[2961]
#define sipNameNr_AccessControlAllowCredentials 2992
#define sipName_AccessControlAllowCredentials &sipStrings_QtNetwork[2992]
#define sipNameNr_CertificateAuthorityConstrait 3022
#define sipName_CertificateAuthorityConstrait &sipStrings_QtNetwork[3022]
#define sipNameNr_IncludeReferredTokenBindingID 3052
#define sipName_IncludeReferredTokenBindingID &sipStrings_QtNetwork[3052]
#define sipNameNr_NextProtocolNegotiationStatus 69
#define sipName_NextProtocolNegotiationStatus &sipStrings_QtNetwork[69]
#define sipNameNr_ProtocolInvalidOperationError 3082
#define sipName_ProtocolInvalidOperationError &sipStrings_QtNetwork[3082]
#define sipNameNr_QAbstractSocket__SocketOption 3112
#define sipName_QAbstractSocket__SocketOption &sipStrings_QtNetwork[3112]
#define sipNameNr_QHttpHeaders__WellKnownHeader 3142
#define sipName_QHttpHeaders__WellKnownHeader &sipStrings_QtNetwork[3142]
#define sipNameNr_3172 3172
#define sipName_3172 &sipStrings_QtNetwork[3172]
#define sipNameNr_3202 3202
#define sipName_3202 &sipStrings_QtNetwork[3202]
#define sipNameNr_3232 3232
#define sipName_3232 &sipStrings_QtNetwork[3232]
#define sipNameNr_QNetworkProxyQuery__QueryType 3262
#define sipName_QNetworkProxyQuery__QueryType &sipStrings_QtNetwork[3262]
#define sipNameNr_QNetworkRequest__KnownHeaders 3292
#define sipName_QNetworkRequest__KnownHeaders &sipStrings_QtNetwork[3292]
#define sipNameNr_QSslPreSharedKeyAuthenticator 3322
#define sipName_QSslPreSharedKeyAuthenticator &sipStrings_QtNetwork[3322]
#define sipNameNr_ReceiveBufferSizeSocketOption 3352
#define sipName_ReceiveBufferSizeSocketOption &sipStrings_QtNetwork[3352]
#define sipNameNr_UnableToDecodeIssuerPublicKey 3382
#define sipName_UnableToDecodeIssuerPublicKey &sipStrings_QtNetwork[3382]
#define sipNameNr_dtlsCookieVerificationEnabled 3412
#define sipName_dtlsCookieVerificationEnabled &sipStrings_QtNetwork[3412]
#define sipNameNr_handshakeMustInterruptOnError 3442
#define sipName_handshakeMustInterruptOnError &sipStrings_QtNetwork[3442]
#define sipNameNr_ignoreSslErrorsImplementation 3472
#define sipName_ignoreSslErrorsImplementation &sipStrings_QtNetwork[3472]
#define sipNameNr_nextProtocolNegotiationStatus 3502
#define sipName_nextProtocolNegotiationStatus &sipStrings_QtNetwork[3502]
#define sipNameNr_setBackendConfigurationOption 3532
#define sipName_setBackendConfigurationOption &sipStrings_QtNetwork[3532]
#define sipNameNr_setNumberOfConnectionsPerHost 3562
#define sipName_setNumberOfConnectionsPerHost &sipStrings_QtNetwork[3562]
#define sipNameNr_AuthenticationReuseAttribute 3592
#define sipName_AuthenticationReuseAttribute &sipStrings_QtNetwork[3592]
#define sipNameNr_BadCertificateStatusResponse 3621
#define sipName_BadCertificateStatusResponse &sipStrings_QtNetwork[3621]
#define sipNameNr_ConnectionEncryptedAttribute 3650
#define sipName_ConnectionEncryptedAttribute &sipStrings_QtNetwork[3650]
#define sipNameNr_FullLocalServerNameAttribute 3679
#define sipName_FullLocalServerNameAttribute &sipStrings_QtNetwork[3679]
#define sipNameNr_OperationNotImplementedError 3708
#define sipName_OperationNotImplementedError &sipStrings_QtNetwork[3708]
#define sipNameNr_QAbstractSocket__SocketError 3737
#define sipName_QAbstractSocket__SocketError &sipStrings_QtNetwork[3737]
#define sipNameNr_QAbstractSocket__SocketState 3766
#define sipName_QAbstractSocket__SocketState &sipStrings_QtNetwork[3766]
#define sipNameNr_QHostAddress__SpecialAddress 3795
#define sipName_QHostAddress__SpecialAddress &sipStrings_QtNetwork[3795]
#define sipNameNr_3824 3824
#define sipName_3824 &sipStrings_QtNetwork[3824]
#define sipNameNr_QNetworkInformation__Feature 3853
#define sipName_QNetworkInformation__Feature &sipStrings_QtNetwork[3853]
#define sipNameNr_QNetworkRequest__LoadControl 3882
#define sipName_QNetworkRequest__LoadControl &sipStrings_QtNetwork[3882]
#define sipNameNr_QSslCertificate__SubjectInfo 3911
#define sipName_QSslCertificate__SubjectInfo &sipStrings_QtNetwork[3911]
#define sipNameNr_SelfSignedCertificateInChain 3940
#define sipName_SelfSignedCertificateInChain &sipStrings_QtNetwork[3940]
#define sipNameNr_ServiceCertificateConstraint 3969
#define sipName_ServiceCertificateConstraint &sipStrings_QtNetwork[3969]
#define sipNameNr_TemporaryNetworkFailureError 3998
#define sipName_TemporaryNetworkFailureError &sipStrings_QtNetwork[3998]
#define sipNameNr_UnableToGetIssuerCertificate 4027
#define sipName_UnableToGetIssuerCertificate &sipStrings_QtNetwork[4027]
#define sipNameNr_continueInterruptedHandshake 4056
#define sipName_continueInterruptedHandshake &sipStrings_QtNetwork[4056]
#define sipNameNr_isBehindCaptivePortalChanged 4085
#define sipName_isBehindCaptivePortalChanged &sipStrings_QtNetwork[4085]
#define sipNameNr_setHuffmanCompressionEnabled 4114
#define sipName_setHuffmanCompressionEnabled &sipStrings_QtNetwork[4114]
#define sipNameNr_setMissingCertificateIsFatal 4143
#define sipName_setMissingCertificateIsFatal &sipStrings_QtNetwork[4143]
#define sipNameNr_sslLibraryBuildVersionNumber 4172
#define sipName_sslLibraryBuildVersionNumber &sipStrings_QtNetwork[4172]
#define sipNameNr_sslLibraryBuildVersionString 4201
#define sipName_sslLibraryBuildVersionString &sipStrings_QtNetwork[4201]
#define sipNameNr_4230 4230
#define sipName_4230 &sipStrings_QtNetwork[4230]
#define sipNameNr_strictTransportSecurityHosts 4259
#define sipName_strictTransportSecurityHosts &sipStrings_QtNetwork[4259]
#define sipNameNr_AccessControlRequestHeaders 4288
#define sipName_AccessControlRequestHeaders &sipStrings_QtNetwork[4288]
#define sipNameNr_AuthenticationRequiredError 1753
#define sipName_AuthenticationRequiredError &sipStrings_QtNetwork[1753]
#define sipNameNr_NextProtocolNegotiationNone 4316
#define sipName_NextProtocolNegotiationNone &sipStrings_QtNetwork[4316]
#define sipNameNr_OcspResponseCannotBeTrusted 4344
#define sipName_OcspResponseCannotBeTrusted &sipStrings_QtNetwork[4344]
#define sipNameNr_PreferLatin1EncodedFilename 4372
#define sipName_PreferLatin1EncodedFilename &sipStrings_QtNetwork[4372]
#define sipNameNr_ProxyConnectionRefusedError 4400
#define sipName_ProxyConnectionRefusedError &sipStrings_QtNetwork[4400]
#define sipNameNr_ProxyConnectionTimeoutError 4428
#define sipName_ProxyConnectionTimeoutError &sipStrings_QtNetwork[4428]
#define sipNameNr_QAbstractSocket__SocketType 4456
#define sipName_QAbstractSocket__SocketType &sipStrings_QtNetwork[4456]
#define sipNameNr_QHttpMultiPart__ContentType 4484
#define sipName_QHttpMultiPart__ContentType &sipStrings_QtNetwork[4484]
#define sipNameNr_4512 4512
#define sipName_4512 &sipStrings_QtNetwork[4512]
#define sipNameNr_4540 4540
#define sipName_4540 &sipStrings_QtNetwork[4540]
#define sipNameNr_QNetworkReply__NetworkError 4568
#define sipName_QNetworkReply__NetworkError &sipStrings_QtNetwork[4568]
#define sipNameNr_QSslDiffieHellmanParameters 4596
#define sipName_QSslDiffieHellmanParameters &sipStrings_QtNetwork[4596]
#define sipNameNr_SslOptionDisableCompression 4624
#define sipName_SslOptionDisableCompression &sipStrings_QtNetwork[4624]
#define sipNameNr_UnknownNetworkLayerProtocol 4652
#define sipName_UnknownNetworkLayerProtocol &sipStrings_QtNetwork[4652]
#define sipNameNr_handshakeInterruptedOnError 4680
#define sipName_handshakeInterruptedOnError &sipStrings_QtNetwork[4680]
#define sipNameNr_proxyAuthenticationRequired 4708
#define sipName_proxyAuthenticationRequired &sipStrings_QtNetwork[4708]
#define sipNameNr_setDefaultDtlsConfiguration 4736
#define sipName_setDefaultDtlsConfiguration &sipStrings_QtNetwork[4736]
#define sipNameNr_setPreSharedKeyIdentityHint 4764
#define sipName_setPreSharedKeyIdentityHint &sipStrings_QtNetwork[4764]
#define sipNameNr_setSessionReceiveWindowSize 4792
#define sipName_setSessionReceiveWindowSize &sipStrings_QtNetwork[4792]
#define sipNameNr_4820 4820
#define sipName_4820 &sipStrings_QtNetwork[4820]
#define sipNameNr_AccessControlExposeHeaders 4848
#define sipName_AccessControlExposeHeaders &sipStrings_QtNetwork[4848]
#define sipNameNr_AccessControlRequestMethod 4875
#define sipName_AccessControlRequestMethod &sipStrings_QtNetwork[4875]
#define sipNameNr_BackgroundRequestAttribute 4902
#define sipName_BackgroundRequestAttribute &sipStrings_QtNetwork[4902]
#define sipNameNr_CertificateSignatureFailed 4929
#define sipName_CertificateSignatureFailed &sipStrings_QtNetwork[4929]
#define sipNameNr_CookieLoadControlAttribute 4956
#define sipName_CookieLoadControlAttribute &sipStrings_QtNetwork[4956]
#define sipNameNr_CookieSaveControlAttribute 4983
#define sipName_CookieSaveControlAttribute &sipStrings_QtNetwork[4983]
#define sipNameNr_DistinguishedNameQualifier 5010
#define sipName_DistinguishedNameQualifier &sipStrings_QtNetwork[5010]
#define sipNameNr_OmitRfc8187EncodedFilename 5037
#define sipName_OmitRfc8187EncodedFilename &sipStrings_QtNetwork[5037]
#define sipNameNr_ProxyConnectionClosedError 5064
#define sipName_ProxyConnectionClosedError &sipStrings_QtNetwork[5064]
#define sipNameNr_QAbstractSocket__PauseMode 5091
#define sipName_QAbstractSocket__PauseMode &sipStrings_QtNetwork[5091]
#define sipNameNr_QLocalServer__SocketOption 5118
#define sipName_QLocalServer__SocketOption &sipStrings_QtNetwork[5118]
#define sipNameNr_QLocalSocket__SocketOption 5145
#define sipName_QLocalSocket__SocketOption &sipStrings_QtNetwork[5145]
#define sipNameNr_QNetworkRequest__Attribute 5172
#define sipName_QNetworkRequest__Attribute &sipStrings_QtNetwork[5172]
#define sipNameNr_QSslSocket__PeerVerifyMode 5199
#define sipName_QSslSocket__PeerVerifyMode &sipStrings_QtNetwork[5199]
#define sipNameNr_RedirectionTargetAttribute 5226
#define sipName_RedirectionTargetAttribute &sipStrings_QtNetwork[5226]
#define sipNameNr_SendBufferSizeSocketOption 5253
#define sipName_SendBufferSizeSocketOption &sipStrings_QtNetwork[5253]
#define sipNameNr_SourceIsFromCacheAttribute 5280
#define sipName_SourceIsFromCacheAttribute &sipStrings_QtNetwork[5280]
#define sipNameNr_UserVerifiedRedirectPolicy 5307
#define sipName_UserVerifiedRedirectPolicy &sipStrings_QtNetwork[5307]
#define sipNameNr_numberOfConnectionsPerHost 5334
#define sipName_numberOfConnectionsPerHost &sipStrings_QtNetwork[5334]
#define sipNameNr_pendingConnectionAvailable 5361
#define sipName_pendingConnectionAvailable &sipStrings_QtNetwork[5361]
#define sipNameNr_setApplicationProxyFactory 5388
#define sipName_setApplicationProxyFactory &sipStrings_QtNetwork[5388]
#define sipNameNr_setDiffieHellmanParameters 5415
#define sipName_setDiffieHellmanParameters &sipStrings_QtNetwork[5415]
#define sipNameNr_setMaximumRedirectsAllowed 5442
#define sipName_setMaximumRedirectsAllowed &sipStrings_QtNetwork[5442]
#define sipNameNr_setStreamReceiveWindowSize 5469
#define sipName_setStreamReceiveWindowSize &sipStrings_QtNetwork[5469]
#define sipNameNr_startedEncryptionHandshake 5496
#define sipName_startedEncryptionHandshake &sipStrings_QtNetwork[5496]
#define sipNameNr_AccessControlAllowHeaders 5523
#define sipName_AccessControlAllowHeaders &sipStrings_QtNetwork[5523]
#define sipNameNr_AccessControlAllowMethods 5549
#define sipName_AccessControlAllowMethods &sipStrings_QtNetwork[5549]
#define sipNameNr_CacheLoadControlAttribute 5575
#define sipName_CacheLoadControlAttribute &sipStrings_QtNetwork[5575]
#define sipNameNr_CacheSaveControlAttribute 5601
#define sipName_CacheSaveControlAttribute &sipStrings_QtNetwork[5601]
#define sipNameNr_ConvertUnspecifiedAddress 5627
#define sipName_ConvertUnspecifiedAddress &sipStrings_QtNetwork[5627]
#define sipNameNr_CrossOriginEmbedderPolicy 5653
#define sipName_CrossOriginEmbedderPolicy &sipStrings_QtNetwork[5653]
#define sipNameNr_CrossOriginResourcePolicy 5679
#define sipName_CrossOriginResourcePolicy &sipStrings_QtNetwork[5679]
#define sipNameNr_HttpReasonPhraseAttribute 5705
#define sipName_HttpReasonPhraseAttribute &sipStrings_QtNetwork[5705]
#define sipNameNr_NetworkSessionFailedError 5731
#define sipName_NetworkSessionFailedError &sipStrings_QtNetwork[5731]
#define sipNameNr_OcspResponseCertIdUnknown 5757
#define sipName_OcspResponseCertIdUnknown &sipStrings_QtNetwork[5757]
#define sipNameNr_QAbstractSocket__BindFlag 5783
#define sipName_QAbstractSocket__BindFlag &sipStrings_QtNetwork[5783]
#define sipNameNr_5809 5809
#define sipName_5809 &sipStrings_QtNetwork[5809]
#define sipNameNr_QNetworkProxy__Capability 5835
#define sipName_QNetworkProxy__Capability &sipStrings_QtNetwork[5835]
#define sipNameNr_QNetworkRequest__Priority 5861
#define sipName_QNetworkRequest__Priority &sipStrings_QtNetwork[5861]
#define sipNameNr_huffmanCompressionEnabled 5887
#define sipName_huffmanCompressionEnabled &sipStrings_QtNetwork[5887]
#define sipNameNr_maximumPreSharedKeyLength 5913
#define sipName_maximumPreSharedKeyLength &sipStrings_QtNetwork[5913]
#define sipNameNr_missingCertificateIsFatal 5939
#define sipName_missingCertificateIsFatal &sipStrings_QtNetwork[5939]
#define sipNameNr_nameserverProtocolChanged 5965
#define sipName_nameserverProtocolChanged &sipStrings_QtNetwork[5965]
#define sipNameNr_sessionTicketLifeTimeHint 5991
#define sipName_sessionTicketLifeTimeHint &sipStrings_QtNetwork[5991]
#define sipNameNr_setTcpKeepAliveProbeCount 6017
#define sipName_setTcpKeepAliveProbeCount &sipStrings_QtNetwork[6017]
#define sipNameNr_setUseSystemConfiguration 6043
#define sipName_setUseSystemConfiguration &sipStrings_QtNetwork[6043]
#define sipNameNr_AccessControlAllowOrigin 6069
#define sipName_AccessControlAllowOrigin &sipStrings_QtNetwork[6069]
#define sipNameNr_AlternativeNameEntryType 2688
#define sipName_AlternativeNameEntryType &sipStrings_QtNetwork[2688]
#define sipNameNr_CertificateStatusUnknown 6094
#define sipName_CertificateStatusUnknown &sipStrings_QtNetwork[6094]
#define sipNameNr_ContentDispositionHeader 6119
#define sipName_ContentDispositionHeader &sipStrings_QtNetwork[6119]
#define sipNameNr_HostNameLookupCapability 6144
#define sipName_HostNameLookupCapability &sipStrings_QtNetwork[6144]
#define sipNameNr_NoLessSafeRedirectPolicy 6169
#define sipName_NoLessSafeRedirectPolicy &sipStrings_QtNetwork[6169]
#define sipNameNr_QDnsTlsAssociationRecord 6194
#define sipName_QDnsTlsAssociationRecord &sipStrings_QtNetwork[6194]
#define sipNameNr_QFormDataBuilder__Option 6219
#define sipName_QFormDataBuilder__Option &sipStrings_QtNetwork[6219]
#define sipNameNr_QHostInfo__HostInfoError 6244
#define sipName_QHostInfo__HostInfoError &sipStrings_QtNetwork[6244]
#define sipNameNr_6269 6269
#define sipName_6269 &sipStrings_QtNetwork[6269]
#define sipNameNr_6294 6294
#define sipName_6294 &sipStrings_QtNetwork[6294]
#define sipNameNr_6319 6319
#define sipName_6319 &sipStrings_QtNetwork[6319]
#define sipNameNr_6344 6344
#define sipName_6344 &sipStrings_QtNetwork[6344]
#define sipNameNr_QNetworkCookie__SameSite 6369
#define sipName_QNetworkCookie__SameSite &sipStrings_QtNetwork[6369]
#define sipNameNr_QNetworkProxy__ProxyType 6394
#define sipName_QNetworkProxy__ProxyType &sipStrings_QtNetwork[6394]
#define sipNameNr_QSslCertificateExtension 6419
#define sipName_QSslCertificateExtension &sipStrings_QtNetwork[6419]
#define sipNameNr_SameOriginRedirectPolicy 6444
#define sipName_SameOriginRedirectPolicy &sipStrings_QtNetwork[6444]
#define sipNameNr_defaultDtlsConfiguration 6469
#define sipName_defaultDtlsConfiguration &sipStrings_QtNetwork[6469]
#define sipNameNr_newSessionTicketReceived 6494
#define sipName_newSessionTicketReceived &sipStrings_QtNetwork[6494]
#define sipNameNr_preSharedKeyIdentityHint 6519
#define sipName_preSharedKeyIdentityHint &sipStrings_QtNetwork[6519]
#define sipNameNr_sessionReceiveWindowSize 6544
#define sipName_sessionReceiveWindowSize &sipStrings_QtNetwork[6544]
#define sipNameNr_setLocalCertificateChain 6569
#define sipName_setLocalCertificateChain &sipStrings_QtNetwork[6569]
#define sipNameNr_setMaxPendingConnections 6594
#define sipName_setMaxPendingConnections &sipStrings_QtNetwork[6594]
#define sipNameNr_6619 6619
#define sipName_6619 &sipStrings_QtNetwork[6619]
#define sipNameNr_AbstractNamespaceOption 6644
#define sipName_AbstractNamespaceOption &sipStrings_QtNetwork[6644]
#define sipNameNr_BadCertificateHashValue 6668
#define sipName_BadCertificateHashValue &sipStrings_QtNetwork[6668]
#define sipNameNr_CertificateUnobtainable 6692
#define sipName_CertificateUnobtainable &sipStrings_QtNetwork[6692]
#define sipNameNr_CertificateVerification 6716
#define sipName_CertificateVerification &sipStrings_QtNetwork[6716]
#define sipNameNr_CrossOriginOpenerPolicy 6740
#define sipName_CrossOriginOpenerPolicy &sipStrings_QtNetwork[6740]
#define sipNameNr_DomainIssuedCertificate 6764
#define sipName_DomainIssuedCertificate &sipStrings_QtNetwork[6764]
#define sipNameNr_HttpStatusCodeAttribute 6788
#define sipName_HttpStatusCodeAttribute &sipStrings_QtNetwork[6788]
#define sipNameNr_KeepAliveIntervalOption 6812
#define sipName_KeepAliveIntervalOption &sipStrings_QtNetwork[6812]
#define sipNameNr_MulticastLoopbackOption 6836
#define sipName_MulticastLoopbackOption &sipStrings_QtNetwork[6836]
#define sipNameNr_OperationCancelledError 6860
#define sipName_OperationCancelledError &sipStrings_QtNetwork[6860]
#define sipNameNr_OptionalWWWAuthenticate 6884
#define sipName_OptionalWWWAuthenticate &sipStrings_QtNetwork[6884]
#define sipNameNr_ProxyAuthenticationInfo 6908
#define sipName_ProxyAuthenticationInfo &sipStrings_QtNetwork[6908]
#define sipNameNr_PublicKeyPinsReportOnly 6932
#define sipName_PublicKeyPinsReportOnly &sipStrings_QtNetwork[6932]
#define sipNameNr_PyQt6_sip_simplewrapper 6956
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtNetwork[6956]
#define sipNameNr_6980 6980
#define sipName_6980 &sipStrings_QtNetwork[6980]
#define sipNameNr_QHstsPolicy__PolicyFlag 7004
#define sipName_QHstsPolicy__PolicyFlag &sipStrings_QtNetwork[7004]
#define sipNameNr_QNetworkCookie__RawForm 7028
#define sipName_QNetworkCookie__RawForm &sipStrings_QtNetwork[7028]
#define sipNameNr_RedirectPolicyAttribute 7052
#define sipName_RedirectPolicyAttribute &sipStrings_QtNetwork[7052]
#define sipNameNr_SctpListeningCapability 7076
#define sipName_SctpListeningCapability &sipStrings_QtNetwork[7076]
#define sipNameNr_SctpTunnelingCapability 7100
#define sipName_SctpTunnelingCapability &sipStrings_QtNetwork[7100]
#define sipNameNr_ServiceUnavailableError 7124
#define sipName_ServiceUnavailableError &sipStrings_QtNetwork[7124]
#define sipNameNr_SslHandshakeFailedError 7148
#define sipName_SslHandshakeFailedError &sipStrings_QtNetwork[7148]
#define sipNameNr_SslInvalidUserDataError 7172
#define sipName_SslInvalidUserDataError &sipStrings_QtNetwork[7172]
#define sipNameNr_StrictTransportSecurity 7196
#define sipName_StrictTransportSecurity &sipStrings_QtNetwork[7196]
#define sipNameNr_TransferTimeoutConstant 413
#define sipName_TransferTimeoutConstant &sipStrings_QtNetwork[413]
#define sipNameNr_UseCredentialsAttribute 7220
#define sipName_UseCredentialsAttribute &sipStrings_QtNetwork[7220]
#define sipNameNr_diffieHellmanParameters 7244
#define sipName_diffieHellmanParameters &sipStrings_QtNetwork[7244]
#define sipNameNr_encryptedBytesAvailable 7268
#define sipName_encryptedBytesAvailable &sipStrings_QtNetwork[7268]
#define sipNameNr_maximumRedirectsAllowed 7292
#define sipName_maximumRedirectsAllowed &sipStrings_QtNetwork[7292]
#define sipNameNr_maximumTransmissionUnit 7316
#define sipName_maximumTransmissionUnit &sipStrings_QtNetwork[7316]
#define sipNameNr_setAllowedNextProtocols 7340
#define sipName_setAllowedNextProtocols &sipStrings_QtNetwork[7340]
#define sipNameNr_setBackendConfiguration 7364
#define sipName_setBackendConfiguration &sipStrings_QtNetwork[7364]
#define sipNameNr_setDefaultConfiguration 7388
#define sipName_setDefaultConfiguration &sipStrings_QtNetwork[7388]
#define sipNameNr_setMaxConcurrentStreams 7412
#define sipName_setMaxConcurrentStreams &sipStrings_QtNetwork[7412]
#define sipNameNr_socketStartedConnecting 7436
#define sipName_socketStartedConnecting &sipStrings_QtNetwork[7436]
#define sipNameNr_sslLibraryVersionNumber 7460
#define sipName_sslLibraryVersionNumber &sipStrings_QtNetwork[7460]
#define sipNameNr_sslLibraryVersionString 7484
#define sipName_sslLibraryVersionString &sipStrings_QtNetwork[7484]
#define sipNameNr_streamReceiveWindowSize 7508
#define sipName_streamReceiveWindowSize &sipStrings_QtNetwork[7508]
#define sipNameNr_subjectAlternativeNames 7532
#define sipName_subjectAlternativeNames &sipStrings_QtNetwork[7532]
#define sipNameNr_supportedEllipticCurves 7556
#define sipName_supportedEllipticCurves &sipStrings_QtNetwork[7556]
#define sipNameNr_usesSystemConfiguration 7580
#define sipName_usesSystemConfiguration &sipStrings_QtNetwork[7580]
#define sipNameNr_CertificateBlacklisted 7604
#define sipName_CertificateBlacklisted &sipStrings_QtNetwork[7604]
#define sipNameNr_CertificateNotYetValid 7627
#define sipName_CertificateNotYetValid &sipStrings_QtNetwork[7627]
#define sipNameNr_ConnectionRefusedError 4405
#define sipName_ConnectionRefusedError &sipStrings_QtNetwork[4405]
#define sipNameNr_DefaultTransferTimeout 7650
#define sipName_DefaultTransferTimeout &sipStrings_QtNetwork[7650]
#define sipNameNr_OperationCanceledError 7673
#define sipName_OperationCanceledError &sipStrings_QtNetwork[7673]
#define sipNameNr_OrganizationalUnitName 7696
#define sipName_OrganizationalUnitName &sipStrings_QtNetwork[7696]
#define sipNameNr_QDnsMailExchangeRecord 7719
#define sipName_QDnsMailExchangeRecord &sipStrings_QtNetwork[7719]
#define sipNameNr_7742 7742
#define sipName_7742 &sipStrings_QtNetwork[7742]
#define sipNameNr_QNetworkRequestFactory 7765
#define sipName_QNetworkRequestFactory &sipStrings_QtNetwork[7765]
#define sipNameNr_QOcspCertificateStatus 7788
#define sipName_QOcspCertificateStatus &sipStrings_QtNetwork[7788]
#define sipNameNr_QSsl__ImplementedClass 7811
#define sipName_QSsl__ImplementedClass &sipStrings_QtNetwork[7811]
#define sipNameNr_QSsl__SupportedFeature 7834
#define sipName_QSsl__SupportedFeature &sipStrings_QtNetwork[7834]
#define sipNameNr_SecWebSocketExtensions 7857
#define sipName_SecWebSocketExtensions &sipStrings_QtNetwork[7857]
#define sipNameNr_UdpTunnelingCapability 7880
#define sipName_UdpTunnelingCapability &sipStrings_QtNetwork[7880]
#define sipNameNr_UnsupportedCertificate 7903
#define sipName_UnsupportedCertificate &sipStrings_QtNetwork[7903]
#define sipNameNr_authenticationRequired 7926
#define sipName_authenticationRequired &sipStrings_QtNetwork[7926]
#define sipNameNr_connectToHostEncrypted 7949
#define sipName_connectToHostEncrypted &sipStrings_QtNetwork[7949]
#define sipNameNr_defaultPortForProtocol 7972
#define sipName_defaultPortForProtocol &sipStrings_QtNetwork[7972]
#define sipNameNr_interfaceIndexFromName 7995
#define sipName_interfaceIndexFromName &sipStrings_QtNetwork[7995]
#define sipNameNr_interfaceNameFromIndex 8018
#define sipName_interfaceNameFromIndex &sipStrings_QtNetwork[8018]
#define sipNameNr_nextNegotiatedProtocol 8041
#define sipName_nextNegotiatedProtocol &sipStrings_QtNetwork[8041]
#define sipNameNr_setOcspStaplingEnabled 8064
#define sipName_setOcspStaplingEnabled &sipStrings_QtNetwork[8064]
#define sipNameNr_tcpKeepAliveProbeCount 8087
#define sipName_tcpKeepAliveProbeCount &sipStrings_QtNetwork[8087]
#define sipNameNr_transportMediumChanged 8110
#define sipName_transportMediumChanged &sipStrings_QtNetwork[8110]
#define sipNameNr_AuthenticationControl 8133
#define sipName_AuthenticationControl &sipStrings_QtNetwork[8133]
#define sipNameNr_ContentSecurityPolicy 8155
#define sipName_ContentSecurityPolicy &sipStrings_QtNetwork[8155]
#define sipNameNr_ConvertV4CompatToIPv4 8177
#define sipName_ConvertV4CompatToIPv4 &sipStrings_QtNetwork[8177]
#define sipNameNr_ConvertV4MappedToIPv4 8199
#define sipName_ConvertV4MappedToIPv4 &sipStrings_QtNetwork[8199]
#define sipNameNr_DatagramTooLargeError 8221
#define sipName_DatagramTooLargeError &sipStrings_QtNetwork[8221]
#define sipNameNr_DnsEligibilityUnknown 8243
#define sipName_DnsEligibilityUnknown &sipStrings_QtNetwork[8243]
#define sipNameNr_Http2AllowedAttribute 8265
#define sipName_Http2AllowedAttribute &sipStrings_QtNetwork[8265]
#define sipNameNr_Http2WasUsedAttribute 8287
#define sipName_Http2WasUsedAttribute &sipStrings_QtNetwork[8287]
#define sipNameNr_IfModifiedSinceHeader 8309
#define sipName_IfModifiedSinceHeader &sipStrings_QtNetwork[8309]
#define sipNameNr_InappropriateFallback 8331
#define sipName_InappropriateFallback &sipStrings_QtNetwork[8331]
#define sipNameNr_InsecureRedirectError 8353
#define sipName_InsecureRedirectError &sipStrings_QtNetwork[8353]
#define sipNameNr_InvalidInputDataError 8375
#define sipName_InvalidInputDataError &sipStrings_QtNetwork[8375]
#define sipNameNr_InvalidNotBeforeField 8397
#define sipName_InvalidNotBeforeField &sipStrings_QtNetwork[8397]
#define sipNameNr_NoApplicationProtocol 8419
#define sipName_NoApplicationProtocol &sipStrings_QtNetwork[8419]
#define sipNameNr_OcspMalformedResponse 8441
#define sipName_OcspMalformedResponse &sipStrings_QtNetwork[8441]
#define sipNameNr_QAbstractNetworkCache 8463
#define sipName_QAbstractNetworkCache &sipStrings_QtNetwork[8463]
#define sipNameNr_QDnsHostAddressRecord 8485
#define sipName_QDnsHostAddressRecord &sipStrings_QtNetwork[8485]
#define sipNameNr_8507 8507
#define sipName_8507 &sipStrings_QtNetwork[8507]
#define sipNameNr_8529 8529
#define sipName_8529 &sipStrings_QtNetwork[8529]
#define sipNameNr_QNetworkAccessManager 8551
#define sipName_QNetworkAccessManager &sipStrings_QtNetwork[8551]
#define sipNameNr_QNetworkCacheMetaData 8573
#define sipName_QNetworkCacheMetaData &sipStrings_QtNetwork[8573]
#define sipNameNr_QOcspRevocationReason 8595
#define sipName_QOcspRevocationReason &sipStrings_QtNetwork[8595]
#define sipNameNr_RemoteHostClosedError 8617
#define sipName_RemoteHostClosedError &sipStrings_QtNetwork[8617]
#define sipNameNr_SelfSignedCertificate 8639
#define sipName_SelfSignedCertificate &sipStrings_QtNetwork[8639]
#define sipNameNr_SubjectIssuerMismatch 8661
#define sipName_SubjectIssuerMismatch &sipStrings_QtNetwork[8661]
#define sipNameNr_TooManyRedirectsError 8683
#define sipName_TooManyRedirectsError &sipStrings_QtNetwork[8683]
#define sipNameNr_UnsafeParametersError 8705
#define sipName_UnsafeParametersError &sipStrings_QtNetwork[8705]
#define sipNameNr_encryptedBytesToWrite 8727
#define sipName_encryptedBytesToWrite &sipStrings_QtNetwork[8727]
#define sipNameNr_encryptedBytesWritten 8749
#define sipName_encryptedBytesWritten &sipStrings_QtNetwork[8749]
#define sipNameNr_hasPendingConnections 8771
#define sipName_hasPendingConnections &sipStrings_QtNetwork[8771]
#define sipNameNr_isBehindCaptivePortal 8793
#define sipName_isBehindCaptivePortal &sipStrings_QtNetwork[8793]
#define sipNameNr_loadBackendByFeatures 8815
#define sipName_loadBackendByFeatures &sipStrings_QtNetwork[8815]
#define sipNameNr_localCertificateChain 8837
#define sipName_localCertificateChain &sipStrings_QtNetwork[8837]
#define sipNameNr_maxPendingConnections 8859
#define sipName_maxPendingConnections &sipStrings_QtNetwork[8859]
#define sipNameNr_maximumIdentityLength 8881
#define sipName_maximumIdentityLength &sipStrings_QtNetwork[8881]
#define sipNameNr_nameserverPortChanged 8903
#define sipName_nameserverPortChanged &sipStrings_QtNetwork[8903]
#define sipNameNr_nextPendingConnection 8925
#define sipName_nextPendingConnection &sipStrings_QtNetwork[8925]
#define sipNameNr_setHttp1Configuration 8947
#define sipName_setHttp1Configuration &sipStrings_QtNetwork[8947]
#define sipNameNr_setHttp2Configuration 8969
#define sipName_setHttp2Configuration &sipStrings_QtNetwork[8969]
#define sipNameNr_setIncludesSubDomains 8991
#define sipName_setIncludesSubDomains &sipStrings_QtNetwork[8991]
#define sipNameNr_setMulticastInterface 9013
#define sipName_setMulticastInterface &sipStrings_QtNetwork[9013]
#define sipNameNr_setNameserverProtocol 9035
#define sipName_setNameserverProtocol &sipStrings_QtNetwork[9035]
#define sipNameNr_startClientEncryption 9057
#define sipName_startClientEncryption &sipStrings_QtNetwork[9057]
#define sipNameNr_startServerEncryption 9079
#define sipName_startServerEncryption &sipStrings_QtNetwork[9079]
#define sipNameNr_subjectInfoAttributes 9101
#define sipName_subjectInfoAttributes &sipStrings_QtNetwork[9101]
#define sipNameNr_tlsAssociationRecords 9123
#define sipName_tlsAssociationRecords &sipStrings_QtNetwork[9123]
#define sipNameNr_CertificateUntrusted 9145
#define sipName_CertificateUntrusted &sipStrings_QtNetwork[9145]
#define sipNameNr_CessationOfOperation 9166
#define sipName_CessationOfOperation &sipStrings_QtNetwork[9166]
#define sipNameNr_ContentConflictError 9187
#define sipName_ContentConflictError &sipStrings_QtNetwork[9187]
#define sipNameNr_ContentNotFoundError 9208
#define sipName_ContentNotFoundError &sipStrings_QtNetwork[9208]
#define sipNameNr_DecompressionFailure 9229
#define sipName_DecompressionFailure &sipStrings_QtNetwork[9229]
#define sipNameNr_DnsEligibilityStatus 252
#define sipName_DnsEligibilityStatus &sipStrings_QtNetwork[252]
#define sipNameNr_Http2DirectAttribute 9250
#define sipName_Http2DirectAttribute &sipStrings_QtNetwork[9250]
#define sipNameNr_InsufficientSecurity 9271
#define sipName_InsufficientSecurity &sipStrings_QtNetwork[9271]
#define sipNameNr_InvalidCaCertificate 9292
#define sipName_InvalidCaCertificate &sipStrings_QtNetwork[9292]
#define sipNameNr_InvalidNotAfterField 9313
#define sipName_InvalidNotAfterField &sipStrings_QtNetwork[9313]
#define sipNameNr_KeepAliveCountOption 9334
#define sipName_KeepAliveCountOption &sipStrings_QtNetwork[9334]
#define sipNameNr_ManualRedirectPolicy 9355
#define sipName_ManualRedirectPolicy &sipStrings_QtNetwork[9355]
#define sipNameNr_NetworkLayerProtocol 570
#define sipName_NetworkLayerProtocol &sipStrings_QtNetwork[570]
#define sipNameNr_OcspMalformedRequest 9376
#define sipName_OcspMalformedRequest &sipStrings_QtNetwork[9376]
#define sipNameNr_ProtocolUnknownError 9397
#define sipName_ProtocolUnknownError &sipStrings_QtNetwork[9397]
#define sipNameNr_QDnsDomainNameRecord 9418
#define sipName_QDnsDomainNameRecord &sipStrings_QtNetwork[9418]
#define sipNameNr_QDnsLookup__Protocol 9439
#define sipName_QDnsLookup__Protocol &sipStrings_QtNetwork[9439]
#define sipNameNr_QFormDataPartBuilder 9460
#define sipName_QFormDataPartBuilder &sipStrings_QtNetwork[9460]
#define sipNameNr_9481 9481
#define sipName_9481 &sipStrings_QtNetwork[9481]
#define sipNameNr_9502 9502
#define sipName_9502 &sipStrings_QtNetwork[9502]
#define sipNameNr_QNetworkAddressEntry 9523
#define sipName_QNetworkAddressEntry &sipStrings_QtNetwork[9523]
#define sipNameNr_QNetworkProxyFactory 9544
#define sipName_QNetworkProxyFactory &sipStrings_QtNetwork[9544]
#define sipNameNr_QSsl__EncodingFormat 9565
#define sipName_QSsl__EncodingFormat &sipStrings_QtNetwork[9565]
#define sipNameNr_SecWebSocketProtocol 9586
#define sipName_SecWebSocketProtocol &sipStrings_QtNetwork[9586]
#define sipNameNr_SubjectPublicKeyInfo 9607
#define sipName_SubjectPublicKeyInfo &sipStrings_QtNetwork[9607]
#define sipNameNr_TrustAnchorAssertion 9628
#define sipName_TrustAnchorAssertion &sipStrings_QtNetwork[9628]
#define sipNameNr_UnsupportedExtension 9649
#define sipName_UnsupportedExtension &sipStrings_QtNetwork[9649]
#define sipNameNr_addPendingConnection 9670
#define sipName_addPendingConnection &sipStrings_QtNetwork[9670]
#define sipNameNr_allowedNextProtocols 9691
#define sipName_allowedNextProtocols &sipStrings_QtNetwork[9691]
#define sipNameNr_authenticationMethod 9712
#define sipName_authenticationMethod &sipStrings_QtNetwork[9712]
#define sipNameNr_backendConfiguration 9733
#define sipName_backendConfiguration &sipStrings_QtNetwork[9733]
#define sipNameNr_canonicalNameRecords 9754
#define sipName_canonicalNameRecords &sipStrings_QtNetwork[9754]
#define sipNameNr_clearAddressLifetime 9775
#define sipName_clearAddressLifetime &sipStrings_QtNetwork[9775]
#define sipNameNr_clearConnectionCache 9796
#define sipName_clearConnectionCache &sipStrings_QtNetwork[9796]
#define sipNameNr_clearQueryParameters 9817
#define sipName_clearQueryParameters &sipStrings_QtNetwork[9817]
#define sipNameNr_defaultConfiguration 9838
#define sipName_defaultConfiguration &sipStrings_QtNetwork[9838]
#define sipNameNr_disconnectFromServer 9859
#define sipName_disconnectFromServer &sipStrings_QtNetwork[9859]
#define sipNameNr_isUniqueLocalUnicast 9880
#define sipName_isUniqueLocalUnicast &sipStrings_QtNetwork[9880]
#define sipNameNr_issuerInfoAttributes 9901
#define sipName_issuerInfoAttributes &sipStrings_QtNetwork[9901]
#define sipNameNr_maxConcurrentStreams 9922
#define sipName_maxConcurrentStreams &sipStrings_QtNetwork[9922]
#define sipNameNr_networkAccessManager 9943
#define sipName_networkAccessManager &sipStrings_QtNetwork[9943]
#define sipNameNr_peerCertificateChain 9964
#define sipName_peerCertificateChain &sipStrings_QtNetwork[9964]
#define sipNameNr_setAutoDeleteReplies 9985
#define sipName_setAutoDeleteReplies &sipStrings_QtNetwork[9985]
#define sipNameNr_setListenBacklogSize 10006
#define sipName_setListenBacklogSize &sipStrings_QtNetwork[10006]
#define sipNameNr_setOriginatingObject 10027
#define sipName_setOriginatingObject &sipStrings_QtNetwork[10027]
#define sipNameNr_setServerPushEnabled 10048
#define sipName_setServerPushEnabled &sipStrings_QtNetwork[10048]
#define sipNameNr_systemCaCertificates 10069
#define sipName_systemCaCertificates &sipStrings_QtNetwork[10069]
#define sipNameNr_waitForNewConnection 10090
#define sipName_waitForNewConnection &sipStrings_QtNetwork[10090]
#define sipNameNr_AccessControlMaxAge 10111
#define sipName_AccessControlMaxAge &sipStrings_QtNetwork[10111]
#define sipNameNr_CertificateRejected 10131
#define sipName_CertificateRejected &sipStrings_QtNetwork[10131]
#define sipNameNr_CertificateRequired 10151
#define sipName_CertificateRequired &sipStrings_QtNetwork[10151]
#define sipNameNr_ContentAccessDenied 10171
#define sipName_ContentAccessDenied &sipStrings_QtNetwork[10171]
#define sipNameNr_ContentLengthHeader 10191
#define sipName_ContentLengthHeader &sipStrings_QtNetwork[10191]
#define sipNameNr_CustomVerbAttribute 10211
#define sipName_CustomVerbAttribute &sipStrings_QtNetwork[10211]
#define sipNameNr_InternalServerError 10231
#define sipName_InternalServerError &sipStrings_QtNetwork[10231]
#define sipNameNr_InvalidRequestError 10251
#define sipName_InvalidRequestError &sipStrings_QtNetwork[10251]
#define sipNameNr_KeepAliveIdleOption 10271
#define sipName_KeepAliveIdleOption &sipStrings_QtNetwork[10271]
#define sipNameNr_ListeningCapability 7080
#define sipName_ListeningCapability &sipStrings_QtNetwork[7080]
#define sipNameNr_NextProtocolHttp1_1 10291
#define sipName_NextProtocolHttp1_1 &sipStrings_QtNetwork[10291]
#define sipNameNr_OcspNoResponseFound 10311
#define sipName_OcspNoResponseFound &sipStrings_QtNetwork[10311]
#define sipNameNr_OcspResponseExpired 10331
#define sipName_OcspResponseExpired &sipStrings_QtNetwork[10331]
#define sipNameNr_PathMtuSocketOption 10351
#define sipName_PathMtuSocketOption &sipStrings_QtNetwork[10351]
#define sipNameNr_QHttp1Configuration 10371
#define sipName_QHttp1Configuration &sipStrings_QtNetwork[10371]
#define sipNameNr_QHttp2Configuration 10391
#define sipName_QHttp2Configuration &sipStrings_QtNetwork[10391]
#define sipNameNr_10411 10411
#define sipName_10411 &sipStrings_QtNetwork[10411]
#define sipNameNr_QNetworkInformation 10431
#define sipName_QNetworkInformation &sipStrings_QtNetwork[10431]
#define sipNameNr_QSslError__SslError 10451
#define sipName_QSslError__SslError &sipStrings_QtNetwork[10451]
#define sipNameNr_QSslSocket__SslMode 10471
#define sipName_QSslSocket__SslMode &sipStrings_QtNetwork[10471]
#define sipNameNr_SecWebSocketVersion 10491
#define sipName_SecWebSocketVersion &sipStrings_QtNetwork[10491]
#define sipNameNr_ServerNotFoundError 10511
#define sipName_ServerNotFoundError &sipStrings_QtNetwork[10511]
#define sipNameNr_SocketResourceError 10531
#define sipName_SocketResourceError &sipStrings_QtNetwork[10531]
#define sipNameNr_StateOrProvinceName 10551
#define sipName_StateOrProvinceName &sipStrings_QtNetwork[10551]
#define sipNameNr_SurrogateCapability 10571
#define sipName_SurrogateCapability &sipStrings_QtNetwork[10571]
#define sipNameNr_TunnelingCapability 7104
#define sipName_TunnelingCapability &sipStrings_QtNetwork[7104]
#define sipNameNr_TypeOfServiceOption 10591
#define sipName_TypeOfServiceOption &sipStrings_QtNetwork[10591]
#define sipNameNr_UnknownAlertMessage 10611
#define sipName_UnknownAlertMessage &sipStrings_QtNetwork[10611]
#define sipNameNr_UnknownContentError 10631
#define sipName_UnknownContentError &sipStrings_QtNetwork[10631]
#define sipNameNr_UnknownNetworkError 10651
#define sipName_UnknownNetworkError &sipStrings_QtNetwork[10651]
#define sipNameNr_XContentTypeOptions 10671
#define sipName_XContentTypeOptions &sipStrings_QtNetwork[10671]
#define sipNameNr_hasPendingDatagrams 10691
#define sipName_hasPendingDatagrams &sipStrings_QtNetwork[10691]
#define sipNameNr_isHttpStatusSuccess 10711
#define sipName_isHttpStatusSuccess &sipStrings_QtNetwork[10711]
#define sipNameNr_isProtocolSupported 10731
#define sipName_isProtocolSupported &sipStrings_QtNetwork[10731]
#define sipNameNr_leaveMulticastGroup 10751
#define sipName_leaveMulticastGroup &sipStrings_QtNetwork[10751]
#define sipNameNr_mailExchangeRecords 10771
#define sipName_mailExchangeRecords &sipStrings_QtNetwork[10771]
#define sipNameNr_ocspStaplingEnabled 10791
#define sipName_ocspStaplingEnabled &sipStrings_QtNetwork[10791]
#define sipNameNr_pendingDatagramSize 10811
#define sipName_pendingDatagramSize &sipStrings_QtNetwork[10811]
#define sipNameNr_reachabilityChanged 10831
#define sipName_reachabilityChanged &sipStrings_QtNetwork[10831]
#define sipNameNr_setApplicationProxy 10851
#define sipName_setApplicationProxy &sipStrings_QtNetwork[10851]
#define sipNameNr_setHandshakeTimeout 10871
#define sipName_setHandshakeTimeout &sipStrings_QtNetwork[10871]
#define sipNameNr_setLocalCertificate 10891
#define sipName_setLocalCertificate &sipStrings_QtNetwork[10891]
#define sipNameNr_setMaximumCacheSize 10911
#define sipName_setMaximumCacheSize &sipStrings_QtNetwork[10911]
#define sipNameNr_setSocketDescriptor 10931
#define sipName_setSocketDescriptor &sipStrings_QtNetwork[10931]
#define sipNameNr_setSslConfiguration 10951
#define sipName_setSslConfiguration &sipStrings_QtNetwork[10951]
#define sipNameNr_systemProxyForQuery 10971
#define sipName_systemProxyForQuery &sipStrings_QtNetwork[10971]
#define sipNameNr_waitForBytesWritten 10991
#define sipName_waitForBytesWritten &sipStrings_QtNetwork[10991]
#define sipNameNr_waitForDisconnected 11011
#define sipName_waitForDisconnected &sipStrings_QtNetwork[11011]
#define sipNameNr_wellKnownHeaderName 11031
#define sipName_wellKnownHeaderName &sipStrings_QtNetwork[11031]
#define sipNameNr_AffiliationChanged 11051
#define sipName_AffiliationChanged &sipStrings_QtNetwork[11051]
#define sipNameNr_ApplyToRedirectRef 11070
#define sipName_ApplyToRedirectRef &sipStrings_QtNetwork[11070]
#define sipNameNr_AuthenticationInfo 6913
#define sipName_AuthenticationInfo &sipStrings_QtNetwork[6913]
#define sipNameNr_CertificateExpired 11089
#define sipName_CertificateExpired &sipStrings_QtNetwork[11089]
#define sipNameNr_CertificateRevoked 11108
#define sipName_CertificateRevoked &sipStrings_QtNetwork[11108]
#define sipNameNr_CertificateUnknown 11127
#define sipName_CertificateUnknown &sipStrings_QtNetwork[11127]
#define sipNameNr_ContentDisposition 11146
#define sipName_ContentDisposition &sipStrings_QtNetwork[11146]
#define sipNameNr_ContentReSendError 11165
#define sipName_ContentReSendError &sipStrings_QtNetwork[11165]
#define sipNameNr_ConversionModeFlag 1828
#define sipName_ConversionModeFlag &sipStrings_QtNetwork[1828]
#define sipNameNr_DefaultForPlatform 11184
#define sipName_DefaultForPlatform &sipStrings_QtNetwork[11184]
#define sipNameNr_IfScheduleTagMatch 11203
#define sipName_IfScheduleTagMatch &sipStrings_QtNetwork[11203]
#define sipNameNr_LastModifiedHeader 11222
#define sipName_LastModifiedHeader &sipStrings_QtNetwork[11222]
#define sipNameNr_MulticastTtlOption 11241
#define sipName_MulticastTtlOption &sipStrings_QtNetwork[11241]
#define sipNameNr_OriginAgentCluster 11260
#define sipName_OriginAgentCluster &sipStrings_QtNetwork[11260]
#define sipNameNr_PathLengthExceeded 11279
#define sipName_PathLengthExceeded &sipStrings_QtNetwork[11279]
#define sipNameNr_ProxyAuthorization 11298
#define sipName_ProxyAuthorization &sipStrings_QtNetwork[11298]
#define sipNameNr_ProxyNotFoundError 11317
#define sipName_ProxyNotFoundError &sipStrings_QtNetwork[11317]
#define sipNameNr_ProxyProtocolError 11336
#define sipName_ProxyProtocolError &sipStrings_QtNetwork[11336]
#define sipNameNr_11355 11355
#define sipName_11355 &sipStrings_QtNetwork[11355]
#define sipNameNr_QNetworkProxyQuery 11374
#define sipName_QNetworkProxyQuery &sipStrings_QtNetwork[11374]
#define sipNameNr_QRestAccessManager 11393
#define sipName_QRestAccessManager &sipStrings_QtNetwork[11393]
#define sipNameNr_QSsl__KeyAlgorithm 11412
#define sipName_QSsl__KeyAlgorithm &sipStrings_QtNetwork[11412]
#define sipNameNr_SecWebSocketAccept 11431
#define sipName_SecWebSocketAccept &sipStrings_QtNetwork[11431]
#define sipNameNr_ServerFailureError 11450
#define sipName_ServerFailureError &sipStrings_QtNetwork[11450]
#define sipNameNr_ServerRefusedError 11469
#define sipName_ServerRefusedError &sipStrings_QtNetwork[11469]
#define sipNameNr_SocketTimeoutError 11488
#define sipName_SocketTimeoutError &sipStrings_QtNetwork[11488]
#define sipNameNr_TolerantConversion 11507
#define sipName_TolerantConversion &sipStrings_QtNetwork[11507]
#define sipNameNr_UnknownPskIdentity 11526
#define sipName_UnknownPskIdentity &sipStrings_QtNetwork[11526]
#define sipNameNr_UnknownServerError 11545
#define sipName_UnknownServerError &sipStrings_QtNetwork[11545]
#define sipNameNr_UnknownSocketError 11564
#define sipName_UnknownSocketError &sipStrings_QtNetwork[11564]
#define sipNameNr_clearCommonHeaders 11583
#define sipName_clearCommonHeaders &sipStrings_QtNetwork[11583]
#define sipNameNr_destinationAddress 11602
#define sipName_destinationAddress &sipStrings_QtNetwork[11602]
#define sipNameNr_disconnectFromHost 11621
#define sipName_disconnectFromHost &sipStrings_QtNetwork[11621]
#define sipNameNr_ephemeralServerKey 11640
#define sipName_ephemeralServerKey &sipStrings_QtNetwork[11640]
#define sipNameNr_hostAddressRecords 11659
#define sipName_hostAddressRecords &sipStrings_QtNetwork[11659]
#define sipNameNr_http1Configuration 11678
#define sipName_http1Configuration &sipStrings_QtNetwork[11678]
#define sipNameNr_http2Configuration 11697
#define sipName_http2Configuration &sipStrings_QtNetwork[11697]
#define sipNameNr_implementedClasses 11716
#define sipName_implementedClasses &sipStrings_QtNetwork[11716]
#define sipNameNr_includesSubDomains 11735
#define sipName_includesSubDomains &sipStrings_QtNetwork[11735]
#define sipNameNr_incomingConnection 11754
#define sipName_incomingConnection &sipStrings_QtNetwork[11754]
#define sipNameNr_interfaceFromIndex 11773
#define sipName_interfaceFromIndex &sipStrings_QtNetwork[11773]
#define sipNameNr_isClassImplemented 11792
#define sipName_isClassImplemented &sipStrings_QtNetwork[11792]
#define sipNameNr_isFeatureSupported 11811
#define sipName_isFeatureSupported &sipStrings_QtNetwork[11811]
#define sipNameNr_isTransparentProxy 11830
#define sipName_isTransparentProxy &sipStrings_QtNetwork[11830]
#define sipNameNr_joinMulticastGroup 11849
#define sipName_joinMulticastGroup &sipStrings_QtNetwork[11849]
#define sipNameNr_loadDefaultBackend 11868
#define sipName_loadDefaultBackend &sipStrings_QtNetwork[11868]
#define sipNameNr_multicastInterface 11887
#define sipName_multicastInterface &sipStrings_QtNetwork[11887]
#define sipNameNr_nameserverProtocol 11906
#define sipName_nameserverProtocol &sipStrings_QtNetwork[11906]
#define sipNameNr_setAddressLifetime 11925
#define sipName_setAddressLifetime &sipStrings_QtNetwork[11925]
#define sipNameNr_setPeerVerifyDepth 11944
#define sipName_setPeerVerifyDepth &sipStrings_QtNetwork[11944]
#define sipNameNr_setQueryParameters 11963
#define sipName_setQueryParameters &sipStrings_QtNetwork[11963]
#define sipNameNr_setTransferTimeout 11982
#define sipName_setTransferTimeout &sipStrings_QtNetwork[11982]
#define sipNameNr_setWellKnownHeader 12001
#define sipName_setWellKnownHeader &sipStrings_QtNetwork[12001]
#define sipNameNr_sslHandshakeErrors 12020
#define sipName_sslHandshakeErrors &sipStrings_QtNetwork[12020]
#define sipNameNr_subjectDisplayName 12039
#define sipName_subjectDisplayName &sipStrings_QtNetwork[12039]
#define sipNameNr_supportedProtocols 12058
#define sipName_supportedProtocols &sipStrings_QtNetwork[12058]
#define sipNameNr_AddressInUseError 12077
#define sipName_AddressInUseError &sipStrings_QtNetwork[12077]
#define sipNameNr_CachingCapability 12095
#define sipName_CachingCapability &sipStrings_QtNetwork[12095]
#define sipNameNr_ContentTypeHeader 12113
#define sipName_ContentTypeHeader &sipStrings_QtNetwork[12113]
#define sipNameNr_ExportRestriction 12131
#define sipName_ExportRestriction &sipStrings_QtNetwork[12131]
#define sipNameNr_GroupAccessOption 12149
#define sipName_GroupAccessOption &sipStrings_QtNetwork[12149]
#define sipNameNr_HostNotFoundError 12167
#define sipName_HostNotFoundError &sipStrings_QtNetwork[12167]
#define sipNameNr_IfNoneMatchHeader 12185
#define sipName_IfNoneMatchHeader &sipStrings_QtNetwork[12185]
#define sipNameNr_IfUnmodifiedSince 12203
#define sipName_IfUnmodifiedSince &sipStrings_QtNetwork[12203]
#define sipNameNr_IncludeSubDomains 12221
#define sipName_IncludeSubDomains &sipStrings_QtNetwork[12221]
#define sipNameNr_InvalidReplyError 12239
#define sipName_InvalidReplyError &sipStrings_QtNetwork[12239]
#define sipNameNr_NoPeerCertificate 12257
#define sipName_NoPeerCertificate &sipStrings_QtNetwork[12257]
#define sipNameNr_OcspInternalError 12275
#define sipName_OcspInternalError &sipStrings_QtNetwork[12275]
#define sipNameNr_OcspStatusUnknown 12293
#define sipName_OcspStatusUnknown &sipStrings_QtNetwork[12293]
#define sipNameNr_OtherAccessOption 12311
#define sipName_OtherAccessOption &sipStrings_QtNetwork[12311]
#define sipNameNr_PreferenceApplied 12329
#define sipName_PreferenceApplied &sipStrings_QtNetwork[12329]
#define sipNameNr_ProxyAuthenticate 12347
#define sipName_ProxyAuthenticate &sipStrings_QtNetwork[12347]
#define sipNameNr_ProxyTimeoutError 12365
#define sipName_ProxyTimeoutError &sipStrings_QtNetwork[12365]
#define sipNameNr_QDnsLookup__Error 12383
#define sipName_QDnsLookup__Error &sipStrings_QtNetwork[12383]
#define sipNameNr_QDnsServiceRecord 12401
#define sipName_QDnsServiceRecord &sipStrings_QtNetwork[12401]
#define sipNameNr_12419 12419
#define sipName_12419 &sipStrings_QtNetwork[12419]
#define sipNameNr_QNetworkCookieJar 12437
#define sipName_QNetworkCookieJar &sipStrings_QtNetwork[12437]
#define sipNameNr_QNetworkDiskCache 12455
#define sipName_QNetworkDiskCache &sipStrings_QtNetwork[12455]
#define sipNameNr_QNetworkInterface 12473
#define sipName_QNetworkInterface &sipStrings_QtNetwork[12473]
#define sipNameNr_QPasswordDigestor 12491
#define sipName_QPasswordDigestor &sipStrings_QtNetwork[12491]
#define sipNameNr_QSsl__SslProtocol 12509
#define sipName_QSsl__SslProtocol &sipStrings_QtNetwork[12509]
#define sipNameNr_QSslConfiguration 12527
#define sipName_QSslConfiguration &sipStrings_QtNetwork[12527]
#define sipNameNr_QSslEllipticCurve 12545
#define sipName_QSslEllipticCurve &sipStrings_QtNetwork[12545]
#define sipNameNr_RegularExpression 12563
#define sipName_RegularExpression &sipStrings_QtNetwork[12563]
#define sipNameNr_SocketAccessError 12581
#define sipName_SocketAccessError &sipStrings_QtNetwork[12581]
#define sipNameNr_UnexpectedMessage 12599
#define sipName_UnexpectedMessage &sipStrings_QtNetwork[12599]
#define sipNameNr_UnknownProxyError 12617
#define sipName_UnknownProxyError &sipStrings_QtNetwork[12617]
#define sipNameNr_UnknownSocketType 12635
#define sipName_UnknownSocketType &sipStrings_QtNetwork[12635]
#define sipNameNr_WantContentDigest 12653
#define sipName_WantContentDigest &sipStrings_QtNetwork[12653]
#define sipNameNr_WorldAccessOption 12671
#define sipName_WorldAccessOption &sipStrings_QtNetwork[12671]
#define sipNameNr_addCaCertificates 12689
#define sipName_addCaCertificates &sipStrings_QtNetwork[12689]
#define sipNameNr_autoDeleteReplies 12707
#define sipName_autoDeleteReplies &sipStrings_QtNetwork[12707]
#define sipNameNr_availableBackends 12725
#define sipName_availableBackends &sipStrings_QtNetwork[12725]
#define sipNameNr_certificateStatus 12743
#define sipName_certificateStatus &sipStrings_QtNetwork[12743]
#define sipNameNr_defaultParameters 12761
#define sipName_defaultParameters &sipStrings_QtNetwork[12761]
#define sipNameNr_hasSameIdentifier 12779
#define sipName_hasSameIdentifier &sipStrings_QtNetwork[12779]
#define sipNameNr_humanReadableName 12797
#define sipName_humanReadableName &sipStrings_QtNetwork[12797]
#define sipNameNr_interfaceFromName 12815
#define sipName_interfaceFromName &sipStrings_QtNetwork[12815]
#define sipNameNr_issuerDisplayName 12833
#define sipName_issuerDisplayName &sipStrings_QtNetwork[12833]
#define sipNameNr_keyExchangeMethod 12851
#define sipName_keyExchangeMethod &sipStrings_QtNetwork[12851]
#define sipNameNr_listenBacklogSize 12869
#define sipName_listenBacklogSize &sipStrings_QtNetwork[12869]
#define sipNameNr_loadBackendByName 12887
#define sipName_loadBackendByName &sipStrings_QtNetwork[12887]
#define sipNameNr_nameServerRecords 12905
#define sipName_nameServerRecords &sipStrings_QtNetwork[12905]
#define sipNameNr_nameserverChanged 12923
#define sipName_nameserverChanged &sipStrings_QtNetwork[12923]
#define sipNameNr_originatingObject 12941
#define sipName_originatingObject &sipStrings_QtNetwork[12941]
#define sipNameNr_preferredLifetime 12959
#define sipName_preferredLifetime &sipStrings_QtNetwork[12959]
#define sipNameNr_sendCustomRequest 12977
#define sipName_sendCustomRequest &sipStrings_QtNetwork[12977]
#define sipNameNr_serverPushEnabled 12995
#define sipName_serverPushEnabled &sipStrings_QtNetwork[12995]
#define sipNameNr_setCaCertificates 13013
#define sipName_setCaCertificates &sipStrings_QtNetwork[13013]
#define sipNameNr_setCacheDirectory 13031
#define sipName_setCacheDirectory &sipStrings_QtNetwork[13031]
#define sipNameNr_setCookiesFromUrl 13049
#define sipName_setCookiesFromUrl &sipStrings_QtNetwork[13049]
#define sipNameNr_setDnsEligibility 13067
#define sipName_setDnsEligibility &sipStrings_QtNetwork[13067]
#define sipNameNr_setEllipticCurves 13085
#define sipName_setEllipticCurves &sipStrings_QtNetwork[13085]
#define sipNameNr_setExpirationDate 13103
#define sipName_setExpirationDate &sipStrings_QtNetwork[13103]
#define sipNameNr_setInterfaceIndex 13121
#define sipName_setInterfaceIndex &sipStrings_QtNetwork[13121]
#define sipNameNr_setNameserverPort 13139
#define sipName_setNameserverPort &sipStrings_QtNetwork[13139]
#define sipNameNr_setPeerVerifyMode 13157
#define sipName_setPeerVerifyMode &sipStrings_QtNetwork[13157]
#define sipNameNr_setPeerVerifyName 13175
#define sipName_setPeerVerifyName &sipStrings_QtNetwork[13175]
#define sipNameNr_setReadBufferSize 13193
#define sipName_setReadBufferSize &sipStrings_QtNetwork[13193]
#define sipNameNr_setRedirectPolicy 13211
#define sipName_setRedirectPolicy &sipStrings_QtNetwork[13211]
#define sipNameNr_setSameSitePolicy 13229
#define sipName_setSameSitePolicy &sipStrings_QtNetwork[13229]
#define sipNameNr_supportedFeatures 13247
#define sipName_supportedFeatures &sipStrings_QtNetwork[13247]
#define sipNameNr_CacheLoadControl 1529
#define sipName_CacheLoadControl &sipStrings_QtNetwork[1529]
#define sipNameNr_CertificateUsage 170
#define sipName_CertificateUsage &sipStrings_QtNetwork[170]
#define sipNameNr_ContentGoneError 13265
#define sipName_ContentGoneError &sipStrings_QtNetwork[13265]
#define sipNameNr_ConvertLocalHost 13282
#define sipName_ConvertLocalHost &sipStrings_QtNetwork[13282]
#define sipNameNr_DontShareAddress 13299
#define sipName_DontShareAddress &sipStrings_QtNetwork[13299]
#define sipNameNr_HandshakeFailure 13316
#define sipName_HandshakeFailure &sipStrings_QtNetwork[13316]
#define sipNameNr_HostNameMismatch 13333
#define sipName_HostNameMismatch &sipStrings_QtNetwork[13333]
#define sipNameNr_HttpCachingProxy 13350
#define sipName_HttpCachingProxy &sipStrings_QtNetwork[13350]
#define sipNameNr_IllegalParameter 13367
#define sipName_IllegalParameter &sipStrings_QtNetwork[13367]
#define sipNameNr_ImplementedClass 7817
#define sipName_ImplementedClass &sipStrings_QtNetwork[7817]
#define sipNameNr_LocalSocketError 2634
#define sipName_LocalSocketError &sipStrings_QtNetwork[2634]
#define sipNameNr_LocalSocketState 2665
#define sipName_LocalSocketState &sipStrings_QtNetwork[2665]
#define sipNameNr_MissingExtension 13384
#define sipName_MissingExtension &sipStrings_QtNetwork[13384]
#define sipNameNr_NameAndValueOnly 13401
#define sipName_NameAndValueOnly &sipStrings_QtNetwork[13401]
#define sipNameNr_OcspUnauthorized 13418
#define sipName_OcspUnauthorized &sipStrings_QtNetwork[13418]
#define sipNameNr_PauseOnSslErrors 13435
#define sipName_PauseOnSslErrors &sipStrings_QtNetwork[13435]
#define sipNameNr_QDnsLookup__Type 13452
#define sipName_QDnsLookup__Type &sipStrings_QtNetwork[13452]
#define sipNameNr_QFormDataBuilder 13469
#define sipName_QFormDataBuilder &sipStrings_QtNetwork[13469]
#define sipNameNr_13486 13486
#define sipName_13486 &sipStrings_QtNetwork[13486]
#define sipNameNr_QNetworkDatagram 13503
#define sipName_QNetworkDatagram &sipStrings_QtNetwork[13503]
#define sipNameNr_QSsl__AlertLevel 13520
#define sipName_QSsl__AlertLevel &sipStrings_QtNetwork[13520]
#define sipNameNr_ReuseAddressHint 13537
#define sipName_ReuseAddressHint &sipStrings_QtNetwork[13537]
#define sipNameNr_SslInternalError 13554
#define sipName_SslInternalError &sipStrings_QtNetwork[13554]
#define sipNameNr_StrictConversion 13571
#define sipName_StrictConversion &sipStrings_QtNetwork[13571]
#define sipNameNr_SupportedFeature 7840
#define sipName_SupportedFeature &sipStrings_QtNetwork[7840]
#define sipNameNr_SurrogateControl 13588
#define sipName_SurrogateControl &sipStrings_QtNetwork[13588]
#define sipNameNr_TransferEncoding 13605
#define sipName_TransferEncoding &sipStrings_QtNetwork[13605]
#define sipNameNr_UnconnectedState 13622
#define sipName_UnconnectedState &sipStrings_QtNetwork[13622]
#define sipNameNr_UnrecognizedName 13639
#define sipName_UnrecognizedName &sipStrings_QtNetwork[13639]
#define sipNameNr_UnspecifiedError 13656
#define sipName_UnspecifiedError &sipStrings_QtNetwork[13656]
#define sipNameNr_UserAccessOption 13673
#define sipName_UserAccessOption &sipStrings_QtNetwork[13673]
#define sipNameNr_addCaCertificate 13690
#define sipName_addCaCertificate &sipStrings_QtNetwork[13690]
#define sipNameNr_applicationProxy 13707
#define sipName_applicationProxy &sipStrings_QtNetwork[13707]
#define sipNameNr_clearAccessCache 13724
#define sipName_clearAccessCache &sipStrings_QtNetwork[13724]
#define sipNameNr_clearBearerToken 13741
#define sipName_clearBearerToken &sipStrings_QtNetwork[13741]
#define sipNameNr_disconnectNotify 13758
#define sipName_disconnectNotify &sipStrings_QtNetwork[13758]
#define sipNameNr_downloadProgress 13775
#define sipName_downloadProgress &sipStrings_QtNetwork[13775]
#define sipNameNr_encryptionMethod 13792
#define sipName_encryptionMethod &sipStrings_QtNetwork[13792]
#define sipNameNr_handshakeTimeout 13809
#define sipName_handshakeTimeout &sipStrings_QtNetwork[13809]
#define sipNameNr_isMeteredChanged 13826
#define sipName_isMeteredChanged &sipStrings_QtNetwork[13826]
#define sipNameNr_localCertificate 13843
#define sipName_localCertificate &sipStrings_QtNetwork[13843]
#define sipNameNr_maximumCacheSize 13860
#define sipName_maximumCacheSize &sipStrings_QtNetwork[13860]
#define sipNameNr_revocationReason 13877
#define sipName_revocationReason &sipStrings_QtNetwork[13877]
#define sipNameNr_setActiveBackend 13894
#define sipName_setActiveBackend &sipStrings_QtNetwork[13894]
#define sipNameNr_setCommonHeaders 13911
#define sipName_setCommonHeaders &sipStrings_QtNetwork[13911]
#define sipNameNr_setDateTimeValue 13928
#define sipName_setDateTimeValue &sipStrings_QtNetwork[13928]
#define sipNameNr_setSessionTicket 13945
#define sipName_setSessionTicket &sipStrings_QtNetwork[13945]
#define sipNameNr_setSocketOptions 13962
#define sipName_setSocketOptions &sipStrings_QtNetwork[13962]
#define sipNameNr_socketDescriptor 13979
#define sipName_socketDescriptor &sipStrings_QtNetwork[13979]
#define sipNameNr_sslConfiguration 13996
#define sipName_sslConfiguration &sipStrings_QtNetwork[13996]
#define sipNameNr_supportedCiphers 14013
#define sipName_supportedCiphers &sipStrings_QtNetwork[14013]
#define sipNameNr_supportedSchemes 14030
#define sipName_supportedSchemes &sipStrings_QtNetwork[14030]
#define sipNameNr_validityLifetime 14047
#define sipName_validityLifetime &sipStrings_QtNetwork[14047]
#define sipNameNr_waitForConnected 14064
#define sipName_waitForConnected &sipStrings_QtNetwork[14064]
#define sipNameNr_waitForEncrypted 14081
#define sipName_waitForEncrypted &sipStrings_QtNetwork[14081]
#define sipNameNr_waitForReadyRead 14098
#define sipName_waitForReadyRead &sipStrings_QtNetwork[14098]
#define sipNameNr_AcceptAdditions 14115
#define sipName_AcceptAdditions &sipStrings_QtNetwork[14115]
#define sipNameNr_AcceptSignature 14131
#define sipName_AcceptSignature &sipStrings_QtNetwork[14131]
#define sipNameNr_AlternativeType 14147
#define sipName_AlternativeType &sipStrings_QtNetwork[14147]
#define sipNameNr_CDNCacheControl 14163
#define sipName_CDNCacheControl &sipStrings_QtNetwork[14163]
#define sipNameNr_CalDAVTimezones 14179
#define sipName_CalDAVTimezones &sipStrings_QtNetwork[14179]
#define sipNameNr_CapsuleProtocol 14195
#define sipName_CapsuleProtocol &sipStrings_QtNetwork[14195]
#define sipNameNr_CertificateHold 14211
#define sipName_CertificateHold &sipStrings_QtNetwork[14211]
#define sipNameNr_ClientCertChain 14227
#define sipName_ClientCertChain &sipStrings_QtNetwork[14227]
#define sipNameNr_ConnectingState 14243
#define sipName_ConnectingState &sipStrings_QtNetwork[14243]
#define sipNameNr_ConnectionError 14259
#define sipName_ConnectionError &sipStrings_QtNetwork[14259]
#define sipNameNr_ContentEncoding 14275
#define sipName_ContentEncoding &sipStrings_QtNetwork[14275]
#define sipNameNr_ContentLanguage 14291
#define sipName_ContentLanguage &sipStrings_QtNetwork[14291]
#define sipNameNr_ContentLocation 14307
#define sipName_ContentLocation &sipStrings_QtNetwork[14307]
#define sipNameNr_CustomOperation 14323
#define sipName_CustomOperation &sipStrings_QtNetwork[14323]
#define sipNameNr_DeleteOperation 14339
#define sipName_DeleteOperation &sipStrings_QtNetwork[14339]
#define sipNameNr_DtlsV1_0OrLater 14355
#define sipName_DtlsV1_0OrLater &sipStrings_QtNetwork[14355]
#define sipNameNr_DtlsV1_2OrLater 14371
#define sipName_DtlsV1_2OrLater &sipStrings_QtNetwork[14371]
#define sipNameNr_FtpCachingProxy 14387
#define sipName_FtpCachingProxy &sipStrings_QtNetwork[14387]
#define sipNameNr_FullCertificate 14403
#define sipName_FullCertificate &sipStrings_QtNetwork[14403]
#define sipNameNr_HostLookupState 14419
#define sipName_HostLookupState &sipStrings_QtNetwork[14419]
#define sipNameNr_IfModifiedSince 14435
#define sipName_IfModifiedSince &sipStrings_QtNetwork[14435]
#define sipNameNr_KeepAliveOption 14451
#define sipName_KeepAliveOption &sipStrings_QtNetwork[14451]
#define sipNameNr_MementoDatetime 14467
#define sipName_MementoDatetime &sipStrings_QtNetwork[14467]
#define sipNameNr_NoRenegotiation 14483
#define sipName_NoRenegotiation &sipStrings_QtNetwork[14483]
#define sipNameNr_ODataMaxVersion 14499
#define sipName_ODataMaxVersion &sipStrings_QtNetwork[14499]
#define sipNameNr_OSLCCoreVersion 14515
#define sipName_OSLCCoreVersion &sipStrings_QtNetwork[14515]
#define sipNameNr_PeerClosedError 14531
#define sipName_PeerClosedError &sipStrings_QtNetwork[14531]
#define sipNameNr_ProtocolFailure 14547
#define sipName_ProtocolFailure &sipStrings_QtNetwork[14547]
#define sipNameNr_ProtocolVersion 14563
#define sipName_ProtocolVersion &sipStrings_QtNetwork[14563]
#define sipNameNr_PyQt6_QtNetwork 14579
#define sipName_PyQt6_QtNetwork &sipStrings_QtNetwork[14579]
#define sipNameNr_QAbstractSocket 14595
#define sipName_QAbstractSocket &sipStrings_QtNetwork[14595]
#define sipNameNr_QNetworkRequest 14611
#define sipName_QNetworkRequest &sipStrings_QtNetwork[14611]
#define sipNameNr_QSsl__AlertType 14627
#define sipName_QSsl__AlertType &sipStrings_QtNetwork[14627]
#define sipNameNr_QSsl__SslOption 14643
#define sipName_QSsl__SslOption &sipStrings_QtNetwork[14643]
#define sipNameNr_QSslCertificate 14659
#define sipName_QSslCertificate &sipStrings_QtNetwork[14659]
#define sipNameNr_SecTokenBinding 14675
#define sipName_SecTokenBinding &sipStrings_QtNetwork[14675]
#define sipNameNr_SecWebSocketKey 14691
#define sipName_SecWebSocketKey &sipStrings_QtNetwork[14691]
#define sipNameNr_SecureProtocols 14707
#define sipName_SecureProtocols &sipStrings_QtNetwork[14707]
#define sipNameNr_SetCookieHeader 14723
#define sipName_SetCookieHeader &sipStrings_QtNetwork[14723]
#define sipNameNr_TransportMedium 687
#define sipName_TransportMedium &sipStrings_QtNetwork[687]
#define sipNameNr_UnencryptedMode 14739
#define sipName_UnencryptedMode &sipStrings_QtNetwork[14739]
#define sipNameNr_UnknownProtocol 14755
#define sipName_UnknownProtocol &sipStrings_QtNetwork[14755]
#define sipNameNr_UserAgentHeader 14771
#define sipName_UserAgentHeader &sipStrings_QtNetwork[14771]
#define sipNameNr_WWWAuthenticate 6892
#define sipName_WWWAuthenticate &sipStrings_QtNetwork[6892]
#define sipNameNr_WellKnownHeader 3156
#define sipName_WellKnownHeader &sipStrings_QtNetwork[3156]
#define sipNameNr_abortHostLookup 14787
#define sipName_abortHostLookup &sipStrings_QtNetwork[14787]
#define sipNameNr_clearAttributes 14803
#define sipName_clearAttributes &sipStrings_QtNetwork[14803]
#define sipNameNr_connectToServer 14819
#define sipName_connectToServer &sipStrings_QtNetwork[14819]
#define sipNameNr_dateTimeValueAt 14835
#define sipName_dateTimeValueAt &sipStrings_QtNetwork[14835]
#define sipNameNr_deriveKeyPbkdf1 14851
#define sipName_deriveKeyPbkdf1 &sipStrings_QtNetwork[14851]
#define sipNameNr_deriveKeyPbkdf2 14867
#define sipName_deriveKeyPbkdf2 &sipStrings_QtNetwork[14867]
#define sipNameNr_destinationPort 14883
#define sipName_destinationPort &sipStrings_QtNetwork[14883]
#define sipNameNr_fromListOfPairs 14899
#define sipName_fromListOfPairs &sipStrings_QtNetwork[14899]
#define sipNameNr_hardwareAddress 14915
#define sipName_hardwareAddress &sipStrings_QtNetwork[14915]
#define sipNameNr_ignoreSslErrors 14931
#define sipName_ignoreSslErrors &sipStrings_QtNetwork[14931]
#define sipNameNr_isAuthenticData 14947
#define sipName_isAuthenticData &sipStrings_QtNetwork[14947]
#define sipNameNr_isLifetimeKnown 14963
#define sipName_isLifetimeKnown &sipStrings_QtNetwork[14963]
#define sipNameNr_isSessionCookie 14979
#define sipName_isSessionCookie &sipStrings_QtNetwork[14979]
#define sipNameNr_isTlsNamedCurve 14995
#define sipName_isTlsNamedCurve &sipStrings_QtNetwork[14995]
#define sipNameNr_localDomainName 15011
#define sipName_localDomainName &sipStrings_QtNetwork[15011]
#define sipNameNr_metaDataChanged 15027
#define sipName_metaDataChanged &sipStrings_QtNetwork[15027]
#define sipNameNr_peerCertificate 15043
#define sipName_peerCertificate &sipStrings_QtNetwork[15043]
#define sipNameNr_peerVerifyDepth 15059
#define sipName_peerVerifyDepth &sipStrings_QtNetwork[15059]
#define sipNameNr_peerVerifyError 15075
#define sipName_peerVerifyError &sipStrings_QtNetwork[15075]
#define sipNameNr_queryParameters 15091
#define sipName_queryParameters &sipStrings_QtNetwork[15091]
#define sipNameNr_receiveDatagram 15107
#define sipName_receiveDatagram &sipStrings_QtNetwork[15107]
#define sipNameNr_redirectAllowed 15123
#define sipName_redirectAllowed &sipStrings_QtNetwork[15123]
#define sipNameNr_replaceOrAppend 15139
#define sipName_replaceOrAppend &sipStrings_QtNetwork[15139]
#define sipNameNr_resumeAccepting 15155
#define sipName_resumeAccepting &sipStrings_QtNetwork[15155]
#define sipNameNr_sessionProtocol 15171
#define sipName_sessionProtocol &sipStrings_QtNetwork[15171]
#define sipNameNr_setCapabilities 15187
#define sipName_setCapabilities &sipStrings_QtNetwork[15187]
#define sipNameNr_setLastModified 15203
#define sipName_setLastModified &sipStrings_QtNetwork[15203]
#define sipNameNr_setLocalAddress 15219
#define sipName_setLocalAddress &sipStrings_QtNetwork[15219]
#define sipNameNr_setMaxFrameSize 15235
#define sipName_setMaxFrameSize &sipStrings_QtNetwork[15235]
#define sipNameNr_setPeerHostName 15251
#define sipName_setPeerHostName &sipStrings_QtNetwork[15251]
#define sipNameNr_setPreSharedKey 15267
#define sipName_setPreSharedKey &sipStrings_QtNetwork[15267]
#define sipNameNr_setPrefixLength 15283
#define sipName_setPrefixLength &sipStrings_QtNetwork[15283]
#define sipNameNr_setProxyFactory 15299
#define sipName_setProxyFactory &sipStrings_QtNetwork[15299]
#define sipNameNr_setSocketOption 15315
#define sipName_setSocketOption &sipStrings_QtNetwork[15315]
#define sipNameNr_transferTimeout 15331
#define sipName_transferTimeout &sipStrings_QtNetwork[15331]
#define sipNameNr_transportMedium 15347
#define sipName_transportMedium &sipStrings_QtNetwork[15347]
#define sipNameNr_AcceptDatetime 15363
#define sipName_AcceptDatetime &sipStrings_QtNetwork[15363]
#define sipNameNr_AcceptEncoding 15378
#define sipName_AcceptEncoding &sipStrings_QtNetwork[15378]
#define sipNameNr_AcceptFeatures 15393
#define sipName_AcceptFeatures &sipStrings_QtNetwork[15393]
#define sipNameNr_AcceptLanguage 15408
#define sipName_AcceptLanguage &sipStrings_QtNetwork[15408]
#define sipNameNr_AutoVerifyPeer 15423
#define sipName_AutoVerifyPeer &sipStrings_QtNetwork[15423]
#define sipNameNr_BadCertificate 15438
#define sipName_BadCertificate &sipStrings_QtNetwork[15438]
#define sipNameNr_ClientSideAlpn 15453
#define sipName_ClientSideAlpn &sipStrings_QtNetwork[15453]
#define sipNameNr_ConnectedState 15468
#define sipName_ConnectedState &sipStrings_QtNetwork[15468]
#define sipNameNr_DifferentialID 15483
#define sipName_DifferentialID &sipStrings_QtNetwork[15483]
#define sipNameNr_EncodingFormat 9571
#define sipName_EncodingFormat &sipStrings_QtNetwork[9571]
#define sipNameNr_InvalidPurpose 15498
#define sipName_InvalidPurpose &sipStrings_QtNetwork[15498]
#define sipNameNr_IpAddressEntry 15513
#define sipName_IpAddressEntry &sipStrings_QtNetwork[15513]
#define sipNameNr_IsPointToPoint 15528
#define sipName_IsPointToPoint &sipStrings_QtNetwork[15528]
#define sipNameNr_ListeningState 15543
#define sipName_ListeningState &sipStrings_QtNetwork[15543]
#define sipNameNr_LocationHeader 15558
#define sipName_LocationHeader &sipStrings_QtNetwork[15558]
#define sipNameNr_LowDelayOption 15573
#define sipName_LowDelayOption &sipStrings_QtNetwork[15573]
#define sipNameNr_NormalPriority 15588
#define sipName_NormalPriority &sipStrings_QtNetwork[15588]
#define sipNameNr_ODataIsolation 15603
#define sipName_ODataIsolation &sipStrings_QtNetwork[15603]
#define sipNameNr_OcspSigRequred 15618
#define sipName_OcspSigRequred &sipStrings_QtNetwork[15618]
#define sipNameNr_OperationError 2387
#define sipName_OperationError &sipStrings_QtNetwork[2387]
#define sipNameNr_PeerVerifyMode 5211
#define sipName_PeerVerifyMode &sipStrings_QtNetwork[5211]
#define sipNameNr_QAuthenticator 15633
#define sipName_QAuthenticator &sipStrings_QtNetwork[15633]
#define sipNameNr_QDnsTextRecord 15648
#define sipName_QDnsTextRecord &sipStrings_QtNetwork[15648]
#define sipNameNr_QHttpMultiPart 15663
#define sipName_QHttpMultiPart &sipStrings_QtNetwork[15663]
#define sipNameNr_15678 15678
#define sipName_15678 &sipStrings_QtNetwork[15678]
#define sipNameNr_QNetworkCookie 15693
#define sipName_QNetworkCookie &sipStrings_QtNetwork[15693]
#define sipNameNr_RecordOverflow 15708
#define sipName_RecordOverflow &sipStrings_QtNetwork[15708]
#define sipNameNr_RedirectPolicy 2355
#define sipName_RedirectPolicy &sipStrings_QtNetwork[2355]
#define sipNameNr_ServerSideAlpn 15723
#define sipName_ServerSideAlpn &sipStrings_QtNetwork[15723]
#define sipNameNr_SignatureInput 15738
#define sipName_SignatureInput &sipStrings_QtNetwork[15738]
#define sipNameNr_SpecialAddress 3809
#define sipName_SpecialAddress &sipStrings_QtNetwork[3809]
#define sipNameNr_TemporaryError 15753
#define sipName_TemporaryError &sipStrings_QtNetwork[15753]
#define sipNameNr_TlsV1_0OrLater 15768
#define sipName_TlsV1_0OrLater &sipStrings_QtNetwork[15768]
#define sipNameNr_TlsV1_1OrLater 15783
#define sipName_TlsV1_1OrLater &sipStrings_QtNetwork[15783]
#define sipNameNr_TlsV1_2OrLater 15798
#define sipName_TlsV1_2OrLater &sipStrings_QtNetwork[15798]
#define sipNameNr_TlsV1_3OrLater 15813
#define sipName_TlsV1_3OrLater &sipStrings_QtNetwork[15813]
#define sipNameNr_WantReprDigest 15828
#define sipName_WantReprDigest &sipStrings_QtNetwork[15828]
#define sipNameNr_addressEntries 15843
#define sipName_addressEntries &sipStrings_QtNetwork[15843]
#define sipNameNr_buildMultiPart 15858
#define sipName_buildMultiPart &sipStrings_QtNetwork[15858]
#define sipNameNr_bytesAvailable 15873
#define sipName_bytesAvailable &sipStrings_QtNetwork[15873]
#define sipNameNr_caCertificates 15888
#define sipName_caCertificates &sipStrings_QtNetwork[15888]
#define sipNameNr_cacheDirectory 15903
#define sipName_cacheDirectory &sipStrings_QtNetwork[15903]
#define sipNameNr_clearAttribute 15918
#define sipName_clearAttribute &sipStrings_QtNetwork[15918]
#define sipNameNr_dateTimeValues 15933
#define sipName_dateTimeValues &sipStrings_QtNetwork[15933]
#define sipNameNr_deleteResource 15948
#define sipName_deleteResource &sipStrings_QtNetwork[15948]
#define sipNameNr_dnsEligibility 15963
#define sipName_dnsEligibility &sipStrings_QtNetwork[15963]
#define sipNameNr_ellipticCurves 15978
#define sipName_ellipticCurves &sipStrings_QtNetwork[15978]
#define sipNameNr_expirationDate 15993
#define sipName_expirationDate &sipStrings_QtNetwork[15993]
#define sipNameNr_fullServerName 16008
#define sipName_fullServerName &sipStrings_QtNetwork[16008]
#define sipNameNr_interfaceIndex 16023
#define sipName_interfaceIndex &sipStrings_QtNetwork[16023]
#define sipNameNr_isCachingProxy 16038
#define sipName_isCachingProxy &sipStrings_QtNetwork[16038]
#define sipNameNr_nameserverPort 16053
#define sipName_nameserverPort &sipStrings_QtNetwork[16053]
#define sipNameNr_pauseAccepting 16068
#define sipName_pauseAccepting &sipStrings_QtNetwork[16068]
#define sipNameNr_peerVerifyMode 16083
#define sipName_peerVerifyMode &sipStrings_QtNetwork[16083]
#define sipNameNr_peerVerifyName 16098
#define sipName_peerVerifyName &sipStrings_QtNetwork[16098]
#define sipNameNr_pointerRecords 16113
#define sipName_pointerRecords &sipStrings_QtNetwork[16113]
#define sipNameNr_protocolString 16128
#define sipName_protocolString &sipStrings_QtNetwork[16128]
#define sipNameNr_rawHeaderPairs 16143
#define sipName_rawHeaderPairs &sipStrings_QtNetwork[16143]
#define sipNameNr_readBufferSize 16158
#define sipName_readBufferSize &sipStrings_QtNetwork[16158]
#define sipNameNr_redirectPolicy 16173
#define sipName_redirectPolicy &sipStrings_QtNetwork[16173]
#define sipNameNr_sameSitePolicy 16188
#define sipName_sameSitePolicy &sipStrings_QtNetwork[16188]
#define sipNameNr_serviceRecords 16203
#define sipName_serviceRecords &sipStrings_QtNetwork[16203]
#define sipNameNr_setBearerToken 16218
#define sipName_setBearerToken &sipStrings_QtNetwork[16218]
#define sipNameNr_setContentType 16233
#define sipName_setContentType &sipStrings_QtNetwork[16233]
#define sipNameNr_setDestination 16248
#define sipName_setDestination &sipStrings_QtNetwork[16248]
#define sipNameNr_setErrorString 16263
#define sipName_setErrorString &sipStrings_QtNetwork[16263]
#define sipNameNr_setPeerAddress 16278
#define sipName_setPeerAddress &sipStrings_QtNetwork[16278]
#define sipNameNr_setProtocolTag 16293
#define sipName_setProtocolTag &sipStrings_QtNetwork[16293]
#define sipNameNr_setSocketError 16308
#define sipName_setSocketError &sipStrings_QtNetwork[16308]
#define sipNameNr_setSocketState 16323
#define sipName_setSocketState &sipStrings_QtNetwork[16323]
#define sipNameNr_updateMetaData 16338
#define sipName_updateMetaData &sipStrings_QtNetwork[16338]
#define sipNameNr_uploadProgress 16353
#define sipName_uploadProgress &sipStrings_QtNetwork[16353]
#define sipNameNr_validateCookie 16368
#define sipName_validateCookie &sipStrings_QtNetwork[16368]
#define sipNameNr_AcceptCharset 16383
#define sipName_AcceptCharset &sipStrings_QtNetwork[16383]
#define sipNameNr_AlwaysNetwork 16397
#define sipName_AlwaysNetwork &sipStrings_QtNetwork[16397]
#define sipNameNr_AnyIPProtocol 16411
#define sipName_AnyIPProtocol &sipStrings_QtNetwork[16411]
#define sipNameNr_Authorization 11303
#define sipName_Authorization &sipStrings_QtNetwork[11303]
#define sipNameNr_CaptivePortal 8801
#define sipName_CaptivePortal &sipStrings_QtNetwork[8801]
#define sipNameNr_CertNotBefore 16425
#define sipName_CertNotBefore &sipStrings_QtNetwork[16425]
#define sipNameNr_ClearSiteData 16439
#define sipName_ClearSiteData &sipStrings_QtNetwork[16439]
#define sipNameNr_ContentDigest 12657
#define sipName_ContentDigest &sipStrings_QtNetwork[12657]
#define sipNameNr_ContentLength 16453
#define sipName_ContentLength &sipStrings_QtNetwork[16453]
#define sipNameNr_DiffieHellman 16467
#define sipName_DiffieHellman &sipStrings_QtNetwork[16467]
#define sipNameNr_DnsIneligible 16481
#define sipName_DnsIneligible &sipStrings_QtNetwork[16481]
#define sipNameNr_EllipticCurve 12549
#define sipName_EllipticCurve &sipStrings_QtNetwork[12549]
#define sipNameNr_HeadOperation 16495
#define sipName_HeadOperation &sipStrings_QtNetwork[16495]
#define sipNameNr_HostInfoError 6255
#define sipName_HostInfoError &sipStrings_QtNetwork[6255]
#define sipNameNr_IfMatchHeader 16509
#define sipName_IfMatchHeader &sipStrings_QtNetwork[16509]
#define sipNameNr_InterfaceFlag 1899
#define sipName_InterfaceFlag &sipStrings_QtNetwork[1899]
#define sipNameNr_InterfaceType 1932
#define sipName_InterfaceType &sipStrings_QtNetwork[1932]
#define sipNameNr_InternalError 12279
#define sipName_InternalError &sipStrings_QtNetwork[12279]
#define sipNameNr_KeyCompromise 16523
#define sipName_KeyCompromise &sipStrings_QtNetwork[16523]
#define sipNameNr_LocalHostIPv6 16537
#define sipName_LocalHostIPv6 &sipStrings_QtNetwork[16537]
#define sipNameNr_NoCertificate 16551
#define sipName_NoCertificate &sipStrings_QtNetwork[16551]
#define sipNameNr_NotFoundError 9215
#define sipName_NotFoundError &sipStrings_QtNetwork[9215]
#define sipNameNr_ODataEntityId 16565
#define sipName_ODataEntityId &sipStrings_QtNetwork[16565]
#define sipNameNr_PatternSyntax 2730
#define sipName_PatternSyntax &sipStrings_QtNetwork[2730]
#define sipNameNr_PostOperation 16579
#define sipName_PostOperation &sipStrings_QtNetwork[16579]
#define sipNameNr_PreferNetwork 16593
#define sipName_PreferNetwork &sipStrings_QtNetwork[16593]
#define sipNameNr_ProtocolQuery 16607
#define sipName_ProtocolQuery &sipStrings_QtNetwork[16607]
#define sipNameNr_PublicKeyPins 16621
#define sipName_PublicKeyPins &sipStrings_QtNetwork[16621]
#define sipNameNr_QNetworkProxy 16635
#define sipName_QNetworkProxy &sipStrings_QtNetwork[16635]
#define sipNameNr_QNetworkReply 16649
#define sipName_QNetworkReply &sipStrings_QtNetwork[16649]
#define sipNameNr_QOcspResponse 16663
#define sipName_QOcspResponse &sipStrings_QtNetwork[16663]
#define sipNameNr_QSsl__KeyType 16677
#define sipName_QSsl__KeyType &sipStrings_QtNetwork[16677]
#define sipNameNr_RemoveFromCRL 16691
#define sipName_RemoveFromCRL &sipStrings_QtNetwork[16691]
#define sipNameNr_ResolverError 16705
#define sipName_ResolverError &sipStrings_QtNetwork[16705]
#define sipNameNr_ScheduleReply 16719
#define sipName_ScheduleReply &sipStrings_QtNetwork[16719]
#define sipNameNr_SessionTicket 13948
#define sipName_SessionTicket &sipStrings_QtNetwork[13948]
#define sipNameNr_SslClientMode 16733
#define sipName_SslClientMode &sipStrings_QtNetwork[16733]
#define sipNameNr_SslServerMode 16747
#define sipName_SslServerMode &sipStrings_QtNetwork[16747]
#define sipNameNr_StrictRfc7578 16761
#define sipName_StrictRfc7578 &sipStrings_QtNetwork[16761]
#define sipNameNr_UserCancelled 16775
#define sipName_UserCancelled &sipStrings_QtNetwork[16775]
#define sipNameNr_XFrameOptions 16789
#define sipName_XFrameOptions &sipStrings_QtNetwork[16789]
#define sipNameNr_activeBackend 16803
#define sipName_activeBackend &sipStrings_QtNetwork[16803]
#define sipNameNr_alertReceived 16817
#define sipName_alertReceived &sipStrings_QtNetwork[16817]
#define sipNameNr_allInterfaces 16831
#define sipName_allInterfaces &sipStrings_QtNetwork[16831]
#define sipNameNr_clearPassword 16845
#define sipName_clearPassword &sipStrings_QtNetwork[16845]
#define sipNameNr_clearUserName 16859
#define sipName_clearUserName &sipStrings_QtNetwork[16859]
#define sipNameNr_combinedValue 16873
#define sipName_combinedValue &sipStrings_QtNetwork[16873]
#define sipNameNr_commonHeaders 16887
#define sipName_commonHeaders &sipStrings_QtNetwork[16887]
#define sipNameNr_connectNotify 13761
#define sipName_connectNotify &sipStrings_QtNetwork[13761]
#define sipNameNr_connectToHost 16901
#define sipName_connectToHost &sipStrings_QtNetwork[16901]
#define sipNameNr_cookiesForUrl 16915
#define sipName_cookiesForUrl &sipStrings_QtNetwork[16915]
#define sipNameNr_createRequest 16929
#define sipName_createRequest &sipStrings_QtNetwork[16929]
#define sipNameNr_dateTimeValue 16943
#define sipName_dateTimeValue &sipStrings_QtNetwork[16943]
#define sipNameNr_effectiveDate 16957
#define sipName_effectiveDate &sipStrings_QtNetwork[16957]
#define sipNameNr_errorOccurred 16971
#define sipName_errorOccurred &sipStrings_QtNetwork[16971]
#define sipNameNr_fromShortName 16985
#define sipName_fromShortName &sipStrings_QtNetwork[16985]
#define sipNameNr_isBlacklisted 16999
#define sipName_isBlacklisted &sipStrings_QtNetwork[16999]
#define sipNameNr_localHostName 17013
#define sipName_localHostName &sipStrings_QtNetwork[17013]
#define sipNameNr_newConnection 17027
#define sipName_newConnection &sipStrings_QtNetwork[17027]
#define sipNameNr_ocspResponses 17041
#define sipName_ocspResponses &sipStrings_QtNetwork[17041]
#define sipNameNr_proxyForQuery 17055
#define sipName_proxyForQuery &sipStrings_QtNetwork[17055]
#define sipNameNr_rawHeaderList 17069
#define sipName_rawHeaderList &sipStrings_QtNetwork[17069]
#define sipNameNr_senderAddress 17083
#define sipName_senderAddress &sipStrings_QtNetwork[17083]
#define sipNameNr_serverAddress 17097
#define sipName_serverAddress &sipStrings_QtNetwork[17097]
#define sipNameNr_sessionCipher 17111
#define sipName_sessionCipher &sipStrings_QtNetwork[17111]
#define sipNameNr_sessionTicket 17125
#define sipName_sessionTicket &sipStrings_QtNetwork[17125]
#define sipNameNr_setAllCookies 17139
#define sipName_setAllCookies &sipStrings_QtNetwork[17139]
#define sipNameNr_setAttributes 17153
#define sipName_setAttributes &sipStrings_QtNetwork[17153]
#define sipNameNr_setBodyDevice 17167
#define sipName_setBodyDevice &sipStrings_QtNetwork[17167]
#define sipNameNr_setNameserver 17181
#define sipName_setNameserver &sipStrings_QtNetwork[17181]
#define sipNameNr_setPrivateKey 17195
#define sipName_setPrivateKey &sipStrings_QtNetwork[17195]
#define sipNameNr_setRawHeaders 17209
#define sipName_setRawHeaders &sipStrings_QtNetwork[17209]
#define sipNameNr_setSaveToDisk 17223
#define sipName_setSaveToDisk &sipStrings_QtNetwork[17223]
#define sipNameNr_setServerName 17237
#define sipName_setServerName &sipStrings_QtNetwork[17237]
#define sipNameNr_socketOptions 17251
#define sipName_socketOptions &sipStrings_QtNetwork[17251]
#define sipNameNr_supportedBits 17265
#define sipName_supportedBits &sipStrings_QtNetwork[17265]
#define sipNameNr_testSslOption 17279
#define sipName_testSslOption &sipStrings_QtNetwork[17279]
#define sipNameNr_toIPv4Address 17293
#define sipName_toIPv4Address &sipStrings_QtNetwork[17293]
#define sipNameNr_toIPv6Address 17307
#define sipName_toIPv6Address &sipStrings_QtNetwork[17307]
#define sipNameNr_toListOfPairs 17321
#define sipName_toListOfPairs &sipStrings_QtNetwork[17321]
#define sipNameNr_writeDatagram 17335
#define sipName_writeDatagram &sipStrings_QtNetwork[17335]
#define sipNameNr_AcceptRanges 17349
#define sipName_AcceptRanges &sipStrings_QtNetwork[17349]
#define sipNameNr_AccessDenied 10178
#define sipName_AccessDenied &sipStrings_QtNetwork[10178]
#define sipNameNr_BadRecordMac 17362
#define sipName_BadRecordMac &sipStrings_QtNetwork[17362]
#define sipNameNr_CACompromise 17375
#define sipName_CACompromise &sipStrings_QtNetwork[17375]
#define sipNameNr_CacheControl 14166
#define sipName_CacheControl &sipStrings_QtNetwork[14166]
#define sipNameNr_CalManagedID 17388
#define sipName_CalManagedID &sipStrings_QtNetwork[17388]
#define sipNameNr_CanBroadcast 17401
#define sipName_CanBroadcast &sipStrings_QtNetwork[17401]
#define sipNameNr_CanMulticast 17414
#define sipName_CanMulticast &sipStrings_QtNetwork[17414]
#define sipNameNr_CertNotAfter 17427
#define sipName_CertNotAfter &sipStrings_QtNetwork[17427]
#define sipNameNr_ClosingState 17440
#define sipName_ClosingState &sipStrings_QtNetwork[17440]
#define sipNameNr_ContentRange 17453
#define sipName_ContentRange &sipStrings_QtNetwork[17453]
#define sipNameNr_CookieHeader 14726
#define sipName_CookieHeader &sipStrings_QtNetwork[14726]
#define sipNameNr_DecryptError 17466
#define sipName_DecryptError &sipStrings_QtNetwork[17466]
#define sipNameNr_DefaultProxy 17479
#define sipName_DefaultProxy &sipStrings_QtNetwork[17479]
#define sipNameNr_Disconnected 11018
#define sipName_Disconnected &sipStrings_QtNetwork[11018]
#define sipNameNr_EmailAddress 17492
#define sipName_EmailAddress &sipStrings_QtNetwork[17492]
#define sipNameNr_FormDataType 17505
#define sipName_FormDataType &sipStrings_QtNetwork[17505]
#define sipNameNr_GetOperation 17518
#define sipName_GetOperation &sipStrings_QtNetwork[17518]
#define sipNameNr_HighPriority 17531
#define sipName_HighPriority &sipStrings_QtNetwork[17531]
#define sipNameNr_HostNotFound 17544
#define sipName_HostNotFound &sipStrings_QtNetwork[17544]
#define sipNameNr_IPv4Protocol 17557
#define sipName_IPv4Protocol &sipStrings_QtNetwork[17557]
#define sipNameNr_IPv6Protocol 17570
#define sipName_IPv6Protocol &sipStrings_QtNetwork[17570]
#define sipNameNr_KeyAlgorithm 11418
#define sipName_KeyAlgorithm &sipStrings_QtNetwork[11418]
#define sipNameNr_KnownHeaders 3309
#define sipName_KnownHeaders &sipStrings_QtNetwork[3309]
#define sipNameNr_LastModified 15206
#define sipName_LastModified &sipStrings_QtNetwork[15206]
#define sipNameNr_LocalityName 17583
#define sipName_LocalityName &sipStrings_QtNetwork[17583]
#define sipNameNr_MatchingType 463
#define sipName_MatchingType &sipStrings_QtNetwork[463]
#define sipNameNr_NetworkError 4583
#define sipName_NetworkError &sipStrings_QtNetwork[4583]
#define sipNameNr_NoSslSupport 17596
#define sipName_NoSslSupport &sipStrings_QtNetwork[17596]
#define sipNameNr_ODataVersion 17609
#define sipName_ODataVersion &sipStrings_QtNetwork[17609]
#define sipNameNr_OcspTryLater 17622
#define sipName_OcspTryLater &sipStrings_QtNetwork[17622]
#define sipNameNr_OrderingType 17635
#define sipName_OrderingType &sipStrings_QtNetwork[17635]
#define sipNameNr_Organization 17648
#define sipName_Organization &sipStrings_QtNetwork[17648]
#define sipNameNr_ProtocolInfo 17661
#define sipName_ProtocolInfo &sipStrings_QtNetwork[17661]
#define sipNameNr_PutOperation 17674
#define sipName_PutOperation &sipStrings_QtNetwork[17674]
#define sipNameNr_QHostAddress 17687
#define sipName_QHostAddress &sipStrings_QtNetwork[17687]
#define sipNameNr_QHttpHeaders 17700
#define sipName_QHttpHeaders &sipStrings_QtNetwork[17700]
#define sipNameNr_QLocalServer 17713
#define sipName_QLocalServer &sipStrings_QtNetwork[17713]
#define sipNameNr_QLocalSocket 17726
#define sipName_QLocalSocket &sipStrings_QtNetwork[17726]
#define sipNameNr_Reachability 1499
#define sipName_Reachability &sipStrings_QtNetwork[1499]
#define sipNameNr_SerialNumber 17739
#define sipName_SerialNumber &sipStrings_QtNetwork[17739]
#define sipNameNr_ServerHeader 17752
#define sipName_ServerHeader &sipStrings_QtNetwork[17752]
#define sipNameNr_ServerTiming 17765
#define sipName_ServerTiming &sipStrings_QtNetwork[17765]
#define sipNameNr_ShareAddress 13303
#define sipName_ShareAddress &sipStrings_QtNetwork[13303]
#define sipNameNr_SocketOption 3129
#define sipName_SocketOption &sipStrings_QtNetwork[3129]
#define sipNameNr_TimeoutError 4443
#define sipName_TimeoutError &sipStrings_QtNetwork[4443]
#define sipNameNr_UnknownError 9405
#define sipName_UnknownError &sipStrings_QtNetwork[9405]
#define sipNameNr_allAddresses 17778
#define sipName_allAddresses &sipStrings_QtNetwork[17778]
#define sipNameNr_bytesToWrite 17791
#define sipName_bytesToWrite &sipStrings_QtNetwork[17791]
#define sipNameNr_capabilities 17804
#define sipName_capabilities &sipStrings_QtNetwork[17804]
#define sipNameNr_defaultValue 17817
#define sipName_defaultValue &sipStrings_QtNetwork[17817]
#define sipNameNr_deleteCookie 17830
#define sipName_deleteCookie &sipStrings_QtNetwork[17830]
#define sipNameNr_disconnected 17843
#define sipName_disconnected &sipStrings_QtNetwork[17843]
#define sipNameNr_fileMetaData 17856
#define sipName_fileMetaData &sipStrings_QtNetwork[17856]
#define sipNameNr_fromLongName 17869
#define sipName_fromLongName &sipStrings_QtNetwork[17869]
#define sipNameNr_hasRawHeader 17882
#define sipName_hasRawHeader &sipStrings_QtNetwork[17882]
#define sipNameNr_identityHint 17895
#define sipName_identityHint &sipStrings_QtNetwork[17895]
#define sipNameNr_importPkcs12 17908
#define sipName_importPkcs12 &sipStrings_QtNetwork[17908]
#define sipNameNr_insertCookie 17921
#define sipName_insertCookie &sipStrings_QtNetwork[17921]
#define sipNameNr_isPrivateUse 17934
#define sipName_isPrivateUse &sipStrings_QtNetwork[17934]
#define sipNameNr_isSelfSigned 17947
#define sipName_isSelfSigned &sipStrings_QtNetwork[17947]
#define sipNameNr_isSequential 17960
#define sipName_isSequential &sipStrings_QtNetwork[17960]
#define sipNameNr_lastModified 17973
#define sipName_lastModified &sipStrings_QtNetwork[17973]
#define sipNameNr_localAddress 17986
#define sipName_localAddress &sipStrings_QtNetwork[17986]
#define sipNameNr_maxFrameSize 17999
#define sipName_maxFrameSize &sipStrings_QtNetwork[17999]
#define sipNameNr_networkReply 18012
#define sipName_networkReply &sipStrings_QtNetwork[18012]
#define sipNameNr_parseCookies 18025
#define sipName_parseCookies &sipStrings_QtNetwork[18025]
#define sipNameNr_peerHostName 18038
#define sipName_peerHostName &sipStrings_QtNetwork[18038]
#define sipNameNr_preSharedKey 18051
#define sipName_preSharedKey &sipStrings_QtNetwork[18051]
#define sipNameNr_prefixLength 18064
#define sipName_prefixLength &sipStrings_QtNetwork[18064]
#define sipNameNr_proxyFactory 18077
#define sipName_proxyFactory &sipStrings_QtNetwork[18077]
#define sipNameNr_reachability 18090
#define sipName_reachability &sipStrings_QtNetwork[18090]
#define sipNameNr_readDatagram 18103
#define sipName_readDatagram &sipStrings_QtNetwork[18103]
#define sipNameNr_readLineData 18116
#define sipName_readLineData &sipStrings_QtNetwork[18116]
#define sipNameNr_removeServer 18129
#define sipName_removeServer &sipStrings_QtNetwork[18129]
#define sipNameNr_serialNumber 18142
#define sipName_serialNumber &sipStrings_QtNetwork[18142]
#define sipNameNr_setAddresses 18155
#define sipName_setAddresses &sipStrings_QtNetwork[18155]
#define sipNameNr_setAttribute 18168
#define sipName_setAttribute &sipStrings_QtNetwork[18168]
#define sipNameNr_setBroadcast 18181
#define sipName_setBroadcast &sipStrings_QtNetwork[18181]
#define sipNameNr_setCookieJar 18194
#define sipName_setCookieJar &sipStrings_QtNetwork[18194]
#define sipNameNr_setLocalPort 18207
#define sipName_setLocalPort &sipStrings_QtNetwork[18207]
#define sipNameNr_setOperation 18220
#define sipName_setOperation &sipStrings_QtNetwork[18220]
#define sipNameNr_setPauseMode 18233
#define sipName_setPauseMode &sipStrings_QtNetwork[18233]
#define sipNameNr_setQueryType 18246
#define sipName_setQueryType &sipStrings_QtNetwork[18246]
#define sipNameNr_setRawHeader 18259
#define sipName_setRawHeader &sipStrings_QtNetwork[18259]
#define sipNameNr_setSslOption 18272
#define sipName_setSslOption &sipStrings_QtNetwork[18272]
#define sipNameNr_socketOption 18285
#define sipName_socketOption &sipStrings_QtNetwork[18285]
#define sipNameNr_stateChanged 18298
#define sipName_stateChanged &sipStrings_QtNetwork[18298]
#define sipNameNr_updateCookie 18311
#define sipName_updateCookie &sipStrings_QtNetwork[18311]
#define sipNameNr_AcceptPatch 18324
#define sipName_AcceptPatch &sipStrings_QtNetwork[18324]
#define sipNameNr_AlwaysCache 18336
#define sipName_AlwaysCache &sipStrings_QtNetwork[18336]
#define sipNameNr_AnyProtocol 18348
#define sipName_AnyProtocol &sipStrings_QtNetwork[18348]
#define sipNameNr_CacheStatus 18360
#define sipName_CacheStatus &sipStrings_QtNetwork[18360]
#define sipNameNr_Certificate 1568
#define sipName_Certificate &sipStrings_QtNetwork[1568]
#define sipNameNr_CloseNotify 18372
#define sipName_CloseNotify &sipStrings_QtNetwork[18372]
#define sipNameNr_ContentType 4500
#define sipName_ContentType &sipStrings_QtNetwork[4500]
#define sipNameNr_CountryName 18384
#define sipName_CountryName &sipStrings_QtNetwork[18384]
#define sipNameNr_DecodeError 18396
#define sipName_DecodeError &sipStrings_QtNetwork[18396]
#define sipNameNr_Destination 16251
#define sipName_Destination &sipStrings_QtNetwork[16251]
#define sipNameNr_DnsEligible 18408
#define sipName_DnsEligible &sipStrings_QtNetwork[18408]
#define sipNameNr_FixedString 18420
#define sipName_FixedString &sipStrings_QtNetwork[18420]
#define sipNameNr_IfNoneMatch 18432
#define sipName_IfNoneMatch &sipStrings_QtNetwork[18432]
#define sipNameNr_LastEventID 18444
#define sipName_LastEventID &sipStrings_QtNetwork[18444]
#define sipNameNr_LoadControl 1534
#define sipName_LoadControl &sipStrings_QtNetwork[1534]
#define sipNameNr_LowPriority 18456
#define sipName_LowPriority &sipStrings_QtNetwork[18456]
#define sipNameNr_MIMEVersion 18468
#define sipName_MIMEVersion &sipStrings_QtNetwork[18468]
#define sipNameNr_MaxForwards 18480
#define sipName_MaxForwards &sipStrings_QtNetwork[18480]
#define sipNameNr_PreferCache 18492
#define sipName_PreferCache &sipStrings_QtNetwork[18492]
#define sipNameNr_ProxyStatus 18504
#define sipName_ProxyStatus &sipStrings_QtNetwork[18504]
#define sipNameNr_QHstsPolicy 18516
#define sipName_QHstsPolicy &sipStrings_QtNetwork[18516]
#define sipNameNr_RedirectRef 11077
#define sipName_RedirectRef &sipStrings_QtNetwork[11077]
#define sipNameNr_RelatedType 18528
#define sipName_RelatedType &sipStrings_QtNetwork[18528]
#define sipNameNr_ReplayNonce 18540
#define sipName_ReplayNonce &sipStrings_QtNetwork[18540]
#define sipNameNr_ScheduleTag 18552
#define sipName_ScheduleTag &sipStrings_QtNetwork[18552]
#define sipNameNr_SocketError 2639
#define sipName_SocketError &sipStrings_QtNetwork[2639]
#define sipNameNr_SocketState 2670
#define sipName_SocketState &sipStrings_QtNetwork[2670]
#define sipNameNr_Socks5Proxy 18564
#define sipName_Socks5Proxy &sipStrings_QtNetwork[18564]
#define sipNameNr_SslProtocol 12515
#define sipName_SslProtocol &sipStrings_QtNetwork[12515]
#define sipNameNr_SubjectInfo 3928
#define sipName_SubjectInfo &sipStrings_QtNetwork[3928]
#define sipNameNr_Traceparent 18576
#define sipName_Traceparent &sipStrings_QtNetwork[18576]
#define sipNameNr_Unspecified 18588
#define sipName_Unspecified &sipStrings_QtNetwork[18588]
#define sipNameNr_VariantVary 18600
#define sipName_VariantVary &sipStrings_QtNetwork[18600]
#define sipNameNr_acceptError 18612
#define sipName_acceptError &sipStrings_QtNetwork[18612]
#define sipNameNr_backendName 18624
#define sipName_backendName &sipStrings_QtNetwork[18624]
#define sipNameNr_bearerToken 18636
#define sipName_bearerToken &sipStrings_QtNetwork[18636]
#define sipNameNr_canReadLine 18648
#define sipName_canReadLine &sipStrings_QtNetwork[18648]
#define sipNameNr_certificate 18660
#define sipName_certificate &sipStrings_QtNetwork[18660]
#define sipNameNr_customEvent 18672
#define sipName_customEvent &sipStrings_QtNetwork[18672]
#define sipNameNr_errorString 18684
#define sipName_errorString &sipStrings_QtNetwork[18684]
#define sipNameNr_eventFilter 18696
#define sipName_eventFilter &sipStrings_QtNetwork[18696]
#define sipNameNr_fromEncoded 18708
#define sipName_fromEncoded &sipStrings_QtNetwork[18708]
#define sipNameNr_isBroadcast 18720
#define sipName_isBroadcast &sipStrings_QtNetwork[18720]
#define sipNameNr_isEncrypted 18732
#define sipName_isEncrypted &sipStrings_QtNetwork[18732]
#define sipNameNr_isLinkLocal 18744
#define sipName_isLinkLocal &sipStrings_QtNetwork[18744]
#define sipNameNr_isListening 18756
#define sipName_isListening &sipStrings_QtNetwork[18756]
#define sipNameNr_isMulticast 18768
#define sipName_isMulticast &sipStrings_QtNetwork[18768]
#define sipNameNr_isPermanent 18780
#define sipName_isPermanent &sipStrings_QtNetwork[18780]
#define sipNameNr_isSiteLocal 18792
#define sipName_isSiteLocal &sipStrings_QtNetwork[18792]
#define sipNameNr_isSupported 18804
#define sipName_isSupported &sipStrings_QtNetwork[18804]
#define sipNameNr_isTemporary 18816
#define sipName_isTemporary &sipStrings_QtNetwork[18816]
#define sipNameNr_modeChanged 18828
#define sipName_modeChanged &sipStrings_QtNetwork[18828]
#define sipNameNr_nameChanged 18840
#define sipName_nameChanged &sipStrings_QtNetwork[18840]
#define sipNameNr_parseSubnet 18852
#define sipName_parseSubnet &sipStrings_QtNetwork[18852]
#define sipNameNr_peerAddress 18864
#define sipName_peerAddress &sipStrings_QtNetwork[18864]
#define sipNameNr_protocolTag 18876
#define sipName_protocolTag &sipStrings_QtNetwork[18876]
#define sipNameNr_requestSent 18888
#define sipName_requestSent &sipStrings_QtNetwork[18888]
#define sipNameNr_serverError 18900
#define sipName_serverError &sipStrings_QtNetwork[18900]
#define sipNameNr_setBoundary 18912
#define sipName_setBoundary &sipStrings_QtNetwork[18912]
#define sipNameNr_setFinished 18924
#define sipName_setFinished &sipStrings_QtNetwork[18924]
#define sipNameNr_setHopLimit 18936
#define sipName_setHopLimit &sipStrings_QtNetwork[18936]
#define sipNameNr_setHostName 18948
#define sipName_setHostName &sipStrings_QtNetwork[18948]
#define sipNameNr_setHttpOnly 18960
#define sipName_setHttpOnly &sipStrings_QtNetwork[18960]
#define sipNameNr_setIdentity 18972
#define sipName_setIdentity &sipStrings_QtNetwork[18972]
#define sipNameNr_setLookupId 18984
#define sipName_setLookupId &sipStrings_QtNetwork[18984]
#define sipNameNr_setPassword 18996
#define sipName_setPassword &sipStrings_QtNetwork[18996]
#define sipNameNr_setPeerName 19008
#define sipName_setPeerName &sipStrings_QtNetwork[19008]
#define sipNameNr_setPeerPort 19020
#define sipName_setPeerPort &sipStrings_QtNetwork[19020]
#define sipNameNr_setPriority 19032
#define sipName_setPriority &sipStrings_QtNetwork[19032]
#define sipNameNr_setProtocol 19044
#define sipName_setProtocol &sipStrings_QtNetwork[19044]
#define sipNameNr_setUserName 19056
#define sipName_setUserName &sipStrings_QtNetwork[19056]
#define sipNameNr_subjectInfo 19068
#define sipName_subjectInfo &sipStrings_QtNetwork[19068]
#define sipNameNr_supportsSsl 19080
#define sipName_supportsSsl &sipStrings_QtNetwork[19080]
#define sipNameNr_textRecords 19092
#define sipName_textRecords &sipStrings_QtNetwork[19092]
#define sipNameNr_typeChanged 19104
#define sipName_typeChanged &sipStrings_QtNetwork[19104]
#define sipNameNr_AcceptPost 19116
#define sipName_AcceptPost &sipStrings_QtNetwork[19116]
#define sipNameNr_AlertLevel 13526
#define sipName_AlertLevel &sipStrings_QtNetwork[13526]
#define sipNameNr_Alternates 19127
#define sipName_Alternates &sipStrings_QtNetwork[19127]
#define sipNameNr_BoundState 19138
#define sipName_BoundState &sipStrings_QtNetwork[19138]
#define sipNameNr_Capability 5850
#define sipName_Capability &sipStrings_QtNetwork[5850]
#define sipNameNr_ClientCert 19149
#define sipName_ClientCert &sipStrings_QtNetwork[19149]
#define sipNameNr_CommonName 19160
#define sipName_CommonName &sipStrings_QtNetwork[19160]
#define sipNameNr_Connection 8936
#define sipName_Connection &sipStrings_QtNetwork[8936]
#define sipNameNr_DnsOverTls 19171
#define sipName_DnsOverTls &sipStrings_QtNetwork[19171]
#define sipNameNr_DtlsCookie 19182
#define sipName_DtlsCookie &sipStrings_QtNetwork[19182]
#define sipNameNr_ETagHeader 19193
#define sipName_ETagHeader &sipStrings_QtNetwork[19193]
#define sipNameNr_EmailEntry 19204
#define sipName_EmailEntry &sipStrings_QtNetwork[19204]
#define sipNameNr_Ieee802154 19215
#define sipName_Ieee802154 &sipStrings_QtNetwork[19215]
#define sipNameNr_IsLoopBack 19226
#define sipName_IsLoopBack &sipStrings_QtNetwork[19226]
#define sipNameNr_PauseNever 19237
#define sipName_PauseNever &sipStrings_QtNetwork[19237]
#define sipNameNr_PolicyFlag 7017
#define sipName_PolicyFlag &sipStrings_QtNetwork[7017]
#define sipNameNr_PrivateKey 17198
#define sipName_PrivateKey &sipStrings_QtNetwork[17198]
#define sipNameNr_PrivateUse 17936
#define sipName_PrivateUse &sipStrings_QtNetwork[17936]
#define sipNameNr_QDnsLookup 19248
#define sipName_QDnsLookup &sipStrings_QtNetwork[19248]
#define sipNameNr_QRestReply 19259
#define sipName_QRestReply &sipStrings_QtNetwork[19259]
#define sipNameNr_QSslCipher 19270
#define sipName_QSslCipher &sipStrings_QtNetwork[19270]
#define sipNameNr_QSslServer 19281
#define sipName_QSslServer &sipStrings_QtNetwork[19281]
#define sipNameNr_QSslSocket 19292
#define sipName_QSslSocket &sipStrings_QtNetwork[19292]
#define sipNameNr_QTcpServer 19303
#define sipName_QTcpServer &sipStrings_QtNetwork[19303]
#define sipNameNr_QTcpSocket 19314
#define sipName_QTcpSocket &sipStrings_QtNetwork[19314]
#define sipNameNr_QUdpSocket 19325
#define sipName_QUdpSocket &sipStrings_QtNetwork[19325]
#define sipNameNr_Q_IPV6ADDR 19336
#define sipName_Q_IPV6ADDR &sipStrings_QtNetwork[19336]
#define sipNameNr_ReprDigest 15832
#define sipName_ReprDigest &sipStrings_QtNetwork[15832]
#define sipNameNr_RetryAfter 19347
#define sipName_RetryAfter &sipStrings_QtNetwork[19347]
#define sipNameNr_SctpServer 19358
#define sipName_SctpServer &sipStrings_QtNetwork[19358]
#define sipNameNr_SctpSocket 19369
#define sipName_SctpSocket &sipStrings_QtNetwork[19369]
#define sipNameNr_SecPurpose 19380
#define sipName_SecPurpose &sipStrings_QtNetwork[19380]
#define sipNameNr_SoapAction 19391
#define sipName_SoapAction &sipStrings_QtNetwork[19391]
#define sipNameNr_SocketType 4473
#define sipName_SocketType &sipStrings_QtNetwork[4473]
#define sipNameNr_Superseded 19402
#define sipName_Superseded &sipStrings_QtNetwork[19402]
#define sipNameNr_Tracestate 19413
#define sipName_Tracestate &sipStrings_QtNetwork[19413]
#define sipNameNr_UrlRequest 19424
#define sipName_UrlRequest &sipStrings_QtNetwork[19424]
#define sipNameNr_VerifyNone 19435
#define sipName_VerifyNone &sipStrings_QtNetwork[19435]
#define sipNameNr_VerifyPeer 15427
#define sipName_VerifyPeer &sipStrings_QtNetwork[15427]
#define sipNameNr___lshift__ 19446
#define sipName___lshift__ &sipStrings_QtNetwork[19446]
#define sipNameNr___rshift__ 19457
#define sipName___rshift__ &sipStrings_QtNetwork[19457]
#define sipNameNr_allCookies 19468
#define sipName_allCookies &sipStrings_QtNetwork[19468]
#define sipNameNr_attributes 19479
#define sipName_attributes &sipStrings_QtNetwork[19479]
#define sipNameNr_childEvent 19490
#define sipName_childEvent &sipStrings_QtNetwork[19490]
#define sipNameNr_expiryDate 19501
#define sipName_expiryDate &sipStrings_QtNetwork[19501]
#define sipNameNr_extensions 19512
#define sipName_extensions &sipStrings_QtNetwork[19512]
#define sipNameNr_fromDevice 19523
#define sipName_fromDevice &sipStrings_QtNetwork[19523]
#define sipNameNr_httpStatus 19534
#define sipName_httpStatus &sipStrings_QtNetwork[19534]
#define sipNameNr_intValueAt 19545
#define sipName_intValueAt &sipStrings_QtNetwork[19545]
#define sipNameNr_isCritical 19556
#define sipName_isCritical &sipStrings_QtNetwork[19556]
#define sipNameNr_isFinished 19567
#define sipName_isFinished &sipStrings_QtNetwork[19567]
#define sipNameNr_isHttpOnly 19578
#define sipName_isHttpOnly &sipStrings_QtNetwork[19578]
#define sipNameNr_isInSubnet 19589
#define sipName_isInSubnet &sipStrings_QtNetwork[19589]
#define sipNameNr_isLoopback 19600
#define sipName_isLoopback &sipStrings_QtNetwork[19600]
#define sipNameNr_issuerInfo 19611
#define sipName_issuerInfo &sipStrings_QtNetwork[19611]
#define sipNameNr_lookupHost 19622
#define sipName_lookupHost &sipStrings_QtNetwork[19622]
#define sipNameNr_nameserver 19633
#define sipName_nameserver &sipStrings_QtNetwork[19633]
#define sipNameNr_passPhrase 19644
#define sipName_passPhrase &sipStrings_QtNetwork[19644]
#define sipNameNr_preference 19655
#define sipName_preference &sipStrings_QtNetwork[19655]
#define sipNameNr_privateKey 19666
#define sipName_privateKey &sipStrings_QtNetwork[19666]
#define sipNameNr_queryProxy 19677
#define sipName_queryProxy &sipStrings_QtNetwork[19677]
#define sipNameNr_rawHeaders 19688
#define sipName_rawHeaders &sipStrings_QtNetwork[19688]
#define sipNameNr_redirected 19699
#define sipName_redirected &sipStrings_QtNetwork[19699]
#define sipNameNr_saveToDisk 19710
#define sipName_saveToDisk &sipStrings_QtNetwork[19710]
#define sipNameNr_senderPort 19721
#define sipName_senderPort &sipStrings_QtNetwork[19721]
#define sipNameNr_serverName 19732
#define sipName_serverName &sipStrings_QtNetwork[19732]
#define sipNameNr_serverPort 13146
#define sipName_serverPort &sipStrings_QtNetwork[13146]
#define sipNameNr_setAddress 19743
#define sipName_setAddress &sipStrings_QtNetwork[19743]
#define sipNameNr_setBaseUrl 19754
#define sipName_setBaseUrl &sipStrings_QtNetwork[19754]
#define sipNameNr_setCiphers 19765
#define sipName_setCiphers &sipStrings_QtNetwork[19765]
#define sipNameNr_setHeaders 19776
#define sipName_setHeaders &sipStrings_QtNetwork[19776]
#define sipNameNr_setNetmask 19787
#define sipName_setNetmask &sipStrings_QtNetwork[19787]
#define sipNameNr_setRequest 19798
#define sipName_setRequest &sipStrings_QtNetwork[19798]
#define sipNameNr_setScopeId 19809
#define sipName_setScopeId &sipStrings_QtNetwork[19809]
#define sipNameNr_socketType 19820
#define sipName_socketType &sipStrings_QtNetwork[19820]
#define sipNameNr_timeToLive 19831
#define sipName_timeToLive &sipStrings_QtNetwork[19831]
#define sipNameNr_timerEvent 19842
#define sipName_timerEvent &sipStrings_QtNetwork[19842]
#define sipNameNr_AlertType 14633
#define sipName_AlertType &sipStrings_QtNetwork[14633]
#define sipNameNr_Attribute 134
#define sipName_Attribute &sipStrings_QtNetwork[134]
#define sipNameNr_Automatic 19853
#define sipName_Automatic &sipStrings_QtNetwork[19853]
#define sipNameNr_Bluetooth 19863
#define sipName_Bluetooth &sipStrings_QtNetwork[19863]
#define sipNameNr_Broadcast 17404
#define sipName_Broadcast &sipStrings_QtNetwork[17404]
#define sipNameNr_ContentID 19873
#define sipName_ContentID &sipStrings_QtNetwork[19873]
#define sipNameNr_DPoPNonce 19883
#define sipName_DPoPNonce &sipStrings_QtNetwork[19883]
#define sipNameNr_DeltaBase 19893
#define sipName_DeltaBase &sipStrings_QtNetwork[19893]
#define sipNameNr_EarlyData 19903
#define sipName_EarlyData &sipStrings_QtNetwork[19903]
#define sipNameNr_Forwarded 19913
#define sipName_Forwarded &sipStrings_QtNetwork[19913]
#define sipNameNr_HttpProxy 19923
#define sipName_HttpProxy &sipStrings_QtNetwork[19923]
#define sipNameNr_Ieee80211 19933
#define sipName_Ieee80211 &sipStrings_QtNetwork[19933]
#define sipNameNr_Ieee80216 19943
#define sipName_Ieee80216 &sipStrings_QtNetwork[19943]
#define sipNameNr_IsRunning 19953
#define sipName_IsRunning &sipStrings_QtNetwork[19953]
#define sipNameNr_KeepAlive 19963
#define sipName_KeepAlive &sipStrings_QtNetwork[19963]
#define sipNameNr_LocalHost 13289
#define sipName_LocalHost &sipStrings_QtNetwork[13289]
#define sipNameNr_LockToken 19973
#define sipName_LockToken &sipStrings_QtNetwork[19973]
#define sipNameNr_MixedType 19983
#define sipName_MixedType &sipStrings_QtNetwork[19983]
#define sipNameNr_Negotiate 19993
#define sipName_Negotiate &sipStrings_QtNetwork[19993]
#define sipNameNr_NoOptions 20003
#define sipName_NoOptions &sipStrings_QtNetwork[20003]
#define sipNameNr_Operation 1870
#define sipName_Operation &sipStrings_QtNetwork[1870]
#define sipNameNr_Overwrite 20013
#define sipName_Overwrite &sipStrings_QtNetwork[20013]
#define sipNameNr_PauseMode 5108
#define sipName_PauseMode &sipStrings_QtNetwork[5108]
#define sipNameNr_PrivMatch 20023
#define sipName_PrivMatch &sipStrings_QtNetwork[20023]
#define sipNameNr_ProxyType 6409
#define sipName_ProxyType &sipStrings_QtNetwork[6409]
#define sipNameNr_PublicKey 3402
#define sipName_PublicKey &sipStrings_QtNetwork[3402]
#define sipNameNr_QHostInfo 20033
#define sipName_QHostInfo &sipStrings_QtNetwork[20033]
#define sipNameNr_QHttpPart 20043
#define sipName_QHttpPart &sipStrings_QtNetwork[20043]
#define sipNameNr_QSslError 20053
#define sipName_QSslError &sipStrings_QtNetwork[20053]
#define sipNameNr_QueryPeer 20063
#define sipName_QueryPeer &sipStrings_QtNetwork[20063]
#define sipNameNr_QueryType 3282
#define sipName_QueryType &sipStrings_QtNetwork[3282]
#define sipNameNr_SetCookie 20073
#define sipName_SetCookie &sipStrings_QtNetwork[20073]
#define sipNameNr_Signature 911
#define sipName_Signature &sipStrings_QtNetwork[911]
#define sipNameNr_SixLoWPAN 20083
#define sipName_SixLoWPAN &sipStrings_QtNetwork[20083]
#define sipNameNr_SslOption 14649
#define sipName_SslOption &sipStrings_QtNetwork[14649]
#define sipNameNr_StatusURI 20093
#define sipName_StatusURI &sipStrings_QtNetwork[20093]
#define sipNameNr_TcpServer 19304
#define sipName_TcpServer &sipStrings_QtNetwork[19304]
#define sipNameNr_TcpSocket 19315
#define sipName_TcpSocket &sipStrings_QtNetwork[19315]
#define sipNameNr_UdpSocket 19326
#define sipName_UdpSocket &sipStrings_QtNetwork[19326]
#define sipNameNr_UnknownCa 20103
#define sipName_UnknownCa &sipStrings_QtNetwork[20103]
#define sipNameNr_UserAgent 20113
#define sipName_UserAgent &sipStrings_QtNetwork[20113]
#define sipNameNr_addresses 20123
#define sipName_addresses &sipStrings_QtNetwork[20123]
#define sipNameNr_alertSent 20133
#define sipName_alertSent &sipStrings_QtNetwork[20133]
#define sipNameNr_algorithm 20143
#define sipName_algorithm &sipStrings_QtNetwork[20143]
#define sipNameNr_attribute 20153
#define sipName_attribute &sipStrings_QtNetwork[20153]
#define sipNameNr_broadcast 20163
#define sipName_broadcast &sipStrings_QtNetwork[20163]
#define sipNameNr_cacheSize 20173
#define sipName_cacheSize &sipStrings_QtNetwork[20173]
#define sipNameNr_connected 11021
#define sipName_connected &sipStrings_QtNetwork[11021]
#define sipNameNr_cookieJar 20183
#define sipName_cookieJar &sipStrings_QtNetwork[20183]
#define sipNameNr_encrypted 20193
#define sipName_encrypted &sipStrings_QtNetwork[20193]
#define sipNameNr_hostFound 20203
#define sipName_hostFound &sipStrings_QtNetwork[20203]
#define sipNameNr_intValues 20213
#define sipName_intValues &sipStrings_QtNetwork[20213]
#define sipNameNr_isExpired 20223
#define sipName_isExpired &sipStrings_QtNetwork[20223]
#define sipNameNr_isMetered 20233
#define sipName_isMetered &sipStrings_QtNetwork[20233]
#define sipNameNr_isRunning 20243
#define sipName_isRunning &sipStrings_QtNetwork[20243]
#define sipNameNr_isSuccess 20253
#define sipName_isSuccess &sipStrings_QtNetwork[20253]
#define sipNameNr_localPort 20263
#define sipName_localPort &sipStrings_QtNetwork[20263]
#define sipNameNr_makeReply 20273
#define sipName_makeReply &sipStrings_QtNetwork[20273]
#define sipNameNr_matchType 20283
#define sipName_matchType &sipStrings_QtNetwork[20283]
#define sipNameNr_normalize 20293
#define sipName_normalize &sipStrings_QtNetwork[20293]
#define sipNameNr_operation 20303
#define sipName_operation &sipStrings_QtNetwork[20303]
#define sipNameNr_pauseMode 20313
#define sipName_pauseMode &sipStrings_QtNetwork[20313]
#define sipNameNr_publicKey 20323
#define sipName_publicKey &sipStrings_QtNetwork[20323]
#define sipNameNr_queryType 20333
#define sipName_queryType &sipStrings_QtNetwork[20333]
#define sipNameNr_rawHeader 20343
#define sipName_rawHeader &sipStrings_QtNetwork[20343]
#define sipNameNr_removeAll 20353
#define sipName_removeAll &sipStrings_QtNetwork[20353]
#define sipNameNr_responder 20363
#define sipName_responder &sipStrings_QtNetwork[20363]
#define sipNameNr_setDomain 20373
#define sipName_setDomain &sipStrings_QtNetwork[20373]
#define sipNameNr_setExpiry 20383
#define sipName_setExpiry &sipStrings_QtNetwork[20383]
#define sipNameNr_setHeader 20393
#define sipName_setHeader &sipStrings_QtNetwork[20393]
#define sipNameNr_setOption 20403
#define sipName_setOption &sipStrings_QtNetwork[20403]
#define sipNameNr_setSecure 20413
#define sipName_setSecure &sipStrings_QtNetwork[20413]
#define sipNameNr_setSender 20423
#define sipName_setSender &sipStrings_QtNetwork[20423]
#define sipNameNr_shortName 20433
#define sipName_shortName &sipStrings_QtNetwork[20433]
#define sipNameNr_sslErrors 20443
#define sipName_sslErrors &sipStrings_QtNetwork[20443]
#define sipNameNr_toRawForm 20453
#define sipName_toRawForm &sipStrings_QtNetwork[20453]
#define sipNameNr_writeData 20463
#define sipName_writeData &sipStrings_QtNetwork[20463]
#define sipNameNr_AcceptCH 20473
#define sipName_AcceptCH &sipStrings_QtNetwork[20473]
#define sipNameNr_BindFlag 5800
#define sipName_BindFlag &sipStrings_QtNetwork[5800]
#define sipNameNr_CPEPInfo 20482
#define sipName_CPEPInfo &sipStrings_QtNetwork[20482]
#define sipNameNr_Cellular 20491
#define sipName_Cellular &sipStrings_QtNetwork[20491]
#define sipNameNr_DnsEntry 20500
#define sipName_DnsEntry &sipStrings_QtNetwork[20500]
#define sipNameNr_DtlsV1_0 20509
#define sipName_DtlsV1_0 &sipStrings_QtNetwork[20509]
#define sipNameNr_DtlsV1_2 20518
#define sipName_DtlsV1_2 &sipStrings_QtNetwork[20518]
#define sipNameNr_Ethernet 20527
#define sipName_Ethernet &sipStrings_QtNetwork[20527]
#define sipNameNr_ExpectCT 20536
#define sipName_ExpectCT &sipStrings_QtNetwork[20536]
#define sipNameNr_Ieee1394 20545
#define sipName_Ieee1394 &sipStrings_QtNetwork[20545]
#define sipNameNr_Location 14314
#define sipName_Location &sipStrings_QtNetwork[14314]
#define sipNameNr_Loopback 19602
#define sipName_Loopback &sipStrings_QtNetwork[19602]
#define sipNameNr_PingFrom 20554
#define sipName_PingFrom &sipStrings_QtNetwork[20554]
#define sipNameNr_Position 20563
#define sipName_Position &sipStrings_QtNetwork[20563]
#define sipNameNr_Priority 5878
#define sipName_Priority &sipStrings_QtNetwork[5878]
#define sipNameNr_PrivCert 20572
#define sipName_PrivCert &sipStrings_QtNetwork[20572]
#define sipNameNr_Protocol 582
#define sipName_Protocol &sipStrings_QtNetwork[582]
#define sipNameNr_SameSite 6385
#define sipName_SameSite &sipStrings_QtNetwork[6385]
#define sipNameNr_Selector 1054
#define sipName_Selector &sipStrings_QtNetwork[1054]
#define sipNameNr_SslError 10462
#define sipName_SslError &sipStrings_QtNetwork[10462]
#define sipNameNr_Standard 20581
#define sipName_Standard &sipStrings_QtNetwork[20581]
#define sipNameNr_Wildcard 20590
#define sipName_Wildcard &sipStrings_QtNetwork[20590]
#define sipNameNr___hash__ 20599
#define sipName___hash__ &sipStrings_QtNetwork[20599]
#define sipNameNr_boundary 20608
#define sipName_boundary &sipStrings_QtNetwork[20608]
#define sipNameNr_contains 20617
#define sipName_contains &sipStrings_QtNetwork[20617]
#define sipNameNr_encoding 20626
#define sipName_encoding &sipStrings_QtNetwork[20626]
#define sipNameNr_exchange 20635
#define sipName_exchange &sipStrings_QtNetwork[20635]
#define sipNameNr_fileName 20644
#define sipName_fileName &sipStrings_QtNetwork[20644]
#define sipNameNr_finished 20653
#define sipName_finished &sipStrings_QtNetwork[20653]
#define sipNameNr_fromData 20662
#define sipName_fromData &sipStrings_QtNetwork[20662]
#define sipNameNr_fromFile 20671
#define sipName_fromFile &sipStrings_QtNetwork[20671]
#define sipNameNr_fromName 20680
#define sipName_fromName &sipStrings_QtNetwork[20680]
#define sipNameNr_fromPath 20689
#define sipName_fromPath &sipStrings_QtNetwork[20689]
#define sipNameNr_hasError 20698
#define sipName_hasError &sipStrings_QtNetwork[20698]
#define sipNameNr_hopLimit 20707
#define sipName_hopLimit &sipStrings_QtNetwork[20707]
#define sipNameNr_hostName 20716
#define sipName_hostName &sipStrings_QtNetwork[20716]
#define sipNameNr_identity 20725
#define sipName_identity &sipStrings_QtNetwork[20725]
#define sipNameNr_instance 20734
#define sipName_instance &sipStrings_QtNetwork[20734]
#define sipNameNr_intValue 20743
#define sipName_intValue &sipStrings_QtNetwork[20743]
#define sipNameNr_isGlobal 20752
#define sipName_isGlobal &sipStrings_QtNetwork[20752]
#define sipNameNr_isSecure 20761
#define sipName_isSecure &sipStrings_QtNetwork[20761]
#define sipNameNr_longName 20770
#define sipName_longName &sipStrings_QtNetwork[20770]
#define sipNameNr_lookupId 20779
#define sipName_lookupId &sipStrings_QtNetwork[20779]
#define sipNameNr_metaData 20788
#define sipName_metaData &sipStrings_QtNetwork[20788]
#define sipNameNr_mimeType 20797
#define sipName_mimeType &sipStrings_QtNetwork[20797]
#define sipNameNr_password 20806
#define sipName_password &sipStrings_QtNetwork[20806]
#define sipNameNr_peerName 20815
#define sipName_peerName &sipStrings_QtNetwork[20815]
#define sipNameNr_peerPort 20824
#define sipName_peerPort &sipStrings_QtNetwork[20824]
#define sipNameNr_priority 20833
#define sipName_priority &sipStrings_QtNetwork[20833]
#define sipNameNr_protocol 20842
#define sipName_protocol &sipStrings_QtNetwork[20842]
#define sipNameNr_readBody 20851
#define sipName_readBody &sipStrings_QtNetwork[20851]
#define sipNameNr_readData 20860
#define sipName_readData &sipStrings_QtNetwork[20860]
#define sipNameNr_readJson 20869
#define sipName_readJson &sipStrings_QtNetwork[20869]
#define sipNameNr_readText 20878
#define sipName_readText &sipStrings_QtNetwork[20878]
#define sipNameNr_removeAt 20887
#define sipName_removeAt &sipStrings_QtNetwork[20887]
#define sipNameNr_selector 20896
#define sipName_selector &sipStrings_QtNetwork[20896]
#define sipNameNr_setCache 20905
#define sipName_setCache &sipStrings_QtNetwork[20905]
#define sipNameNr_setError 20914
#define sipName_setError &sipStrings_QtNetwork[20914]
#define sipNameNr_setProxy 20923
#define sipName_setProxy &sipStrings_QtNetwork[20923]
#define sipNameNr_setValue 20932
#define sipName_setValue &sipStrings_QtNetwork[20932]
#define sipNameNr_skipData 20941
#define sipName_skipData &sipStrings_QtNetwork[20941]
#define sipNameNr_storeDir 20950
#define sipName_storeDir &sipStrings_QtNetwork[20950]
#define sipNameNr_supports 20959
#define sipName_supports &sipStrings_QtNetwork[20959]
#define sipNameNr_timedOut 20968
#define sipName_timedOut &sipStrings_QtNetwork[20968]
#define sipNameNr_toString 20977
#define sipName_toString &sipStrings_QtNetwork[20977]
#define sipNameNr_usedBits 20986
#define sipName_usedBits &sipStrings_QtNetwork[20986]
#define sipNameNr_userName 20995
#define sipName_userName &sipStrings_QtNetwork[20995]
#define sipNameNr_AltUsed 21004
#define sipName_AltUsed &sipStrings_QtNetwork[21004]
#define sipNameNr_AnyIPv4 21012
#define sipName_AnyIPv4 &sipStrings_QtNetwork[21012]
#define sipNameNr_AnyIPv6 21020
#define sipName_AnyIPv6 &sipStrings_QtNetwork[21020]
#define sipNameNr_CDNLoop 21028
#define sipName_CDNLoop &sipStrings_QtNetwork[21028]
#define sipNameNr_DANE_EE 21036
#define sipName_DANE_EE &sipStrings_QtNetwork[21036]
#define sipNameNr_DANE_TA 21044
#define sipName_DANE_TA &sipStrings_QtNetwork[21044]
#define sipNameNr_Default 21052
#define sipName_Default &sipStrings_QtNetwork[21052]
#define sipNameNr_Expires 21060
#define sipName_Expires &sipStrings_QtNetwork[21060]
#define sipNameNr_Feature 3874
#define sipName_Feature &sipStrings_QtNetwork[3874]
#define sipNameNr_Hobareg 21068
#define sipName_Hobareg &sipStrings_QtNetwork[21068]
#define sipNameNr_IfMatch 21076
#define sipName_IfMatch &sipStrings_QtNetwork[21076]
#define sipNameNr_IfRange 21084
#define sipName_IfRange &sipStrings_QtNetwork[21084]
#define sipNameNr_KeyType 16683
#define sipName_KeyType &sipStrings_QtNetwork[16683]
#define sipNameNr_Metered 20235
#define sipName_Metered &sipStrings_QtNetwork[20235]
#define sipNameNr_NoError 21092
#define sipName_NoError &sipStrings_QtNetwork[21092]
#define sipNameNr_NoProxy 21100
#define sipName_NoProxy &sipStrings_QtNetwork[21100]
#define sipNameNr_PKIX_EE 21108
#define sipName_PKIX_EE &sipStrings_QtNetwork[21108]
#define sipNameNr_PKIX_TA 21116
#define sipName_PKIX_TA &sipStrings_QtNetwork[21116]
#define sipNameNr_PrivSel 21124
#define sipName_PrivSel &sipStrings_QtNetwork[21124]
#define sipNameNr_QSslKey 21132
#define sipName_QSslKey &sipStrings_QtNetwork[21132]
#define sipNameNr_RawForm 7044
#define sipName_RawForm &sipStrings_QtNetwork[7044]
#define sipNameNr_Referer 21140
#define sipName_Referer &sipStrings_QtNetwork[21140]
#define sipNameNr_Refresh 21148
#define sipName_Refresh &sipStrings_QtNetwork[21148]
#define sipNameNr_Revoked 11119
#define sipName_Revoked &sipStrings_QtNetwork[11119]
#define sipNameNr_SslMode 10483
#define sipName_SslMode &sipStrings_QtNetwork[10483]
#define sipNameNr_Timeout 7665
#define sipName_Timeout &sipStrings_QtNetwork[7665]
#define sipNameNr_TlsV1_0 21156
#define sipName_TlsV1_0 &sipStrings_QtNetwork[21156]
#define sipNameNr_TlsV1_1 21164
#define sipName_TlsV1_1 &sipStrings_QtNetwork[21164]
#define sipNameNr_TlsV1_2 21172
#define sipName_TlsV1_2 &sipStrings_QtNetwork[21172]
#define sipNameNr_TlsV1_3 21180
#define sipName_TlsV1_3 &sipStrings_QtNetwork[21180]
#define sipNameNr_Trailer 21188
#define sipName_Trailer &sipStrings_QtNetwork[21188]
#define sipNameNr_Unknown 5775
#define sipName_Unknown &sipStrings_QtNetwork[5775]
#define sipNameNr_Upgrade 21196
#define sipName_Upgrade &sipStrings_QtNetwork[21196]
#define sipNameNr_Urgency 21204
#define sipName_Urgency &sipStrings_QtNetwork[21204]
#define sipNameNr_UserMax 21212
#define sipName_UserMax &sipStrings_QtNetwork[21212]
#define sipNameNr_Virtual 21220
#define sipName_Virtual &sipStrings_QtNetwork[21220]
#define sipNameNr_Warning 21228
#define sipName_Warning &sipStrings_QtNetwork[21228]
#define sipNameNr_address 21236
#define sipName_address &sipStrings_QtNetwork[21236]
#define sipNameNr_baseUrl 21244
#define sipName_baseUrl &sipStrings_QtNetwork[21244]
#define sipNameNr_ciphers 21252
#define sipName_ciphers &sipStrings_QtNetwork[21252]
#define sipNameNr_headers 21260
#define sipName_headers &sipStrings_QtNetwork[21260]
#define sipNameNr_isEmpty 21268
#define sipName_isEmpty &sipStrings_QtNetwork[21268]
#define sipNameNr_isEqual 21276
#define sipName_isEqual &sipStrings_QtNetwork[21276]
#define sipNameNr_isValid 21284
#define sipName_isValid &sipStrings_QtNetwork[21284]
#define sipNameNr_manager 21292
#define sipName_manager &sipStrings_QtNetwork[21292]
#define sipNameNr_maxSize 21300
#define sipName_maxSize &sipStrings_QtNetwork[21300]
#define sipNameNr_netmask 21308
#define sipName_netmask &sipStrings_QtNetwork[21308]
#define sipNameNr_options 21316
#define sipName_options &sipStrings_QtNetwork[21316]
#define sipNameNr_prepare 21324
#define sipName_prepare &sipStrings_QtNetwork[21324]
#define sipNameNr_replace 21332
#define sipName_replace &sipStrings_QtNetwork[21332]
#define sipNameNr_request 21340
#define sipName_request &sipStrings_QtNetwork[21340]
#define sipNameNr_reserve 21348
#define sipName_reserve &sipStrings_QtNetwork[21348]
#define sipNameNr_scopeId 21356
#define sipName_scopeId &sipStrings_QtNetwork[21356]
#define sipNameNr_setBody 21364
#define sipName_setBody &sipStrings_QtNetwork[21364]
#define sipNameNr_setData 21372
#define sipName_setData &sipStrings_QtNetwork[21372]
#define sipNameNr_setHost 21380
#define sipName_setHost &sipStrings_QtNetwork[21380]
#define sipNameNr_setName 21388
#define sipName_setName &sipStrings_QtNetwork[21388]
#define sipNameNr_setPath 21396
#define sipName_setPath &sipStrings_QtNetwork[21396]
#define sipNameNr_setPort 21404
#define sipName_setPort &sipStrings_QtNetwork[21404]
#define sipNameNr_setType 21412
#define sipName_setType &sipStrings_QtNetwork[21412]
#define sipNameNr_setUser 21420
#define sipName_setUser &sipStrings_QtNetwork[21420]
#define sipNameNr_subject 21428
#define sipName_subject &sipStrings_QtNetwork[21428]
#define sipNameNr_timeout 21436
#define sipName_timeout &sipStrings_QtNetwork[21436]
#define sipNameNr_valueAt 21444
#define sipName_valueAt &sipStrings_QtNetwork[21444]
#define sipNameNr_version 11518
#define sipName_version &sipStrings_QtNetwork[11518]
#define sipNameNr_Accept 11443
#define sipName_Accept &sipStrings_QtNetwork[11443]
#define sipNameNr_Alerts 21452
#define sipName_Alerts &sipStrings_QtNetwork[21452]
#define sipNameNr_AltSvc 21459
#define sipName_AltSvc &sipStrings_QtNetwork[21459]
#define sipNameNr_CanBus 21466
#define sipName_CanBus &sipStrings_QtNetwork[21466]
#define sipNameNr_Cookie 14988
#define sipName_Cookie &sipStrings_QtNetwork[14988]
#define sipNameNr_Expect 21473
#define sipName_Expect &sipStrings_QtNetwork[21473]
#define sipNameNr_Manual 21480
#define sipName_Manual &sipStrings_QtNetwork[21480]
#define sipNameNr_OSCORE 21487
#define sipName_OSCORE &sipStrings_QtNetwork[21487]
#define sipNameNr_Online 21494
#define sipName_Online &sipStrings_QtNetwork[21494]
#define sipNameNr_Opaque 21501
#define sipName_Opaque &sipStrings_QtNetwork[21501]
#define sipNameNr_Option 3135
#define sipName_Option &sipStrings_QtNetwork[3135]
#define sipNameNr_Origin 6087
#define sipName_Origin &sipStrings_QtNetwork[6087]
#define sipNameNr_Phonet 21508
#define sipName_Phonet &sipStrings_QtNetwork[21508]
#define sipNameNr_PingTo 21515
#define sipName_PingTo &sipStrings_QtNetwork[21515]
#define sipNameNr_Pragma 21522
#define sipName_Pragma &sipStrings_QtNetwork[21522]
#define sipNameNr_Prefer 21529
#define sipName_Prefer &sipStrings_QtNetwork[21529]
#define sipNameNr_Server 9873
#define sipName_Server &sipStrings_QtNetwork[9873]
#define sipNameNr_Sha256 21536
#define sipName_Sha256 &sipStrings_QtNetwork[21536]
#define sipNameNr_Sha512 21543
#define sipName_Sha512 &sipStrings_QtNetwork[21543]
#define sipNameNr_Socket 14604
#define sipName_Socket &sipStrings_QtNetwork[14604]
#define sipNameNr_Strict 21550
#define sipName_Strict &sipStrings_QtNetwork[21550]
#define sipNameNr_Sunset 21557
#define sipName_Sunset &sipStrings_QtNetwork[21557]
#define sipNameNr___eq__ 21564
#define sipName___eq__ &sipStrings_QtNetwork[21564]
#define sipNameNr___ne__ 21571
#define sipName___ne__ &sipStrings_QtNetwork[21571]
#define sipNameNr_append 21578
#define sipName_append &sipStrings_QtNetwork[21578]
#define sipNameNr_device 21585
#define sipName_device &sipStrings_QtNetwork[21585]
#define sipNameNr_digest 21592
#define sipName_digest &sipStrings_QtNetwork[21592]
#define sipNameNr_domain 21599
#define sipName_domain &sipStrings_QtNetwork[21599]
#define sipNameNr_expire 21606
#define sipName_expire &sipStrings_QtNetwork[21606]
#define sipNameNr_expiry 21613
#define sipName_expiry &sipStrings_QtNetwork[21613]
#define sipNameNr_format 21620
#define sipName_format &sipStrings_QtNetwork[21620]
#define sipNameNr_handle 21627
#define sipName_handle &sipStrings_QtNetwork[21627]
#define sipNameNr_header 21634
#define sipName_header &sipStrings_QtNetwork[21634]
#define sipNameNr_insert 21641
#define sipName_insert &sipStrings_QtNetwork[21641]
#define sipNameNr_isNull 21648
#define sipName_isNull &sipStrings_QtNetwork[21648]
#define sipNameNr_length 21655
#define sipName_length &sipStrings_QtNetwork[21655]
#define sipNameNr_listen 21662
#define sipName_listen &sipStrings_QtNetwork[21662]
#define sipNameNr_lookup 21669
#define sipName_lookup &sipStrings_QtNetwork[21669]
#define sipNameNr_nameAt 21676
#define sipName_nameAt &sipStrings_QtNetwork[21676]
#define sipNameNr_option 21683
#define sipName_option &sipStrings_QtNetwork[21683]
#define sipNameNr_parent 18581
#define sipName_parent &sipStrings_QtNetwork[18581]
#define sipNameNr_remove 21690
#define sipName_remove &sipStrings_QtNetwork[21690]
#define sipNameNr_resume 21697
#define sipName_resume &sipStrings_QtNetwork[21697]
#define sipNameNr_setUrl 21704
#define sipName_setUrl &sipStrings_QtNetwork[21704]
#define sipNameNr_syntax 21711
#define sipName_syntax &sipStrings_QtNetwork[21711]
#define sipNameNr_target 21718
#define sipName_target &sipStrings_QtNetwork[21718]
#define sipNameNr_toText 21725
#define sipName_toText &sipStrings_QtNetwork[21725]
#define sipNameNr_values 21732
#define sipName_values &sipStrings_QtNetwork[21732]
#define sipNameNr_verify 21739
#define sipName_verify &sipStrings_QtNetwork[21739]
#define sipNameNr_weight 21746
#define sipName_weight &sipStrings_QtNetwork[21746]
#define sipNameNr_Allow 21753
#define sipName_Allow &sipStrings_QtNetwork[21753]
#define sipNameNr_CNAME 21759
#define sipName_CNAME &sipStrings_QtNetwork[21759]
#define sipNameNr_Close 21765
#define sipName_Close &sipStrings_QtNetwork[21765]
#define sipNameNr_Depth 11957
#define sipName_Depth &sipStrings_QtNetwork[11957]
#define sipNameNr_Error 1197
#define sipName_Error &sipStrings_QtNetwork[1197]
#define sipNameNr_Exact 21771
#define sipName_Exact &sipStrings_QtNetwork[21771]
#define sipNameNr_Fatal 4166
#define sipName_Fatal &sipStrings_QtNetwork[4166]
#define sipNameNr_Label 21777
#define sipName_Label &sipStrings_QtNetwork[21777]
#define sipNameNr_Local 18750
#define sipName_Local &sipStrings_QtNetwork[18750]
#define sipNameNr_Meter 21783
#define sipName_Meter &sipStrings_QtNetwork[21783]
#define sipNameNr_MlDsa 21789
#define sipName_MlDsa &sipStrings_QtNetwork[21789]
#define sipNameNr_None_ 21795
#define sipName_None_ &sipStrings_QtNetwork[21795]
#define sipNameNr_Range 17460
#define sipName_Range &sipStrings_QtNetwork[17460]
#define sipNameNr_Topic 21801
#define sipName_Topic &sipStrings_QtNetwork[21801]
#define sipNameNr_abort 21807
#define sipName_abort &sipStrings_QtNetwork[21807]
#define sipNameNr_atEnd 21813
#define sipName_atEnd &sipStrings_QtNetwork[21813]
#define sipNameNr_cache 21819
#define sipName_cache &sipStrings_QtNetwork[21819]
#define sipNameNr_clear 21825
#define sipName_clear &sipStrings_QtNetwork[21825]
#define sipNameNr_close 21831
#define sipName_close &sipStrings_QtNetwork[21831]
#define sipNameNr_error 21837
#define sipName_error &sipStrings_QtNetwork[21837]
#define sipNameNr_event 21843
#define sipName_event &sipStrings_QtNetwork[21843]
#define sipNameNr_flags 21849
#define sipName_flags &sipStrings_QtNetwork[21849]
#define sipNameNr_flush 21855
#define sipName_flush &sipStrings_QtNetwork[21855]
#define sipNameNr_index 21861
#define sipName_index &sipStrings_QtNetwork[21861]
#define sipNameNr_msecs 21867
#define sipName_msecs &sipStrings_QtNetwork[21867]
#define sipNameNr_patch 21873
#define sipName_patch &sipStrings_QtNetwork[21873]
#define sipNameNr_proxy 21879
#define sipName_proxy &sipStrings_QtNetwork[21879]
#define sipNameNr_query 21885
#define sipName_query &sipStrings_QtNetwork[21885]
#define sipNameNr_realm 21891
#define sipName_realm &sipStrings_QtNetwork[21891]
#define sipNameNr_reset 21897
#define sipName_reset &sipStrings_QtNetwork[21897]
#define sipNameNr_setIp 21903
#define sipName_setIp &sipStrings_QtNetwork[21903]
#define sipNameNr_state 19418
#define sipName_state &sipStrings_QtNetwork[19418]
#define sipNameNr_toDer 21909
#define sipName_toDer &sipStrings_QtNetwork[21909]
#define sipNameNr_toPem 21915
#define sipName_toPem &sipStrings_QtNetwork[21915]
#define sipNameNr_usage 21921
#define sipName_usage &sipStrings_QtNetwork[21921]
#define sipNameNr_value 21927
#define sipName_value &sipStrings_QtNetwork[21927]
#define sipNameNr_AAAA 21933
#define sipName_AAAA &sipStrings_QtNetwork[21933]
#define sipNameNr_ALPN 21938
#define sipName_ALPN &sipStrings_QtNetwork[21938]
#define sipNameNr_Cert 19155
#define sipName_Cert &sipStrings_QtNetwork[19155]
#define sipNameNr_DASL 21943
#define sipName_DASL &sipStrings_QtNetwork[21943]
#define sipNameNr_DPoP 21948
#define sipName_DPoP &sipStrings_QtNetwork[21948]
#define sipNameNr_Date 13116
#define sipName_Date &sipStrings_QtNetwork[13116]
#define sipNameNr_Dtls 21953
#define sipName_Dtls &sipStrings_QtNetwork[21953]
#define sipNameNr_ETag 21958
#define sipName_ETag &sipStrings_QtNetwork[21958]
#define sipNameNr_Fddi 21963
#define sipName_Fddi &sipStrings_QtNetwork[21963]
#define sipNameNr_From 20558
#define sipName_From &sipStrings_QtNetwork[20558]
#define sipNameNr_Full 21968
#define sipName_Full &sipStrings_QtNetwork[21968]
#define sipNameNr_Good 21973
#define sipName_Good &sipStrings_QtNetwork[21973]
#define sipNameNr_Host 3587
#define sipName_Host &sipStrings_QtNetwork[3587]
#define sipNameNr_IsUp 21978
#define sipName_IsUp &sipStrings_QtNetwork[21978]
#define sipNameNr_Link 21983
#define sipName_Link &sipStrings_QtNetwork[21983]
#define sipNameNr_Null 21650
#define sipName_Null &sipStrings_QtNetwork[21650]
#define sipNameNr_Ocsp 21988
#define sipName_Ocsp &sipStrings_QtNetwork[21988]
#define sipNameNr_QSsl 21993
#define sipName_QSsl &sipStrings_QtNetwork[21993]
#define sipNameNr_SLUG 21998
#define sipName_SLUG &sipStrings_QtNetwork[21998]
#define sipNameNr_SPKI 22003
#define sipName_SPKI &sipStrings_QtNetwork[22003]
#define sipNameNr_Site 6389
#define sipName_Site &sipStrings_QtNetwork[6389]
#define sipNameNr_Slip 22008
#define sipName_Slip &sipStrings_QtNetwork[22008]
#define sipNameNr_TLSA 22013
#define sipName_TLSA &sipStrings_QtNetwork[22013]
#define sipNameNr_Type 471
#define sipName_Type &sipStrings_QtNetwork[471]
#define sipNameNr_User 21423
#define sipName_User &sipStrings_QtNetwork[21423]
#define sipNameNr_Vary 18607
#define sipName_Vary &sipStrings_QtNetwork[18607]
#define sipNameNr_WiFi 22018
#define sipName_WiFi &sipStrings_QtNetwork[22018]
#define sipNameNr_Wifi 22023
#define sipName_Wifi &sipStrings_QtNetwork[22023]
#define sipNameNr_bind 22028
#define sipName_bind &sipStrings_QtNetwork[22028]
#define sipNameNr_data 22033
#define sipName_data &sipStrings_QtNetwork[22033]
#define sipNameNr_form 11198
#define sipName_form &sipStrings_QtNetwork[11198]
#define sipNameNr_head 22038
#define sipName_head &sipStrings_QtNetwork[22038]
#define sipNameNr_host 22043
#define sipName_host &sipStrings_QtNetwork[22043]
#define sipNameNr_load 22048
#define sipName_load &sipStrings_QtNetwork[22048]
#define sipNameNr_mode 22053
#define sipName_mode &sipStrings_QtNetwork[22053]
#define sipNameNr_name 1974
#define sipName_name &sipStrings_QtNetwork[1974]
#define sipNameNr_open 22058
#define sipName_open &sipStrings_QtNetwork[22058]
#define sipNameNr_part 22063
#define sipName_part &sipStrings_QtNetwork[22063]
#define sipNameNr_path 22068
#define sipName_path &sipStrings_QtNetwork[22068]
#define sipNameNr_port 17604
#define sipName_port &sipStrings_QtNetwork[17604]
#define sipNameNr_post 22073
#define sipName_post &sipStrings_QtNetwork[22073]
#define sipNameNr_seek 22078
#define sipName_seek &sipStrings_QtNetwork[22078]
#define sipNameNr_size 22083
#define sipName_size &sipStrings_QtNetwork[22083]
#define sipNameNr_swap 22088
#define sipName_swap &sipStrings_QtNetwork[22088]
#define sipNameNr_type 22093
#define sipName_type &sipStrings_QtNetwork[22093]
#define sipNameNr_user 22098
#define sipName_user &sipStrings_QtNetwork[22098]
#define sipNameNr_AIM 22103
#define sipName_AIM &sipStrings_QtNetwork[22103]
#define sipNameNr_ANY 22107
#define sipName_ANY &sipStrings_QtNetwork[22107]
#define sipNameNr_Age 10127
#define sipName_Age &sipStrings_QtNetwork[10127]
#define sipNameNr_Any 22111
#define sipName_Any &sipStrings_QtNetwork[22111]
#define sipNameNr_DAV 22115
#define sipName_DAV &sipStrings_QtNetwork[22115]
#define sipNameNr_Der 21911
#define sipName_Der &sipStrings_QtNetwork[21911]
#define sipNameNr_Dsa 21791
#define sipName_Dsa &sipStrings_QtNetwork[21791]
#define sipNameNr_Key 3408
#define sipName_Key &sipStrings_QtNetwork[3408]
#define sipNameNr_Lax 22119
#define sipName_Lax &sipStrings_QtNetwork[22119]
#define sipNameNr_NEL 22123
#define sipName_NEL &sipStrings_QtNetwork[22123]
#define sipNameNr_PTR 22127
#define sipName_PTR &sipStrings_QtNetwork[22127]
#define sipNameNr_Pem 21917
#define sipName_Pem &sipStrings_QtNetwork[21917]
#define sipNameNr_Ppp 22131
#define sipName_Ppp &sipStrings_QtNetwork[22131]
#define sipNameNr_Psk 22135
#define sipName_Psk &sipStrings_QtNetwork[22135]
#define sipNameNr_Rsa 22139
#define sipName_Rsa &sipStrings_QtNetwork[22139]
#define sipNameNr_SRV 22143
#define sipName_SRV &sipStrings_QtNetwork[22143]
#define sipNameNr_TCN 22147
#define sipName_TCN &sipStrings_QtNetwork[22147]
#define sipNameNr_TTL 22151
#define sipName_TTL &sipStrings_QtNetwork[22151]
#define sipNameNr_TXT 22155
#define sipName_TXT &sipStrings_QtNetwork[22155]
#define sipNameNr_Via 22159
#define sipName_Via &sipStrings_QtNetwork[22159]
#define sipNameNr_get 21721
#define sipName_get &sipStrings_QtNetwork[21721]
#define sipNameNr_oid 22163
#define sipName_oid &sipStrings_QtNetwork[22163]
#define sipNameNr_pos 22167
#define sipName_pos &sipStrings_QtNetwork[22167]
#define sipNameNr_put 15749
#define sipName_put &sipStrings_QtNetwork[15749]
#define sipNameNr_url 22171
#define sipName_url &sipStrings_QtNetwork[22171]
#define sipNameNr_Dh 22175
#define sipName_Dh &sipStrings_QtNetwork[22175]
#define sipNameNr_Ec 22178
#define sipName_Ec &sipStrings_QtNetwork[22178]
#define sipNameNr_IM 22104
#define sipName_IM &sipStrings_QtNetwork[22104]
#define sipNameNr_If 22181
#define sipName_If &sipStrings_QtNetwork[22181]
#define sipNameNr_MX 22184
#define sipName_MX &sipStrings_QtNetwork[22184]
#define sipNameNr_NS 22187
#define sipName_NS &sipStrings_QtNetwork[22187]
#define sipNameNr_TE 22190
#define sipName_TE &sipStrings_QtNetwork[22190]
#define sipNameNr_id 7647
#define sipName_id &sipStrings_QtNetwork[7647]
#define sipNameNr_ip 22010
#define sipName_ip &sipStrings_QtNetwork[22010]
#define sipNameNr_ok 22193
#define sipName_ok &sipStrings_QtNetwork[22193]
#define sipNameNr_A 21050
#define sipName_A &sipStrings_QtNetwork[21050]

#define sipMalloc                   sipAPI_QtNetwork->api_malloc
#define sipFree                     sipAPI_QtNetwork->api_free
#define sipBuildResult              sipAPI_QtNetwork->api_build_result
#define sipCallMethod               sipAPI_QtNetwork->api_call_method
#define sipCallProcedureMethod      sipAPI_QtNetwork->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtNetwork->api_call_error_handler
#define sipParseResultEx            sipAPI_QtNetwork->api_parse_result_ex
#define sipParseResult              sipAPI_QtNetwork->api_parse_result
#define sipParseArgs                sipAPI_QtNetwork->api_parse_args
#define sipParseKwdArgs             sipAPI_QtNetwork->api_parse_kwd_args
#define sipParsePair                sipAPI_QtNetwork->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtNetwork->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtNetwork->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtNetwork->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtNetwork->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtNetwork->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtNetwork->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtNetwork->api_add_exception
#define sipNoFunction               sipAPI_QtNetwork->api_no_function
#define sipNoMethod                 sipAPI_QtNetwork->api_no_method
#define sipAbstractMethod           sipAPI_QtNetwork->api_abstract_method
#define sipBadClass                 sipAPI_QtNetwork->api_bad_class
#define sipBadCatcherResult         sipAPI_QtNetwork->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtNetwork->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtNetwork->api_bad_operator_arg
#define sipTrace                    sipAPI_QtNetwork->api_trace
#define sipTransferBack             sipAPI_QtNetwork->api_transfer_back
#define sipTransferTo               sipAPI_QtNetwork->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtNetwork->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtNetwork->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtNetwork->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtNetwork->api_voidptr_type
#define sipGetPyObject              sipAPI_QtNetwork->api_get_pyobject
#define sipGetAddress               sipAPI_QtNetwork->api_get_address
#define sipGetMixinAddress          sipAPI_QtNetwork->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtNetwork->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtNetwork->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtNetwork->api_call_hook
#define sipEndThread                sipAPI_QtNetwork->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtNetwork->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtNetwork->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtNetwork->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtNetwork->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtNetwork->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtNetwork->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtNetwork->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtNetwork->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtNetwork->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtNetwork->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtNetwork->api_convert_to_bool
#define sipReleaseType              sipAPI_QtNetwork->api_release_type
#define sipConvertFromType          sipAPI_QtNetwork->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtNetwork->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtNetwork->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtNetwork->api_convert_from_enum
#define sipGetState                 sipAPI_QtNetwork->api_get_state
#define sipExportSymbol             sipAPI_QtNetwork->api_export_symbol
#define sipImportSymbol             sipAPI_QtNetwork->api_import_symbol
#define sipFindType                 sipAPI_QtNetwork->api_find_type
#define sipBytes_AsChar             sipAPI_QtNetwork->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtNetwork->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtNetwork->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtNetwork->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtNetwork->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtNetwork->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtNetwork->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtNetwork->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtNetwork->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtNetwork->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtNetwork->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtNetwork->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtNetwork->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtNetwork->api_get_reference
#define sipKeepReference            sipAPI_QtNetwork->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtNetwork->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtNetwork->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtNetwork->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtNetwork->api_type_scope
#define sipResolveTypedef           sipAPI_QtNetwork->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtNetwork->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtNetwork->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtNetwork->api_init_mixin
#define sipExportModule             sipAPI_QtNetwork->api_export_module
#define sipInitModule               sipAPI_QtNetwork->api_init_module
#define sipGetInterpreter           sipAPI_QtNetwork->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtNetwork->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtNetwork->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtNetwork->api_py_type_dict
#define sipPyTypeName               sipAPI_QtNetwork->api_py_type_name
#define sipGetCFunction             sipAPI_QtNetwork->api_get_c_function
#define sipGetMethod                sipAPI_QtNetwork->api_get_method
#define sipFromMethod               sipAPI_QtNetwork->api_from_method
#define sipGetDate                  sipAPI_QtNetwork->api_get_date
#define sipFromDate                 sipAPI_QtNetwork->api_from_date
#define sipGetDateTime              sipAPI_QtNetwork->api_get_datetime
#define sipFromDateTime             sipAPI_QtNetwork->api_from_datetime
#define sipGetTime                  sipAPI_QtNetwork->api_get_time
#define sipFromTime                 sipAPI_QtNetwork->api_from_time
#define sipIsUserType               sipAPI_QtNetwork->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtNetwork->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtNetwork->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtNetwork->api_unicode_write
#define sipUnicodeData              sipAPI_QtNetwork->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtNetwork->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtNetwork->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtNetwork->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtNetwork->api_is_derived_class
#define sipGetUserObject            sipAPI_QtNetwork->api_get_user_object
#define sipSetUserObject            sipAPI_QtNetwork->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtNetwork->api_register_event_handler
#define sipConvertToArray           sipAPI_QtNetwork->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtNetwork->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtNetwork->api_enable_gc
#define sipPrintObject              sipAPI_QtNetwork->api_print_object
#define sipLong_AsChar              sipAPI_QtNetwork->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtNetwork->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtNetwork->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtNetwork->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtNetwork->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtNetwork->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtNetwork->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtNetwork->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtNetwork->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtNetwork->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtNetwork->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtNetwork->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtNetwork->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtNetwork->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtNetwork->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtNetwork->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtNetwork->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtNetwork->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtNetwork->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtNetwork->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtNetwork->api_release_type_us
#define sipIsPyMethod               sipAPI_QtNetwork->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtNetwork[];

#define sipType_QNetworkCacheMetaData sipExportedTypes_QtNetwork[87]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkCacheMetaData;

#define sipType_QAbstractNetworkCache sipExportedTypes_QtNetwork[0]

extern sipClassTypeDef sipTypeDef_QtNetwork_QAbstractNetworkCache;

#define sipType_QAbstractSocket sipExportedTypes_QtNetwork[1]

#define sipType_QAbstractSocket_PauseMode sipExportedTypes_QtNetwork[4]

#define sipType_QAbstractSocket_BindFlag sipExportedTypes_QtNetwork[2]

#define sipType_QAbstractSocket_SocketOption sipExportedTypes_QtNetwork[6]

#define sipType_QAbstractSocket_SocketState sipExportedTypes_QtNetwork[7]

#define sipType_QAbstractSocket_SocketError sipExportedTypes_QtNetwork[5]

#define sipType_QAbstractSocket_NetworkLayerProtocol sipExportedTypes_QtNetwork[3]

#define sipType_QAbstractSocket_SocketType sipExportedTypes_QtNetwork[8]

extern sipClassTypeDef sipTypeDef_QtNetwork_QAbstractSocket;

#define sipType_QAuthenticator sipExportedTypes_QtNetwork[9]

extern sipClassTypeDef sipTypeDef_QtNetwork_QAuthenticator;

#define sipType_QDnsDomainNameRecord sipExportedTypes_QtNetwork[10]

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsDomainNameRecord;

#define sipType_QDnsHostAddressRecord sipExportedTypes_QtNetwork[11]

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsHostAddressRecord;

#define sipType_QDnsMailExchangeRecord sipExportedTypes_QtNetwork[16]

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsMailExchangeRecord;

#define sipType_QDnsServiceRecord sipExportedTypes_QtNetwork[17]

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsServiceRecord;

#define sipType_QDnsTextRecord sipExportedTypes_QtNetwork[18]

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsTextRecord;

#define sipType_QDnsTlsAssociationRecord sipExportedTypes_QtNetwork[19]

#define sipType_QDnsTlsAssociationRecord_MatchingType sipExportedTypes_QtNetwork[21]

#define sipType_QDnsTlsAssociationRecord_Selector sipExportedTypes_QtNetwork[22]

#define sipType_QDnsTlsAssociationRecord_CertificateUsage sipExportedTypes_QtNetwork[20]

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsTlsAssociationRecord;

#define sipType_QDnsLookup sipExportedTypes_QtNetwork[12]

#define sipType_QDnsLookup_Type sipExportedTypes_QtNetwork[15]

#define sipType_QDnsLookup_Protocol sipExportedTypes_QtNetwork[14]

#define sipType_QDnsLookup_Error sipExportedTypes_QtNetwork[13]

extern sipClassTypeDef sipTypeDef_QtNetwork_QDnsLookup;

#define sipType_QFormDataPartBuilder sipExportedTypes_QtNetwork[36]

extern sipClassTypeDef sipTypeDef_QtNetwork_QFormDataPartBuilder;

#define sipType_QFormDataBuilder sipExportedTypes_QtNetwork[34]

#define sipType_QFormDataBuilder_Option sipExportedTypes_QtNetwork[35]

extern sipClassTypeDef sipTypeDef_QtNetwork_QFormDataBuilder;

#define sipType_QHostAddress sipExportedTypes_QtNetwork[38]

#define sipType_QHostAddress_ConversionModeFlag sipExportedTypes_QtNetwork[39]

#define sipType_QHostAddress_SpecialAddress sipExportedTypes_QtNetwork[40]

extern sipClassTypeDef sipTypeDef_QtNetwork_QHostAddress;

#define sipType_QHostInfo sipExportedTypes_QtNetwork[41]

#define sipType_QHostInfo_HostInfoError sipExportedTypes_QtNetwork[42]

extern sipClassTypeDef sipTypeDef_QtNetwork_QHostInfo;

#define sipType_QHstsPolicy sipExportedTypes_QtNetwork[43]

#define sipType_QHstsPolicy_PolicyFlag sipExportedTypes_QtNetwork[44]

extern sipClassTypeDef sipTypeDef_QtNetwork_QHstsPolicy;

#define sipType_QHttp1Configuration sipExportedTypes_QtNetwork[45]

extern sipClassTypeDef sipTypeDef_QtNetwork_QHttp1Configuration;

#define sipType_QHttp2Configuration sipExportedTypes_QtNetwork[46]

extern sipClassTypeDef sipTypeDef_QtNetwork_QHttp2Configuration;

#define sipType_QHttpHeaders sipExportedTypes_QtNetwork[47]

#define sipType_QHttpHeaders_WellKnownHeader sipExportedTypes_QtNetwork[48]

extern sipClassTypeDef sipTypeDef_QtNetwork_QHttpHeaders;

#define sipType_QHttpPart sipExportedTypes_QtNetwork[51]

extern sipClassTypeDef sipTypeDef_QtNetwork_QHttpPart;

#define sipType_QHttpMultiPart sipExportedTypes_QtNetwork[49]

#define sipType_QHttpMultiPart_ContentType sipExportedTypes_QtNetwork[50]

extern sipClassTypeDef sipTypeDef_QtNetwork_QHttpMultiPart;

#define sipType_QLocalServer sipExportedTypes_QtNetwork[75]

#define sipType_QLocalServer_SocketOption sipExportedTypes_QtNetwork[76]

extern sipClassTypeDef sipTypeDef_QtNetwork_QLocalServer;

#define sipType_QLocalSocket sipExportedTypes_QtNetwork[77]

#define sipType_QLocalSocket_SocketOption sipExportedTypes_QtNetwork[80]

#define sipType_QLocalSocket_LocalSocketState sipExportedTypes_QtNetwork[79]

#define sipType_QLocalSocket_LocalSocketError sipExportedTypes_QtNetwork[78]

extern sipClassTypeDef sipTypeDef_QtNetwork_QLocalSocket;

#define sipType_QNetworkAccessManager sipExportedTypes_QtNetwork[83]

#define sipType_QNetworkAccessManager_Operation sipExportedTypes_QtNetwork[84]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkAccessManager;

#define sipType_QNetworkCookie sipExportedTypes_QtNetwork[88]

#define sipType_QNetworkCookie_SameSite sipExportedTypes_QtNetwork[90]

#define sipType_QNetworkCookie_RawForm sipExportedTypes_QtNetwork[89]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkCookie;

#define sipType_QNetworkCookieJar sipExportedTypes_QtNetwork[91]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkCookieJar;

#define sipType_QNetworkDatagram sipExportedTypes_QtNetwork[92]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkDatagram;

#define sipType_QNetworkDiskCache sipExportedTypes_QtNetwork[93]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkDiskCache;

#define sipType_QNetworkInformation sipExportedTypes_QtNetwork[94]

#define sipType_QNetworkInformation_TransportMedium sipExportedTypes_QtNetwork[97]

#define sipType_QNetworkInformation_Feature sipExportedTypes_QtNetwork[95]

#define sipType_QNetworkInformation_Reachability sipExportedTypes_QtNetwork[96]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkInformation;

#define sipType_QNetworkAddressEntry sipExportedTypes_QtNetwork[85]

#define sipType_QNetworkAddressEntry_DnsEligibilityStatus sipExportedTypes_QtNetwork[86]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkAddressEntry;

#define sipType_QNetworkInterface sipExportedTypes_QtNetwork[98]

#define sipType_QNetworkInterface_InterfaceType sipExportedTypes_QtNetwork[100]

#define sipType_QNetworkInterface_InterfaceFlag sipExportedTypes_QtNetwork[99]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkInterface;

#define sipType_QNetworkProxy sipExportedTypes_QtNetwork[101]

#define sipType_QNetworkProxy_Capability sipExportedTypes_QtNetwork[102]

#define sipType_QNetworkProxy_ProxyType sipExportedTypes_QtNetwork[103]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkProxy;

#define sipType_QNetworkProxyQuery sipExportedTypes_QtNetwork[105]

#define sipType_QNetworkProxyQuery_QueryType sipExportedTypes_QtNetwork[106]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkProxyQuery;

#define sipType_QNetworkProxyFactory sipExportedTypes_QtNetwork[104]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkProxyFactory;

#define sipType_QNetworkReply sipExportedTypes_QtNetwork[107]

#define sipType_QNetworkReply_NetworkError sipExportedTypes_QtNetwork[108]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkReply;

#define sipType_QNetworkRequest sipExportedTypes_QtNetwork[109]

#define sipType_QNetworkRequest_TransferTimeoutConstant sipExportedTypes_QtNetwork[116]

#define sipType_QNetworkRequest_RedirectPolicy sipExportedTypes_QtNetwork[115]

#define sipType_QNetworkRequest_Priority sipExportedTypes_QtNetwork[114]

#define sipType_QNetworkRequest_LoadControl sipExportedTypes_QtNetwork[113]

#define sipType_QNetworkRequest_CacheLoadControl sipExportedTypes_QtNetwork[111]

#define sipType_QNetworkRequest_Attribute sipExportedTypes_QtNetwork[110]

#define sipType_QNetworkRequest_KnownHeaders sipExportedTypes_QtNetwork[112]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkRequest;

#define sipType_QNetworkRequestFactory sipExportedTypes_QtNetwork[117]

extern sipClassTypeDef sipTypeDef_QtNetwork_QNetworkRequestFactory;

#define sipType_QOcspResponse sipExportedTypes_QtNetwork[119]

extern sipClassTypeDef sipTypeDef_QtNetwork_QOcspResponse;

#define sipType_QPasswordDigestor sipExportedTypes_QtNetwork[121]

extern sipClassTypeDef sipTypeDef_QtNetwork_QPasswordDigestor;

#define sipType_QRestAccessManager sipExportedTypes_QtNetwork[122]

extern sipClassTypeDef sipTypeDef_QtNetwork_QRestAccessManager;

#define sipType_QRestReply sipExportedTypes_QtNetwork[123]

extern sipClassTypeDef sipTypeDef_QtNetwork_QRestReply;

#define sipType_QSsl sipExportedTypes_QtNetwork[124]

#define sipType_QSsl_SupportedFeature sipExportedTypes_QtNetwork[134]

#define sipType_QSsl_ImplementedClass sipExportedTypes_QtNetwork[129]

#define sipType_QSsl_AlertType sipExportedTypes_QtNetwork[126]

#define sipType_QSsl_AlertLevel sipExportedTypes_QtNetwork[125]

#define sipType_QSsl_SslOption sipExportedTypes_QtNetwork[132]

#define sipType_QSsl_SslProtocol sipExportedTypes_QtNetwork[133]

#define sipType_QSsl_AlternativeNameEntryType sipExportedTypes_QtNetwork[127]

#define sipType_QSsl_KeyAlgorithm sipExportedTypes_QtNetwork[130]

#define sipType_QSsl_EncodingFormat sipExportedTypes_QtNetwork[128]

#define sipType_QSsl_KeyType sipExportedTypes_QtNetwork[131]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSsl;

#define sipType_QSslCertificate sipExportedTypes_QtNetwork[135]

#define sipType_QSslCertificate_PatternSyntax sipExportedTypes_QtNetwork[136]

#define sipType_QSslCertificate_SubjectInfo sipExportedTypes_QtNetwork[137]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslCertificate;

#define sipType_QSslCertificateExtension sipExportedTypes_QtNetwork[138]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslCertificateExtension;

#define sipType_QSslCipher sipExportedTypes_QtNetwork[139]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslCipher;

#define sipType_QSslConfiguration sipExportedTypes_QtNetwork[140]

#define sipType_QSslConfiguration_NextProtocolNegotiationStatus sipExportedTypes_QtNetwork[141]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslConfiguration;

#define sipType_QSslDiffieHellmanParameters sipExportedTypes_QtNetwork[142]

#define sipType_QSslDiffieHellmanParameters_Error sipExportedTypes_QtNetwork[143]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslDiffieHellmanParameters;

#define sipType_QSslEllipticCurve sipExportedTypes_QtNetwork[144]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslEllipticCurve;

#define sipType_QSslError sipExportedTypes_QtNetwork[145]

#define sipType_QSslError_SslError sipExportedTypes_QtNetwork[146]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslError;

#define sipType_QSslKey sipExportedTypes_QtNetwork[147]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslKey;

#define sipType_QSslPreSharedKeyAuthenticator sipExportedTypes_QtNetwork[148]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslPreSharedKeyAuthenticator;

#define sipType_QTcpServer sipExportedTypes_QtNetwork[153]

extern sipClassTypeDef sipTypeDef_QtNetwork_QTcpServer;

#define sipType_QSslServer sipExportedTypes_QtNetwork[149]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslServer;

#define sipType_QTcpSocket sipExportedTypes_QtNetwork[154]

extern sipClassTypeDef sipTypeDef_QtNetwork_QTcpSocket;

#define sipType_QSslSocket sipExportedTypes_QtNetwork[150]

#define sipType_QSslSocket_PeerVerifyMode sipExportedTypes_QtNetwork[151]

#define sipType_QSslSocket_SslMode sipExportedTypes_QtNetwork[152]

extern sipClassTypeDef sipTypeDef_QtNetwork_QSslSocket;

#define sipType_QUdpSocket sipExportedTypes_QtNetwork[155]

extern sipClassTypeDef sipTypeDef_QtNetwork_QUdpSocket;

#define sipType_QList_0100QString sipExportedTypes_QtNetwork[73]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QString;

#define sipType_QList_0100QOcspResponse sipExportedTypes_QtNetwork[64]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QOcspResponse;

#define sipType_QMap_0100QByteArray_0100QVariant sipExportedTypes_QtNetwork[81]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QMap_0100QByteArray_0100QVariant;

#define sipType_QList_0100QSslEllipticCurve sipExportedTypes_QtNetwork[71]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSslEllipticCurve;

#define sipType_QList_0100QSslCipher sipExportedTypes_QtNetwork[70]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSslCipher;

#define sipType_QList_0100QSslCertificateExtension sipExportedTypes_QtNetwork[69]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSslCertificateExtension;

#define sipType_QList_0100QSslCertificate sipExportedTypes_QtNetwork[68]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSslCertificate;

#define sipType_std_optional_0100QJsonDocument sipExportedTypes_QtNetwork[158]

extern sipMappedTypeDef sipTypeDef_QtNetwork_std_optional_0100QJsonDocument;

#define sipType_QList_0100QNetworkProxy sipExportedTypes_QtNetwork[63]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QNetworkProxy;

#define sipType_QList_0100QNetworkInterface sipExportedTypes_QtNetwork[62]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QNetworkInterface;

#define sipType_QList_0100QNetworkAddressEntry sipExportedTypes_QtNetwork[60]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QNetworkAddressEntry;

#define sipType_QList_0100QNetworkCookie sipExportedTypes_QtNetwork[61]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QNetworkCookie;

#define sipType_QList_0100QHstsPolicy sipExportedTypes_QtNetwork[59]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QHstsPolicy;

#define sipType_QList_0100QSslError sipExportedTypes_QtNetwork[72]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSslError;

#define sipType_std_optional_0600QList_0100QDateTime sipExportedTypes_QtNetwork[159]

extern sipMappedTypeDef sipTypeDef_QtNetwork_std_optional_0600QList_0100QDateTime;

#define sipType_std_optional_0100QDateTime sipExportedTypes_QtNetwork[157]

extern sipMappedTypeDef sipTypeDef_QtNetwork_std_optional_0100QDateTime;

#define sipType_QList_0100QHostAddress sipExportedTypes_QtNetwork[58]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QHostAddress;

#define sipType_std_pair_0100QHostAddress_1800 sipExportedTypes_QtNetwork[161]

extern sipMappedTypeDef sipTypeDef_QtNetwork_std_pair_0100QHostAddress_1800;

#define sipType_QList_0100QDnsTlsAssociationRecord sipExportedTypes_QtNetwork[57]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QDnsTlsAssociationRecord;

#define sipType_QList_0100QDnsTextRecord sipExportedTypes_QtNetwork[56]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QDnsTextRecord;

#define sipType_QList_0100QDnsServiceRecord sipExportedTypes_QtNetwork[55]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QDnsServiceRecord;

#define sipType_QList_0100QDnsMailExchangeRecord sipExportedTypes_QtNetwork[54]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QDnsMailExchangeRecord;

#define sipType_QList_0100QDnsHostAddressRecord sipExportedTypes_QtNetwork[53]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QDnsHostAddressRecord;

#define sipType_QList_0100QDnsDomainNameRecord sipExportedTypes_QtNetwork[52]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QDnsDomainNameRecord;

#define sipType_QFlags_0100QSsl_SslOption sipExportedTypes_QtNetwork[33]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QFlags_0100QSsl_SslOption;

#define sipType_std_pair_0100QByteArray_0100QByteArray sipExportedTypes_QtNetwork[160]

extern sipMappedTypeDef sipTypeDef_QtNetwork_std_pair_0100QByteArray_0100QByteArray;

#define sipType_QFlags_0100QNetworkProxy_Capability sipExportedTypes_QtNetwork[32]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QFlags_0100QNetworkProxy_Capability;

#define sipType_QFlags_0100QNetworkInterface_InterfaceFlag sipExportedTypes_QtNetwork[31]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QFlags_0100QNetworkInterface_InterfaceFlag;

#define sipType_QFlags_0100QNetworkInformation_Feature sipExportedTypes_QtNetwork[30]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QFlags_0100QNetworkInformation_Feature;

#define sipType_QList_0600std_pair_0100QByteArray_0100QByteArray sipExportedTypes_QtNetwork[74]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0600std_pair_0100QByteArray_0100QByteArray;

#define sipType_QFlags_0100QLocalSocket_SocketOption sipExportedTypes_QtNetwork[29]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QFlags_0100QLocalSocket_SocketOption;

#define sipType_QFlags_0100QLocalServer_SocketOption sipExportedTypes_QtNetwork[28]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QFlags_0100QLocalServer_SocketOption;

#define sipType_QFlags_0100QHstsPolicy_PolicyFlag sipExportedTypes_QtNetwork[27]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QFlags_0100QHstsPolicy_PolicyFlag;

#define sipType_QFlags_0100QHostAddress_ConversionModeFlag sipExportedTypes_QtNetwork[26]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QFlags_0100QHostAddress_ConversionModeFlag;

#define sipType_QFlags_0100QFormDataBuilder_Option sipExportedTypes_QtNetwork[25]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QFlags_0100QFormDataBuilder_Option;

#define sipType_QFlags_0100QAbstractSocket_PauseMode sipExportedTypes_QtNetwork[24]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QFlags_0100QAbstractSocket_PauseMode;

#define sipType_QFlags_0100QAbstractSocket_BindFlag sipExportedTypes_QtNetwork[23]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QFlags_0100QAbstractSocket_BindFlag;

#define sipType_QHash_0100QNetworkRequest_Attribute_0100QVariant sipExportedTypes_QtNetwork[37]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QHash_0100QNetworkRequest_Attribute_0100QVariant;

#define sipType_QList_0100QSsl_SupportedFeature sipExportedTypes_QtNetwork[67]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSsl_SupportedFeature;

#define sipType_QList_0100QSsl_ImplementedClass sipExportedTypes_QtNetwork[65]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSsl_ImplementedClass;

#define sipType_QList_0100QSsl_SslProtocol sipExportedTypes_QtNetwork[66]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QList_0100QSsl_SslProtocol;

#define sipType_QMultiMap_0100QSsl_AlternativeNameEntryType_0100QString sipExportedTypes_QtNetwork[82]

extern sipMappedTypeDef sipTypeDef_QtNetwork_QMultiMap_0100QSsl_AlternativeNameEntryType_0100QString;

#define sipType_Q_IPV6ADDR sipExportedTypes_QtNetwork[156]

extern sipMappedTypeDef sipTypeDef_QtNetwork_Q_IPV6ADDR;

#define sipType_QOcspRevocationReason sipExportedTypes_QtNetwork[120]

#define sipType_QOcspCertificateStatus sipExportedTypes_QtNetwork[118]

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtNetwork;
extern sipExportedModuleDef sipModuleAPI_QtNetwork;
extern sipTypeDef *sipExportedTypes_QtNetwork[];

#define sipType_QObject sipImportedTypes_QtNetwork_QtCore[19].it_td

#define sipType_QIODeviceBase sipImportedTypes_QtNetwork_QtCore[13].it_td

#define sipType_QIODevice sipImportedTypes_QtNetwork_QtCore[12].it_td

#define sipType_QByteArray sipImportedTypes_QtNetwork_QtCore[1].it_td

#define sipType_QEvent sipImportedTypes_QtNetwork_QtCore[8].it_td

#define sipType_QTimerEvent sipImportedTypes_QtNetwork_QtCore[23].it_td

#define sipType_QChildEvent sipImportedTypes_QtNetwork_QtCore[3].it_td

#define sipType_QCryptographicHash_Algorithm sipImportedTypes_QtNetwork_QtCore[4].it_td

#define sipType_QDataStream sipImportedTypes_QtNetwork_QtCore[5].it_td

#define sipType_QDateTime sipImportedTypes_QtNetwork_QtCore[6].it_td

#define sipType_QDeadlineTimer sipImportedTypes_QtNetwork_QtCore[7].it_td

#define sipType_QJsonDocument sipImportedTypes_QtNetwork_QtCore[14].it_td

#define sipType_QJsonParseError sipImportedTypes_QtNetwork_QtCore[15].it_td

#define sipType_QMetaMethod sipImportedTypes_QtNetwork_QtCore[18].it_td

#define sipType_QUrl sipImportedTypes_QtNetwork_QtCore[24].it_td

#define sipType_QUrl_ParsingMode sipImportedTypes_QtNetwork_QtCore[25].it_td

#define sipType_QUrlQuery sipImportedTypes_QtNetwork_QtCore[26].it_td

#define sipType_QVariant sipImportedTypes_QtNetwork_QtCore[27].it_td

#define sipType_QList_0100QByteArray sipImportedTypes_QtNetwork_QtCore[16].it_td

#define sipType_QMap_0100QString_0100QVariant sipImportedTypes_QtNetwork_QtCore[17].it_td

#define sipType_QHash_0100QString_0100QVariant sipImportedTypes_QtNetwork_QtCore[11].it_td

#define sipType_QFlags_0100QUrl_ComponentFormattingOption sipImportedTypes_QtNetwork_QtCore[10].it_td

#define sipType_QFlags_0100QIODeviceBase_OpenModeFlag sipImportedTypes_QtNetwork_QtCore[9].it_td

#define sipType_QByteArrayView sipImportedTypes_QtNetwork_QtCore[2].it_td

#define sipType_QStringList sipImportedTypes_QtNetwork_QtCore[21].it_td

#define sipType_QStringView sipImportedTypes_QtNetwork_QtCore[22].it_td

#define sipType_std_optional_0600QList_3800 sipImportedTypes_QtNetwork_QtCore[32].it_td

#define sipType_std_optional_3800 sipImportedTypes_QtNetwork_QtCore[33].it_td

#define sipType_QString sipImportedTypes_QtNetwork_QtCore[20].it_td

#define sipType_std_chrono_seconds sipImportedTypes_QtNetwork_QtCore[31].it_td

#define sipType_std_chrono_milliseconds sipImportedTypes_QtNetwork_QtCore[30].it_td

#define sipType_QAnyStringView sipImportedTypes_QtNetwork_QtCore[0].it_td

#define sipType_quintptr sipImportedTypes_QtNetwork_QtCore[29].it_td

#define sipType_qintptr sipImportedTypes_QtNetwork_QtCore[28].it_td
extern sipImportedTypeDef sipImportedTypes_QtNetwork_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtNetwork_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtNetwork_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtNetwork_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtNetwork_qt_metacast;
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtNetwork/qhostinfo.sip"
// Imports from QtCore.
typedef sipErrorState (*pyqt6_qtnetwork_get_connection_parts_t)(PyObject *, QObject *, const char *, bool, QObject **, QByteArray &);
extern pyqt6_qtnetwork_get_connection_parts_t pyqt6_qtnetwork_get_connection_parts;
#line 3737 "/build/pyqt6/src/pyqt6-6.11.0/build/QtNetwork/sipAPIQtNetwork.h"

#endif
